@@ -83,6 +83,21 @@ const uint32 MENU_CART_ATTACH_IDE64				= 'M049';
 const uint32 MENU_CART_SET_DEFAULT				= 'M050';
 const uint32 MENU_CART_DETACH					= 'M051';
 const uint32 MENU_CART_FREEZE					= 'M052';
+const uint32 MENU_NETPLAY_SERVER				= 'M053';
+const uint32 MENU_NETPLAY_CLIENT				= 'M054';
+const uint32 MENU_NETPLAY_DISCONNECT			= 'M055';
+const uint32 MENU_NETPLAY_SETTINGS				= 'M056';
+
+const uint32 MENU_EVENT_TOGGLE_RECORD			= 'M070';
+const uint32 MENU_EVENT_TOGGLE_PLAYBACK			= 'M071';
+const uint32 MENU_EVENT_SETMILESTONE			= 'M072';
+const uint32 MENU_EVENT_RESETMILESTONE			= 'M073';
+const uint32 MENU_EVENT_START_MODE_SAVE			= 'M074';
+const uint32 MENU_EVENT_START_MODE_LOAD			= 'M075';
+const uint32 MENU_EVENT_START_MODE_RESET		= 'M076';
+const uint32 MENU_EVENT_START_MODE_PLAYBACK		= 'M077';
+const uint32 MENU_EVENT_SNAPSHOT_START			= 'M078';
+const uint32 MENU_EVENT_SNAPSHOT_END			= 'M079';
 
 const uint32 MENU_CART_VIC20_16KB_2000			= 'M060';
 const uint32 MENU_CART_VIC20_16KB_4000			= 'M061';
@@ -102,6 +117,10 @@ const uint32 MENU_TOGGLE_DOUBLESIZE				= 'M106';
 const uint32 MENU_TOGGLE_DOUBLESCAN				= 'M107';
 const uint32 MENU_TOGGLE_VIDEOCACHE				= 'M108';
 const uint32 MENU_TOGGLE_REU					= 'M109';
+const uint32 MENU_TOGGLE_GEORAM					= 'M143';
+const uint32 MENU_TOGGLE_RAMCART					= 'M145';
+const uint32 MENU_TOGGLE_PLUS60K					= 'M146';
+const uint32 MENU_TOGGLE_C64_256K					= 'M144';
 const uint32 MENU_TOGGLE_MOUSE					= 'M110';
 const uint32 MENU_TOGGLE_DIRECTWINDOW			= 'M111';
 const uint32 MENU_TOGGLE_IEEE488				= 'M112';
@@ -165,6 +184,25 @@ const uint32 MENU_REU_SIZE_4096					= 'M405';
 const uint32 MENU_REU_SIZE_8192					= 'M406';
 const uint32 MENU_REU_SIZE_16384				= 'M407';
 
+const uint32 MENU_GEORAM_SIZE_64					= 'M450';
+const uint32 MENU_GEORAM_SIZE_128					= 'M451';
+const uint32 MENU_GEORAM_SIZE_256					= 'M452';
+const uint32 MENU_GEORAM_SIZE_512					= 'M453';
+const uint32 MENU_GEORAM_SIZE_1024					= 'M454';
+const uint32 MENU_GEORAM_SIZE_2048					= 'M455';
+const uint32 MENU_GEORAM_SIZE_4096					= 'M456';
+
+const uint32 MENU_RAMCART_SIZE_64					= 'M457';
+const uint32 MENU_RAMCART_SIZE_128					= 'M458';
+
+const uint32 MENU_PLUS60K_BASE_D040					= 'M459';
+const uint32 MENU_PLUS60K_BASE_D100					= 'M460';
+
+const uint32 MENU_C64_256K_BASE_DE00				= 'M459';
+const uint32 MENU_C64_256K_BASE_DE80				= 'M460';
+const uint32 MENU_C64_256K_BASE_DF00				= 'M461';
+const uint32 MENU_C64_256K_BASE_DF80				= 'M462';
+
 const uint32 MENU_ABOUT							= 'M901';
 const uint32 MENU_CONTRIBUTORS					= 'M902';
 const uint32 MENU_LICENSE						= 'M904';
