@@ -3,7 +3,7 @@
  *
  * Written by
  *  Ettore Perazzoli <ettore@comm2000.it>
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -34,16 +34,16 @@
 #include <pc.h>
 #include <stdarg.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/farptr.h>
 #include <time.h>
 
-#include "kbd.h"
-
 #include "cmdline.h"
 #include "datasette.h"
 #include "fliplist.h"
 #include "interrupt.h"
-#include "joystick.h"
+#include "joy.h"
+#include "kbd.h"
 #include "keyboard.h"
 #include "log.h"
 #include "machine.h"
@@ -58,17 +58,6 @@
 
 /* ------------------------------------------------------------------------- */
 
-/* Joystick status. We use 3 elements to avoid `-1'.  */
-BYTE joystick_value[3] = { 0, 0, 0 };
-
-/* 40/80 column key.  */
-static key_ctrl_column4080_func_t key_ctrl_column4080_func = NULL;
-
-/* CAPS key.  */
-static key_ctrl_caps_func_t key_ctrl_caps_func = NULL;
-
-/* ------------------------------------------------------------------------- */
-
 /* Segment info for the standard keyboard handler.  */
 static _go32_dpmi_seginfo std_kbd_handler_seginfo;
 
@@ -93,8 +82,6 @@ struct _convmap {
     int virtual_shift_row, virtual_shift_column;
 };
 static struct _convmap keyconvmaps[MAX_CONVMAPS];
-static struct _convmap *keyconv_base;
-static int num_keyconvmaps;
 
 /* Function for triggering cartridge (e.g. AR) freezing.  */
 static void (*freeze_function)(void);
@@ -111,55 +98,6 @@ BYTE _kbd_extended_key_tab[256] = {
 
 /* ------------------------------------------------------------------------- */
 
-static int keymap_index;
-
-static int set_keymap_index(resource_value_t v, void *param)
-{
-    int real_index;
-
-    keymap_index = (int) v;
-
-    /* The `>> 1' is a temporary hack to avoid the positional/symbol mapping
-       which is not implemented in the MS-DOS version.  */
-    real_index = keymap_index >> 1;
-
-#if 0
-    if (real_index >= num_keyconvmaps)
-        return -1;
-#else
-    /* Argh, we cannot do the sanity check because we initialize the keyboard
-       /after/ this resource is set.  FIXME: Something we should definitely
-       fix some day.  */
-#endif
-
-    keyconv_base = &keyconvmaps[real_index];
-    return 0;
-}
-
-static resource_t resources[] = {
-    { "KeymapIndex", RES_INTEGER, (resource_value_t) 0,
-      (resource_value_t *) &keymap_index, set_keymap_index, NULL },
-    { NULL }
-};
-
-int kbd_resources_init(void)
-{
-    return resources_register(resources);
-}
-
-static cmdline_option_t cmdline_options[] = {
-    { "-keymap", SET_RESOURCE, 1, NULL, NULL, "KeymapIndex", NULL,
-      "<number>", "Specify index of used keymap" },
-    { NULL },
-};
-
-int kbd_cmdline_options_init(void)
-{
-    return cmdline_register_options(cmdline_options);
-}
-
-/* ------------------------------------------------------------------------- */
-
 /* These are the keyboard commands that cannot be handled within a keyboard
    interrupt.  They are dispatched via `kbd_flush_commands()'.  */
 
@@ -209,9 +147,9 @@ static void queue_command(kbd_command_type_t type,
 static void queue_command_end(void) { }
 
 /* CPU trap to enter the main menu.  */
-static void menu_trap(ADDRESS addr, void *data)
+static void menu_trap(WORD addr, void *data)
 {
-    ui_main((char) (unsigned long) data);
+    ui_main((char)(unsigned long)data);
 }
 
 /* Dispatch all the pending keyboard commands.  */
@@ -226,11 +164,11 @@ void kbd_flush_commands(void)
         switch (command_queue[i].type) {
           case KCMD_HARD_RESET:
             vsync_suspend_speed_eval();
-            machine_powerup();
+            machine_trigger_reset(MACHINE_RESET_MODE_HARD);
             break;
           case KCMD_RESET:
             vsync_suspend_speed_eval();
-            maincpu_trigger_reset();
+            machine_trigger_reset(MACHINE_RESET_MODE_SOFT);
             break;
           case KCMD_RESTORE_PRESSED:
             machine_set_restore_key(1);
@@ -243,23 +181,24 @@ void kbd_flush_commands(void)
                 freeze_function();
             break;
           case KCMD_FLIP_NEXT:
-            flip_attach_head(8, 1);
+            fliplist_attach_head(8, 1);
             break;
           case KCMD_FLIP_PREVIOUS:
-            flip_attach_head(8, 0);
+            fliplist_attach_head(8, 0);
             break;
           case KCMD_FLIP_ADD:
-            flip_add_image(8);
+            fliplist_add_image(8);
             break;
           case KCMD_FLIP_REMOVE:
-            flip_remove(-1, NULL);
+            fliplist_remove(-1, NULL);
             break;
           case KCMD_TOGGLE_WARP:
             resources_toggle("WarpMode", NULL);
             break;
 
           case KCMD_MENU:
-            maincpu_trigger_trap(menu_trap, (void *) command_queue[i].data);
+            interrupt_maincpu_trigger_trap(menu_trap,
+                                           (void *)command_queue[i].data);
             break;
           case KCMD_TOGGLE_STATUSBAR:
             if (statusbar_enabled()) {
@@ -315,7 +254,7 @@ static char kcode_to_ascii(unsigned int kcode)
 
 static void my_kbd_interrupt_handler(void)
 {
-    static int extended = 0;	/* Extended key count.  */
+    static int extended = 0;    /* Extended key count.  */
     static int skip_count = 0;
     unsigned int kcode;
 
@@ -326,11 +265,11 @@ static void my_kbd_interrupt_handler(void)
         outportb(0x20, 0x20);
         return;
     } else if (kcode == 0xe0) {
-	/* Extended key: at the next interrupt we'll get its extended keycode
-	   or 0xe0 again.  */
-	extended++;
-	outportb(0x20, 0x20);
-	return;
+        /* Extended key: at the next interrupt we'll get its extended keycode
+           or 0xe0 again.  */
+        extended++;
+        outportb(0x20, 0x20);
+        return;
     } else if (kcode == 0xe1) {
         /* Damn Pause key.  It sends 0xe1 0x1d 0x52 0xe1 0x9d 0xd2.  This is
            awesome, but at least we know it's the only sequence starting by
@@ -341,7 +280,6 @@ static void my_kbd_interrupt_handler(void)
     }
 
     if (!(kcode & 0x80)) {      /* Key pressed.  */
-
         /* Derive the extended keycode.  */
         if (extended == 1)
             kcode = _kbd_extended_key_tab[kcode];
@@ -367,29 +305,13 @@ static void my_kbd_interrupt_handler(void)
             modifiers.right_alt = 1;
             break;
         }
-
-        /* This must be done separately because some machines (eg. the PETs)
-           might want to map this differently.  */
-        if (kcode == K_PGUP)  /* Restore */
-            queue_command(KCMD_RESTORE_PRESSED, (kbd_command_data_t) 0);
-
-	switch (kcode) {
+        switch (kcode) {
           case K_ESC:           /* Menu */
-            queue_command(KCMD_MENU, (kbd_command_data_t) 0);
+            queue_command(KCMD_MENU, (kbd_command_data_t)0);
             break;
           case K_SCROLLOCK:     /* Warp mode on/off */
-            queue_command(KCMD_TOGGLE_WARP, (kbd_command_data_t) 0);
+            queue_command(KCMD_TOGGLE_WARP, (kbd_command_data_t)0);
             break;
-          case K_F4: 
-          case K_F7: /* 40/80 column screen switch */
-            if (kcode == K_F7 && key_ctrl_column4080_func != NULL) {
-                key_ctrl_column4080_func();
-                break;
-            } 
-            if (kcode == K_F4 && key_ctrl_caps_func != NULL) {
-                key_ctrl_caps_func();
-                break;
-            }
             /* Fall through */
           default:
             if (modifiers.left_alt && modifiers.left_ctrl) {
@@ -397,32 +319,33 @@ static void my_kbd_interrupt_handler(void)
                   case K_F12:
                     /* Ctrl-Alt-F12 does a hard reset. */
                     queue_command(KCMD_HARD_RESET,
-                                  (kbd_command_data_t) 0);
+                                  (kbd_command_data_t)0);
                     break;
                   case K_F4:
                     /* Ctrl-Alt-F4 is RECORD on the datasette. */
                     queue_command(KCMD_DATASETTE_RECORD,
-                                  (kbd_command_data_t) 0);
+                                  (kbd_command_data_t)0);
                     break;
                   case K_F5:
                     /* Ctrl-Alt-F5 is PLAY on the datasette. */
                     queue_command(KCMD_DATASETTE_START,
-                                  (kbd_command_data_t) 0);
+                                  (kbd_command_data_t)0);
                     break;
                   case K_F6:
                     /* Ctrl-Alt-F6 is REWIND on the datasette. */
                     queue_command(KCMD_DATASETTE_REWIND,
-                                  (kbd_command_data_t) 0);
+                                  (kbd_command_data_t)0);
                     break;
                   case K_F7:
                     /* Ctrl-Alt-F7 is FF on the datasette. */
                     queue_command(KCMD_DATASETTE_FORWARD,
-                                  (kbd_command_data_t) 0);
+                                  (kbd_command_data_t)0);
                     break;
+
                   case K_F8:
                     /* Ctrl-Alt-F8 is STOP on the datasette. */
                     queue_command(KCMD_DATASETTE_STOP,
-                                  (kbd_command_data_t) 0);
+                                  (kbd_command_data_t)0);
                     break;
                 }
             } else if (modifiers.left_alt || modifiers.right_alt) {
@@ -430,55 +353,49 @@ static void my_kbd_interrupt_handler(void)
                 switch (kcode) {
                   case K_F12:
                     /* Alt-F12 does a reset.  */
-                    queue_command(KCMD_RESET, (kbd_command_data_t) 0);
+                    queue_command(KCMD_RESET, (kbd_command_data_t)0);
                     break;
                   case K_F1:
                     /* Alt-F1 Next image in flip list.  */
-                    queue_command(KCMD_FLIP_NEXT, (kbd_command_data_t) 0);
+                    queue_command(KCMD_FLIP_NEXT, (kbd_command_data_t)0);
                     break;
                   case K_F2:
                     /* Alt-F2 Previous image in flip list.  */
-                    queue_command(KCMD_FLIP_PREVIOUS, (kbd_command_data_t) 0);
+                    queue_command(KCMD_FLIP_PREVIOUS, (kbd_command_data_t)0);
                     break;
                   case K_F3:
                     /* Alt-F3 Add image to flip list.  */
-                    queue_command(KCMD_FLIP_ADD, (kbd_command_data_t) 0);
+                    queue_command(KCMD_FLIP_ADD, (kbd_command_data_t)0);
                     break;
                   case K_F4:
                     /* Alt-F4 remove image from flip list.  */
-                    queue_command(KCMD_FLIP_REMOVE, (kbd_command_data_t) 0);
+                    queue_command(KCMD_FLIP_REMOVE, (kbd_command_data_t)0);
                     break;
                   case K_F5:
                     /* Alt-F5 toggles statusbar.  */
                       queue_command(KCMD_TOGGLE_STATUSBAR,
-                                    (kbd_command_data_t) 0);
+                                    (kbd_command_data_t)0);
                     break;
                   case K_PAUSE:
                     /* Alt-Pause enables cartridge freezing.  */
-                    queue_command(KCMD_FREEZE, (kbd_command_data_t) 0);
+                    queue_command(KCMD_FREEZE, (kbd_command_data_t)0);
                     break;
                   default:
                     /* Alt-{letter,number} enters the main menu.  */
                     if (isalnum((int) kcode_to_ascii(kcode)))
                         queue_command(KCMD_MENU,
-                                      (kbd_command_data_t) kcode_to_ascii(kcode));
+                            (kbd_command_data_t)kcode_to_ascii(kcode));
                 }
             } else {
                 /* "Normal" key.  */
-                if (!joystick_handle_key(kcode, 1)) {
-                    keyboard_set_keyarr(keyconv_base->map[kcode].row,
-                               keyconv_base->map[kcode].column, 1);
-                    if (keyconv_base->map[kcode].vshift)
-                        keyboard_set_keyarr(keyconv_base->virtual_shift_row,
-                                   keyconv_base->virtual_shift_column, 1);
-                }
+                if (!joystick_handle_key(kcode, 1))
+                    keyboard_key_pressed((signed long)kcode);
             }
-	}
+        }
 
     } else {                    /* Key released.  */
-
         /* Remove release bit.  */
-        kcode &= 0x7F;
+        kcode &= 0x7f;
 
         /* Derive the extended keycode.  */
         if (extended == 1)
@@ -506,19 +423,10 @@ static void my_kbd_interrupt_handler(void)
             break;
         }
 
-        /* This must be done separately because some machines (eg. the PETs)
-           might want to map this differently.  */
-        if (kcode == K_PGUP)
-            queue_command(KCMD_RESTORE_RELEASED, (kbd_command_data_t) 0);
-
         if (!modifiers.left_alt && !modifiers.right_alt) {
-            if (!joystick_handle_key(kcode, 0)) {
-                keyboard_set_keyarr(keyconv_base->map[kcode].row,
-                           keyconv_base->map[kcode].column, 0);
-                if (keyconv_base->map[kcode].vshift)
-                    keyboard_set_keyarr(keyconv_base->virtual_shift_row,
-                               keyconv_base->virtual_shift_column, 0);
-            }
+            /* "Normal" key.  */
+            if (!joystick_handle_key(kcode, 0))
+                keyboard_key_released((signed long)kcode);
         }
 
     }
@@ -537,7 +445,7 @@ void kbd_install(void)
     int r;
     static _go32_dpmi_seginfo my_kbd_handler_seginfo;
 
-    my_kbd_handler_seginfo.pm_offset = (int) my_kbd_interrupt_handler;
+    my_kbd_handler_seginfo.pm_offset = (int)my_kbd_interrupt_handler;
     my_kbd_handler_seginfo.pm_selector = _go32_my_cs();
     r = _go32_dpmi_allocate_iret_wrapper(&my_kbd_handler_seginfo);
     if (r) {
@@ -545,7 +453,9 @@ void kbd_install(void)
                   "Cannot allocate IRET wrapper for the keyboard interrupt.");
 	exit(-1);
     }
-    r = _go32_dpmi_set_protected_mode_interrupt_vector(9, &my_kbd_handler_seginfo);
+
+    r = _go32_dpmi_set_protected_mode_interrupt_vector(9,
+            &my_kbd_handler_seginfo);
     if (r) {
 	log_error(LOG_DEFAULT,
                   "Cannot install the keyboard interrupt handler.");
@@ -553,8 +463,7 @@ void kbd_install(void)
     }
 
     /* Initialize the keyboard matrix.  */
-    memset(keyarr, 0, sizeof(keyarr));
-    memset(rev_keyarr, 0, sizeof(rev_keyarr));
+    keyboard_clear_keymatrix();
     /* Reset modifier status.  */
     memset(&modifiers, 0, sizeof(modifiers));
 }
@@ -576,12 +485,8 @@ static void kbd_exit(void)
     kbd_uninstall();
 }
 
-/* Initialize the keyboard driver.  */
-int kbd_init(int num, ...)
+static void kbd_init_common(void)
 {
-    if (num > MAX_CONVMAPS)
-        return -1;
-
     _go32_dpmi_get_protected_mode_interrupt_vector(9, &std_kbd_handler_seginfo);
     atexit(kbd_exit);
 
@@ -591,47 +496,17 @@ int kbd_init(int num, ...)
     _go32_dpmi_lock_code(queue_command, (unsigned long)queue_command_end
                          - (unsigned long)queue_command);
 
-    {
-        va_list p;
-        int i;
 
-        num_keyconvmaps = num;
-
-        va_start(p, num);
-        for (i = 0; i < num_keyconvmaps; i++) {
-            keyconv *map;
-            unsigned int sizeof_map;
-            int shift_row, shift_column;
-
-            shift_row = va_arg(p, int);
-            shift_column = va_arg(p, int);
-            map = va_arg(p, keyconv *);
-            sizeof_map = va_arg(p, unsigned int);
-
-            _go32_dpmi_lock_data(map, sizeof_map);
-            keyconvmaps[i].map = map;
-            keyconvmaps[i].virtual_shift_row = shift_row;
-            keyconvmaps[i].virtual_shift_column = shift_column;
-        }
-    }
-
-    _go32_dpmi_lock_data(&keymap_index, sizeof(keymap_index));
     _go32_dpmi_lock_data(keyconvmaps, sizeof(keyconvmaps));
     _go32_dpmi_lock_data(keyarr, sizeof(keyarr));
     _go32_dpmi_lock_data(rev_keyarr, sizeof(rev_keyarr));
-    _go32_dpmi_lock_data(joystick_value, sizeof(joystick_value));
     _go32_dpmi_lock_data(&modifiers, sizeof(modifiers));
     _go32_dpmi_lock_data(&num_queued_commands, sizeof(num_queued_commands));
     _go32_dpmi_lock_data(&command_queue, sizeof(command_queue));
 
     num_queued_commands = 0;
 
-    /* FIXME: argh, another hack.  */
-    keyconv_base = &keyconvmaps[keymap_index >> 1];
-
     kbd_install();
-
-    return 0;
 }
 
 /* ------------------------------------------------------------------------- */
@@ -666,13 +541,24 @@ const char *kbd_code_to_string(kbd_code_t kcode)
 
 /* ------------------------------------------------------------------------ */
 
-void kbd_register_column4080_key(key_ctrl_column4080_func_t func)
+void kbd_arch_init(void)
 {
-    key_ctrl_column4080_func = func;
+    kbd_init_common();
 }
 
-void kbd_register_caps_key(key_ctrl_caps_func_t func)
+signed long kbd_arch_keyname_to_keynum(char *keyname)
 {
-    key_ctrl_caps_func = func;
+    return (signed long)atoi(keyname);
+}
+
+const char *kbd_arch_keynum_to_keyname(signed long keynum)
+{
+    static char keyname[20];
+
+    memset(keyname, 0, 20);
+
+    sprintf(keyname, "%li", keynum);
+
+    return keyname;
 }
 
