@@ -361,7 +361,7 @@ void ui_enable_drive_status(ui_drive_enable_t state, int *drive_led_color)
 void ui_display_drive_track(unsigned int drive_number, unsigned int drive_base, 
                             unsigned int half_track_number)
 {
-    double track_number = (double)half_track_number;
+    double track_number = (double)half_track_number/2.0;
 
     ui_status_track[drive_number] = track_number;
     ui_draw_drive_status(drive_number);
@@ -572,3 +572,8 @@ void ui_dispatch_events(void)
     }
 }
 
+void ui_display_statustext(const char *text, int fade_out)
+{
+}
+
+
