@@ -525,6 +525,20 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
     case IDM_REU:
         toggle("REU");
         return;
+    case IDM_GEORAM:
+        toggle("GEORAM");
+        return;
+    case IDM_RAMCART:
+        toggle("RAMCART");
+        return;
+#ifdef __X64__
+    case IDM_PLUS60K:
+        toggle("PLUS60K");
+        return;
+    case IDM_C64_256K:
+        toggle("C64_256K");
+        return;
+#endif
 #ifdef HAVE_TFE
     case IDM_TFE:
         toggle("ETHERNET_ACTIVE");
@@ -541,6 +555,43 @@ void menu_action(HWND hwnd, USHORT idm) //, MPARAM mp2)
         resources_set_value("REUSize",
                             (resource_value_t*)((idm&0xff)<<7));
         return;
+
+    case IDM_GEORAM64:
+    case IDM_GEORAM128:
+    case IDM_GEORAM256:
+    case IDM_GEORAM512:
+    case IDM_GEORAM1024:
+    case IDM_GEORAM2048:
+    case IDM_GEORAM4096:
+        resources_set_value("GEORAMSize",
+                            (resource_value_t*)((idm&0xff)<<6));
+        return;
+
+    case IDM_RAMCART64:
+    case IDM_RAMCART128:
+        resources_set_value("RAMCARTSize",
+                            (resource_value_t*)((idm&0xf)<<6));
+        return;
+
+#ifdef __X64__
+    case IDM_PLUS60KD040:
+        resources_set_value("PLUS60Kbase",
+                            (resource_value_t*)0xd040);
+        return;
+
+    case IDM_PLUS60KD100:
+        resources_set_value("PLUS60Kbase",
+                            (resource_value_t*)0xd100);
+        return;
+    case IDM_C64_256K_BASEDE00:
+    case IDM_C64_256K_BASEDE80:
+    case IDM_C64_256K_BASEDF00:
+    case IDM_C64_256K_BASEDF80:
+        resources_set_value("C64_256Kbase",
+                            (resource_value_t*)(((idm&3)*80)+0xde00));
+        return;
+#endif
+
 #endif // __X64__ || __X128__
 #ifdef HAVE_MOUSE
     case IDM_MOUSE:
@@ -1175,6 +1226,20 @@ void menu_select(HWND hwnd, USHORT item)
         resources_get_value("REU", (void *)&val);
         WinCheckMenuItem(hwnd,  IDM_REU,     val);
         WinEnableMenuItem(hwnd, IDM_REUSIZE, val);
+        resources_get_value("GEORAM", (void *)&val);
+        WinCheckMenuItem(hwnd,  IDM_GEORAM,     val);
+        WinEnableMenuItem(hwnd, IDM_GEORAMSIZE, val);
+        resources_get_value("RAMCART", (void *)&val);
+        WinCheckMenuItem(hwnd,  IDM_RAMCART,     val);
+        WinEnableMenuItem(hwnd, IDM_RAMCARTSIZE, val);
+#endif
+#ifdef __X64__
+        resources_get_value("PLUS60K", (void *)&val);
+        WinCheckMenuItem(hwnd,  IDM_PLUS60K,     val);
+        WinEnableMenuItem(hwnd, IDM_PLUS60KBASE, val);
+        resources_get_value("C64_256K", (void *)&val);
+        WinCheckMenuItem(hwnd,  IDM_C64_256K,     val);
+        WinEnableMenuItem(hwnd, IDM_C64_256K_BASE, val);
 #endif
 #ifdef __XPET__
         WinCheckRes(hwnd, IDM_CHARSET,  "Basic1Chars");
@@ -1242,6 +1307,39 @@ void menu_select(HWND hwnd, USHORT item)
         WinCheckMenuItem(hwnd, IDM_REU8192,  val==8192);
         WinCheckMenuItem(hwnd, IDM_REU16384, val==16384);
         return;
+
+    case IDM_GEORAMSIZE:
+        resources_get_value("GEORAMSize", (void *)&val);
+        WinCheckMenuItem(hwnd, IDM_GEORAM64,   val==64);
+        WinCheckMenuItem(hwnd, IDM_GEORAM128,   val==128);
+        WinCheckMenuItem(hwnd, IDM_GEORAM256,   val==256);
+        WinCheckMenuItem(hwnd, IDM_GEORAM512,   val==512);
+        WinCheckMenuItem(hwnd, IDM_GEORAM1024,  val==1024);
+        WinCheckMenuItem(hwnd, IDM_GEORAM2048,  val==2048);
+        WinCheckMenuItem(hwnd, IDM_GEORAM4096,  val==4096);
+        return;
+
+    case IDM_RAMCARTSIZE:
+        resources_get_value("RAMCARTSize", (void *)&val);
+        WinCheckMenuItem(hwnd, IDM_RAMCART64,   val==64);
+        WinCheckMenuItem(hwnd, IDM_RAMCART128,   val==128);
+        return;
+
+#ifdef __X64__
+    case IDM_PLUS60KBASE:
+        resources_get_value("PLUS60Kbase", (void *)&val);
+        WinCheckMenuItem(hwnd, IDM_PLUS60KD040,   val==0xd040);
+        WinCheckMenuItem(hwnd, IDM_PLUS60KD100,   val==0xd100);
+        return;
+
+    case IDM_C64_256K_BASE:
+        resources_get_value("C64_256K_Base", (void *)&val);
+        WinCheckMenuItem(hwnd, IDM_C64_256K_BASEDE00,   val==0xde00);
+        WinCheckMenuItem(hwnd, IDM_C64_256K_BASEDE80,   val==0xde80);
+        WinCheckMenuItem(hwnd, IDM_C64_256K_BASEDF00,   val==0xdf00);
+        WinCheckMenuItem(hwnd, IDM_C64_256K_BASEDF80,   val==0xdf80);
+        return;
+#endif
 #endif
 #ifdef __X128__
     case IDM_C128TYPE:
