@@ -121,6 +121,33 @@
 #define IDM_REU8192      0x640
 #define IDM_REU16384     0x680
 
+#define IDM_GEORAM       0x16b
+#define IDM_GEORAMSIZE   0x16c
+#define IDM_GEORAM64     0x901
+#define IDM_GEORAM128    0x902
+#define IDM_GEORAM256    0x904
+#define IDM_GEORAM512    0x908
+#define IDM_GEORAM1024   0x910
+#define IDM_GEORAM2048   0x920
+#define IDM_GEORAM4096   0x940
+
+#define IDM_RAMCART      0x16e
+#define IDM_RAMCARTSIZE  0x16f
+#define IDM_RAMCART64    0x941
+#define IDM_RAMCART128   0x942
+
+#define IDM_PLUS60K      0x17c
+#define IDM_PLUS60KBASE  0x17d
+#define IDM_PLUS60KD040  0x17e
+#define IDM_PLUS60KD100  0x17f
+
+#define IDM_C64_256K          0x16d
+#define IDM_C64_256K_BASE	0x16e
+#define IDM_C64_256K_BASEDE00	0x18c
+#define IDM_C64_256K_BASEDE80	0x18d
+#define IDM_C64_256K_BASEDF00	0x18e
+#define IDM_C64_256K_BASEDF80	0x18f
+
 #define IDM_TFE          0x158
 
 #define IDM_MOUSE        0x151
