@@ -2,7 +2,7 @@
  * c64c128ui.h - UI aspects shared by C64 and C128.
  *
  * Written by
- *  Andreas Dehmel <dehmel@forwiss.tu-muenchen.de>
+ *  Andreas Dehmel <zarquon@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -28,5 +28,6 @@
 #define _C64C128UI_H
 
 extern void c64c128_ui_init_keyboard(const char *filename);
+extern void c64c128_ui_cartridge_callbacks(void);
 
 #endif
