@@ -219,6 +219,10 @@ static help_icon_t Help_ConfigSystem[] = {
   {Icon_ConfSys_Kernal, "\\HelpConfSysKernal|M\\HelpConfSystemPath"},
   {Icon_ConfSys_Basic, "\\HelpConfSysBasic|M\\HelpConfSystemPath"},
   {Icon_ConfSys_REU, "\\HelpConfSysREU"},
+  {Icon_ConfSys_GEORAM, "\\HelpConfSysGEORAM"},
+  {Icon_ConfSys_RAMCART, "\\HelpConfSysRAMCART"},
+  {Icon_ConfSys_PLUS60K, "\\HelpConfSysPLUS60K"},
+  {Icon_ConfSys_C64_256K, "\\HelpConfSysC64_256K"},
   {Icon_ConfSys_IEEE488, "\\HelpConfSysIEEE"},
   {Icon_ConfSys_EmuID, "\\HelpConfSysID"},
   {Icon_ConfSys_NoTraps, "\\HelpConfSysTraps"},
