@@ -117,6 +117,10 @@ char *archdep_default_sysfile_pathlist(const char *emu_id)
 {
     static char *default_path;
 
+#ifdef MINIXVMD
+    static char *default_path_temp;
+#endif
+
     if (default_path == NULL) {
         const char *boot_path;
         const char *home_path;
@@ -126,6 +130,31 @@ char *archdep_default_sysfile_pathlist(const char *emu_id)
 
         /* First search in the `LIBDIR' then the $HOME/.vice/ dir (home_path)
            and then in the `boot_path'.  */
+
+#ifdef MINIXVMD
+        default_path_temp = util_concat(LIBDIR, "/", emu_id,
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   home_path, "/", VICEUSERDIR, "/", emu_id);
+
+        default_path = util_concat(default_path_temp,
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   boot_path, "/", emu_id,
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   LIBDIR, "/DRIVES",
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   home_path, "/", VICEUSERDIR, "/DRIVES",
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   boot_path, "/DRIVES",
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   LIBDIR, "/PRINTER",
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   home_path, "/", VICEUSERDIR, "/PRINTER",
+                                   ARCHDEP_FINDPATH_SEPARATOR_STRING,
+                                   boot_path, "/PRINTER",
+                                   NULL);
+        lib_free(default_path_temp);
+
+#else
         default_path = util_concat(LIBDIR, "/", emu_id,
                                    ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    home_path, "/", VICEUSERDIR, "/", emu_id,
@@ -144,6 +173,7 @@ char *archdep_default_sysfile_pathlist(const char *emu_id)
                                    ARCHDEP_FINDPATH_SEPARATOR_STRING,
                                    boot_path, "/PRINTER",
                                    NULL);
+#endif
     }
 
     return default_path;
