@@ -50,6 +50,8 @@
 #include "uiscreenshot.h"
 #include "uisettings.h"
 #include "uireu.h"
+#include "uigeoram.h"
+#include "uiramcart.h"
 #include "uiromset.h"
 #include "uirs232c64c128.h"
 #include "uisid.h"
@@ -235,6 +237,10 @@ static ui_menu_entry_t io_extensions_submenu[] = {
     { "--" },
     { N_("RAM Expansion Unit"),
       NULL, NULL, reu_submenu },
+    { N_("GEORAM Expansion Unit"),
+      NULL, NULL, georam_submenu },
+    { N_("RAM Expansion Cart"),
+      NULL, NULL, ramcart_submenu },
     { N_("IDE64 emulation"),
       NULL, NULL, ide64_submenu },
 #ifdef HAVE_TFE
@@ -311,9 +317,9 @@ static UI_CALLBACK(save_screenshot)
 }
 
 static ui_menu_entry_t screenshot_submenu[] = {
-    { N_("VIC II Screenshot"),
+    { N_("VIC II Save media file"),
       (ui_callback_t)save_screenshot, (ui_callback_data_t)1, NULL },
-    { N_("VDC Screenshot"),
+    { N_("VDC Save media file"),
       (ui_callback_t)save_screenshot, (ui_callback_data_t)0, NULL },
     { NULL }
 };
