@@ -37,16 +37,20 @@
 #include "machine-video.h"
 #include "resources.h"
 #include "uiattach.h"
+#include "uic64_256k.h"
 #include "uic64cart.h"
 #include "uicommands.h"
 #include "uidatasette.h"
 #include "uidrive.h"
 #include "uidrivec64vic20.h"
+#include "uigeoram.h"
 #include "uiide64.h"
 #include "uijoystick2.h"
 #include "uikeyboard.h"
 #include "uimenu.h"
 #include "uiperipheraliec.h"
+#include "uiplus60k.h"
+#include "uiramcart.h"
 #include "uireu.h"
 #include "uiromset.h"
 #include "uirs232c64c128.h"
@@ -263,6 +267,14 @@ UI_MENU_DEFINE_TOGGLE(Mouse)
 static ui_menu_entry_t io_extensions_submenu[] = {
     { N_("RAM Expansion Unit"),
       NULL, NULL, reu_submenu },
+    { N_("GEORAM Expansion Unit"),
+      NULL, NULL, georam_submenu },
+    { N_("RAM Expansion Cart"),
+      NULL, NULL, ramcart_submenu },
+    { N_("+60K RAM Expansion Hack"),
+      NULL, NULL, plus60k_submenu },
+    { N_("256K RAM Expansion Hack"),
+      NULL, NULL, c64_256k_submenu },
     { N_("IDE64 emulation"),
       NULL, NULL, ide64_submenu },
 #ifdef HAVE_TFE
@@ -331,7 +343,7 @@ static UI_CALLBACK(save_screenshot)
 }
 
 static ui_menu_entry_t ui_screenshot_commands_menu[] = {
-    { N_("Screenshot..."),
+    { N_("Save media file"),
       (ui_callback_t)save_screenshot, (ui_callback_data_t)0, NULL },
     { NULL }
 };
