@@ -48,6 +48,7 @@
 #include "uicommands.h"
 #include "uimenu.h"
 #include "uisnapshot.h"
+#include "uinetplay.h"
 #include "uidrive.h"
 #include "util.h"
 #include "vsync.h"
@@ -463,6 +464,11 @@ ui_menu_entry_t ui_snapshot_commands_submenu[] = {
     { "--" },
     { N_("Recording start mode"),
       NULL, NULL, set_event_start_mode_submenu },
+    { "--" },
+#ifdef HAVE_NETWORK
+    { N_("Netplay (experimental)"),
+      NULL, NULL, netplay_submenu },
+#endif
     { NULL }
 };
 
