@@ -25,9 +25,11 @@
  *
  */
 
-#ifndef _UIGLIPLIST_H
+#ifndef _UIFLIPLIST_H
 #define _UIFLIPLIST_H
 
+#include "uimenu.h"
+
 extern struct ui_menu_entry_s fliplist_submenu[];
 
 extern void uifliplist_update_menus(int from_unit, int to_unit);
