@@ -32,6 +32,7 @@
 #include "lib.h"
 #include "printer.h"
 #include "resources.h"
+#include "uilib.h"
 #include "uimenu.h"
 #include "util.h"
 #include "vsync.h"
@@ -143,31 +144,9 @@ UI_CALLBACK(set_printer_dump_file)
 
 UI_CALLBACK(uiprinter_set_printer_exec_file)
 {
-    char *resname = (char *)UI_MENU_CB_PARAM;
-    char *title;
-    char *value;
-    char *new_value;
-    int len;
-    ui_button_t button;
-
-    vsync_suspend_speed_eval();
-    title = lib_stralloc(_("Command to execute for printing (preceed with '|')"));
-
-    resources_get_value(resname, (void *)&value);
-    len = strlen(value) * 2;
-    if (len < 255)
-        len = 255;
-
-    new_value = lib_malloc(len + 1);
-    strcpy(new_value, value);
-
-    button = ui_input_string(title, _("Command:"), new_value, len);
-    lib_free(title);
-
-    if (button == UI_BUTTON_OK)
-        resources_set_value(resname, (resource_value_t)new_value);
-
-    lib_free(new_value);
+    uilib_select_string((char *)UI_MENU_CB_PARAM,
+                        _("Command to execute for printing (preceed with '|')"),
+                        _("Command:"));
 }
 
 /* ------------------------------------------------------------------------- */
