@@ -237,7 +237,7 @@ void dga2_mode_callback(void *callback)
     mode_callback = callback;
 }
 
-void dga2_menu_create(struct ui_menu_entry_s menu[])
+void dga2_menu_create(struct ui_menu_entry_s *menu)
 {
     unsigned int i;
     ui_menu_entry_t *resolutions_submenu;
@@ -261,9 +261,9 @@ void dga2_menu_create(struct ui_menu_entry_s menu[])
     }
 }
 
-void dga2_menu_shutdown(struct ui_menu_entry_s menu[])
+void dga2_menu_shutdown(struct ui_menu_entry_s *menu)
 {
-    unsigned int i, amodes;
+    unsigned int i;
     ui_menu_entry_t *resolutions_submenu = NULL;
 
     if (fs_bestmode_counter == 0)
