@@ -93,6 +93,13 @@ int _video_use_xsync;
 /* Flag: Do we try to use the MIT shared memory extensions?  */
 static int try_mitshm;
 
+static unsigned int fourcc = 0;
+static char *fourcc_s = NULL;
+
+static double aspect_ratio;
+static char *aspect_ratio_s = NULL;
+
+
 static int set_use_xsync(resource_value_t v, void *param)
 {
     _video_use_xsync = (int)v;
@@ -105,22 +112,20 @@ static int set_try_mitshm(resource_value_t v, void *param)
     return 0;
 }
 
-static unsigned int fourcc;
 static int set_fourcc(resource_value_t v, void *param)
 {
-    if (v && strlen((char *)v) == 4) {
-        memcpy(&fourcc, (char *)v, 4);
-    }
-    else {
+    if (util_string_set(&fourcc_s, (const char *)v))
+        return 0;
+
+    if (fourcc_s != NULL && strlen(fourcc_s) == 4) {
+        memcpy(&fourcc, fourcc_s, 4);
+    } else {
         fourcc = 0;
     }
     
     return 0;
 }
 
-static double aspect_ratio;
-static char *aspect_ratio_s = NULL;
-
 static int set_aspect_ratio(resource_value_t v, void *param)
 {
     if (v) {
@@ -155,7 +160,7 @@ static const resource_t resources[] = {
       (void *)&try_mitshm, set_try_mitshm, NULL },
 #ifdef HAVE_XVIDEO
     { "FOURCC", RES_STRING, (resource_value_t)"",
-      (void *)&fourcc, set_fourcc, NULL },
+      (void *)&fourcc_s, set_fourcc, NULL },
     { "AspectRatio", RES_STRING, (resource_value_t)"1.0",
       (void *)&aspect_ratio_s, set_aspect_ratio, NULL },
 #endif
@@ -170,6 +175,7 @@ int video_arch_resources_init(void)
 void video_arch_resources_shutdown(void)
 {
     lib_free(aspect_ratio_s);
+    lib_free(fourcc_s);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -204,7 +210,11 @@ int video_init_cmdline_options(void)
 
 /* ------------------------------------------------------------------------- */
 
+#if !defined(__NETBSD__)
 static GC _video_gc;
+#else
+GC _video_gc;
+#endif
 static void (*_refresh_func)();
 
 /* This is set to 1 if the Shared Memory Extensions can actually be used. */
@@ -318,7 +328,11 @@ static void video_arch_frame_buffer_free(video_canvas_t *canvas)
 
 #ifdef HAVE_XVIDEO
     if (canvas->xv_image) {
+#ifdef __QNX__
+        XShmSegmentInfo* shminfo = NULL;
+#else
         XShmSegmentInfo* shminfo = use_mitshm ? &canvas->xshm_info : NULL;
+#endif
 
         display = x11ui_get_display_ptr();
 	destroy_yuv_image(display, canvas->xv_image, shminfo);
@@ -593,7 +607,11 @@ void video_canvas_refresh(video_canvas_t *canvas,
         int doublesize = canvas->videoconfig->doublesizex
           && canvas->videoconfig->doublesizey;
 
+#ifdef __QNX__
+        XShmSegmentInfo* shminfo = NULL;
+#else
         XShmSegmentInfo* shminfo = use_mitshm ? &canvas->xshm_info : NULL;
+#endif
         Window root;
         int x, y;
         unsigned int dest_w, dest_h, border_width, depth;
