@@ -50,7 +50,7 @@ int vm_is_enabled = 0;
 int vm_is_suspended = 0;
 
 static log_t vidmode_log = LOG_ERR;
-unsigned int vm_mode_count;
+int vm_mode_count;
 static unsigned int vm_index = 0;
 static int vm_available = 0;
 static int saved_h, saved_w;
@@ -63,7 +63,8 @@ extern int screen;
 
 int vidmode_init(void)
 {
-    unsigned int hz, i;
+    unsigned int hz;
+    int i;
     Display *display;
 
     vidmode_log = log_open("VidMode");
@@ -74,7 +75,11 @@ int vidmode_init(void)
         &vm_modes)) {
         log_error(vidmode_log, _("Error getting video mode information - disabling vidmode extension."));
         vm_available = 0;
+#if !defined(__NETBSD__)
         return -1;
+#else
+        return 0;
+#endif
     }
 
     for (i = 0; i < vm_mode_count; i++) {
@@ -255,7 +260,7 @@ void vidmode_mode_callback(void *callback)
     mode_callback = callback;
 }
 
-void vidmode_menu_create(struct ui_menu_entry_s menu[])
+void vidmode_menu_create(struct ui_menu_entry_s *menu)
 {
     unsigned int i, amodes;
     ui_menu_entry_t *resolutions_submenu;
@@ -281,7 +286,7 @@ void vidmode_menu_create(struct ui_menu_entry_s menu[])
     }
 }
 
-void vidmode_menu_shutdown(struct ui_menu_entry_s menu[])
+void vidmode_menu_shutdown(struct ui_menu_entry_s *menu)
 {
     unsigned int i, amodes;
     ui_menu_entry_t *resolutions_submenu = NULL;
