@@ -83,7 +83,11 @@ int video_arch_frame_buffer_alloc(video_canvas_t *canvas, unsigned int width,
         && (canvas->videoconfig->rendermode == VIDEO_RENDER_PAL_1X1
             || canvas->videoconfig->rendermode == VIDEO_RENDER_PAL_2X2))
     {
+#ifdef __QNX__
+        XShmSegmentInfo* shminfo = NULL;
+#else
         XShmSegmentInfo* shminfo = use_mitshm ? &canvas->xshm_info : NULL;
+#endif
 
         if (!find_yuv_port(display, &canvas->xv_port, &canvas->xv_format))
             return -1;
