@@ -33,6 +33,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <windows.h>
+#include <winsock.h>
 #include <tlhelp32.h>
 #include <tchar.h>
 
@@ -82,6 +83,18 @@
 static char *orig_workdir;
 static char *argv0;
 
+static void archdep_network_init(void)
+{
+    WORD wVersionRequested = MAKEWORD(1, 1);
+    WSADATA wsaData;
+
+    WSAStartup(wVersionRequested, &wsaData);
+}
+
+static void archdep_network_shutdown(void)
+{
+    WSACleanup();
+}
 
 int archdep_init(int *argc, char **argv)
 {
@@ -94,6 +107,8 @@ int archdep_init(int *argc, char **argv)
 
     orig_workdir = getcwd(NULL, MAX_PATH);
 
+    archdep_network_init();
+
     return 0;
 }
 
@@ -161,16 +176,18 @@ static BOOL verify_exe(char *file_name)
 {
 DWORD	version_info_size;
 BOOL	bResult = FALSE;
-char	*product_name = NULL;
-int 	product_name_length = 0;
+char	*company_name = NULL;
+int 	company_name_length = 0;
 
-    if (version_info_size = GetFileVersionInfoSize(file_name, NULL)) {
+    version_info_size = GetFileVersionInfoSize(file_name, NULL);
+
+    if (version_info_size) {
         BYTE *version_info_buffer = lib_malloc(version_info_size);
 
         if (GetFileVersionInfo(file_name, (DWORD)NULL, version_info_size, (VOID*)version_info_buffer)) {
-            if (VerQueryValue(version_info_buffer, "\\StringFileInfo\\04090000\\ProductName", &product_name, &product_name_length)) {
-                if (product_name) {
-                    if (strncmp("Vice Emulator", product_name, product_name_length) == 0) {
+            if (VerQueryValue(version_info_buffer, "\\StringFileInfo\\04090000\\CompanyName", &company_name, &company_name_length)) {
+                if (company_name) {
+                    if (strncmp("Vice Team", company_name, company_name_length) == 0) {
                         bResult = TRUE;
                     }
                 }
@@ -584,8 +601,14 @@ int archdep_file_is_chardev(const char *name)
 
 void archdep_shutdown(void)
 {
+    archdep_network_shutdown();
+
     lib_free(boot_path);
     lib_free(argv0);
     lib_free(orig_workdir);
 }
 
+void archdep_workaround_nop(const char *otto)
+{
+}
+
