@@ -34,6 +34,7 @@
 
 #include "c128ui.h"
 #include "res.h"
+#include "translate.h"
 #include "ui.h"
 #include "uiacia.h"
 #include "uic128.h"
@@ -42,6 +43,8 @@
 #include "uiide64.h"
 #include "uikeyboard.h"
 #include "uireu.h"
+#include "uigeoram.h"
+#include "uiramcart.h"
 #include "uirom.h"
 #include "uirs232user.h"
 #include "uisid.h"
@@ -185,12 +188,18 @@ static void c128_ui_specific(WPARAM wparam, HWND hwnd)
       case IDM_REU_SETTINGS:
         ui_reu_settings_dialog(hwnd);
         break;
+      case IDM_GEORAM_SETTINGS:
+        ui_georam_settings_dialog(hwnd);
+        break;
+      case IDM_RAMCART_SETTINGS:
+        ui_ramcart_settings_dialog(hwnd);
+        break;
       case IDM_IDE64_SETTINGS:
         uiide64_settings_dialog(hwnd);
         break;
       case IDM_ROM_SETTINGS:
-        uirom_settings_dialog(hwnd, IDD_C128ROM_SETTINGS_DIALOG,
-                              IDD_C128DRIVEROM_SETTINGS_DIALOG,
+        uirom_settings_dialog(hwnd, translate_res(IDD_C128ROM_SETTINGS_DIALOG),
+                              translate_res(IDD_C128DRIVEROM_SETTINGS_DIALOG),
                               romset_dialog_resources, uirom_settings);
         break;
 #ifdef HAVE_TFE
