@@ -3,9 +3,13 @@
 
 #define UNSTABLE
 
+#pragma warning(disable:4996)
+
 #define HAVE_ALLOCA             1
 #define RETSIGTYPE              void
 #define HAVE_RESID              1
+#define HAVE_PNG                1
+#define HAVE_ZLIB               1
 #define HAS_JOYSTICK            1
 #define HAVE_MOUSE              1
 #define HAVE_CATWEASELMKIII     1
@@ -39,6 +43,8 @@
 #define HAVE_FFMPEG             1
 #define HAVE_OPENCBM            1
 #define HAVE_CRTDBG             1
+#define HAS_TRANSLATION         1
+#define HAVE_NETWORK            1
 
 #define __i386__                1
 
@@ -51,6 +57,9 @@
 #define MSVC_RC                 1
 
 #define strcasecmp(s1, s2)      _stricmp(s1, s2)
+#define HAVE_STRCASECMP         1
+
+#define snprintf _snprintf
 
 /* Temporary kludge.  */
 #define PATH_MAX                256
