@@ -32,6 +32,7 @@
 
 #include "petui.h"
 #include "res.h"
+#include "translate.h"
 #include "ui.h"
 #include "uiacia.h"
 #include "uidrivepetcbm2.h"
@@ -124,8 +125,8 @@ static void pet_ui_specific(WPARAM wparam, HWND hwnd)
         ui_pet_settings_dialog(hwnd);
         break;
       case IDM_ROM_SETTINGS:
-        uirom_settings_dialog(hwnd, IDD_PETROM_SETTINGS_DIALOG,
-                              IDD_PETDRIVEROM_SETTINGS_DIALOG,
+        uirom_settings_dialog(hwnd, translate_res(IDD_PETROM_SETTINGS_DIALOG),
+                              translate_res(IDD_PETDRIVEROM_SETTINGS_DIALOG),
                               romset_dialog_resources, uirom_settings);
         break;
       case IDM_VIDEO_SETTINGS:
