@@ -55,9 +55,11 @@
 #include "mem.h"
 #include "monitor.h"
 #include "mousedrv.h"
+#include "network.h"
 #include "res.h"
 #include "resources.h"
 #include "system.h"
+#include "translate.h"
 #include "types.h"
 #include "ui.h"
 #include "uiattach.h"
@@ -70,6 +72,7 @@
 #include "uijoystick.h"
 #include "uilib.h"
 #include "uimediafile.h"
+#include "uinetwork.h"
 #include "uiquicksnapshot.h"
 #include "uiram.h"
 #include "uirs232.h"
@@ -84,11 +87,15 @@
 #include "statusbar.h"
 
 
+extern char *intl_speed_at_text;
+
+#define countof(array) (sizeof(array) / sizeof((array)[0]))
+
 static TCHAR *hwnd_titles[2];
 
 /* Exposure handler.  */
 HWND window_handles[2];
-int number_of_windows;
+int number_of_windows = 0;
 int window_canvas_xsize[2];
 int window_canvas_ysize[2];
 
@@ -119,6 +126,7 @@ static const ui_menu_toggle_t toggle_list[] = {
     { "SaveResourcesOnExit", IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT },
     { "ConfirmOnExit", IDM_TOGGLE_CONFIRM_ON_EXIT },
     { "FullScreenEnabled", IDM_TOGGLE_FULLSCREEN },
+    { "AlwaysOnTop", IDM_TOGGLE_ALWAYSONTOP },
 #ifdef DEBUG
     { "MainCPU_TRACE", IDM_TOGGLE_MAINCPU_TRACE },
     { "MainCPU_TRACE", IDM_TOGGLE_MAINCPU_TRACE|0x00010000 },
@@ -193,6 +201,20 @@ static const ui_res_value_list_t value_list[] = {
     { NULL, NULL, 0 }
 };
 
+static const struct {
+    char *lang_code;
+    UINT item_id;
+} ui_lang_menu_entries [] = {
+    { "en", IDM_LANG_EN },
+    { "de", IDM_LANG_DE },
+    { "fr", IDM_LANG_FR },
+    { "it", IDM_LANG_IT },
+    { "nl", IDM_LANG_NL },
+    { "pl", IDM_LANG_PL },
+    { "sv", IDM_LANG_SV },
+    { NULL, 0}
+};
+
 /* ------------------------------------------------------------------------ */
 #ifdef DEBUG
 #define UI_DEBUG_HOTKEYS                                                \
@@ -272,47 +294,48 @@ static HBRUSH tape_motor_off_brush;
 */
 static HWND main_hwnd;
 
+static int emu_menu;
+
 /* Initialize the UI before setting all the resource values.  */
 int ui_init(int *argc, char **argv)
 {
     WNDCLASS window_class;
-    WORD menu;
 
     switch (machine_class) {
       case VICE_MACHINE_C64:
-        menu = IDR_MENUC64;
+        emu_menu = IDR_MENUC64;
         ui_accelerator = CreateAcceleratorTable(c64_accel, 
             sizeof(c64_accel) / sizeof(ACCEL));
         break;
       case VICE_MACHINE_C128:
-        menu = IDR_MENUC128;
+        emu_menu = IDR_MENUC128;
         ui_accelerator = CreateAcceleratorTable(c128_accel, 
             sizeof(c128_accel) / sizeof(ACCEL));
         break;
       case VICE_MACHINE_VIC20:
-        menu = IDR_MENUVIC;
+        emu_menu = IDR_MENUVIC;
         ui_accelerator = CreateAcceleratorTable(vic_accel,
             sizeof(vic_accel)/ sizeof(ACCEL));
         break;
       case VICE_MACHINE_PET:
-        menu = IDR_MENUPET;
+        emu_menu = IDR_MENUPET;
         ui_accelerator = CreateAcceleratorTable(pet_accel,
             sizeof(pet_accel) / sizeof(ACCEL));
         break;
       case VICE_MACHINE_PLUS4:
-        menu = IDR_MENUPLUS4;
+        emu_menu = IDR_MENUPLUS4;
         ui_accelerator = CreateAcceleratorTable(plus4_accel,
             sizeof(plus4_accel) / sizeof(ACCEL));
         break;
       case VICE_MACHINE_CBM2:
-        menu = IDR_MENUCBM2;
+        emu_menu = IDR_MENUCBM2;
         ui_accelerator = CreateAcceleratorTable(cbm2_accel,
             sizeof(cbm2_accel) / sizeof(ACCEL));
         break;
       default:
         log_debug("UI: No menu entries for this machine defined!");
         log_debug("UI: Using C64 type UI menues.");
-        menu = IDR_MENUC64;
+        emu_menu = IDR_MENUC64;
         ui_accelerator = CreateAcceleratorTable(c64_accel,
             sizeof(c64_accel) / sizeof(ACCEL));
     }
@@ -327,7 +350,7 @@ int ui_init(int *argc, char **argv)
                                   MAKEINTRESOURCE(IDI_ICON1));
     window_class.hCursor = LoadCursor(NULL, IDC_ARROW);
     window_class.hbrBackground = (HBRUSH)CreateSolidBrush(RGB(0, 0, 0) + 1);
-    window_class.lpszMenuName = MAKEINTRESOURCE(menu);
+    window_class.lpszMenuName = MAKEINTRESOURCE(emu_menu);
     window_class.lpszClassName = APPLICATION_CLASS;
     RegisterClass(&window_class);
 
@@ -377,7 +400,6 @@ int ui_init(int *argc, char **argv)
 
 void ui_shutdown(void)
 {
-
 }
 
 /* Initialize the UI after setting all the resource values.  */
@@ -415,6 +437,7 @@ HWND ui_open_canvas_window(const char *title, unsigned int width,
 {
     HWND hwnd;
     int xpos, ypos;
+    HMENU menu;
 
     resources_get_sprintf("Window%dXpos", &xpos, number_of_windows);
     resources_get_sprintf("Window%dYpos", &ypos, number_of_windows);
@@ -448,12 +471,24 @@ HWND ui_open_canvas_window(const char *title, unsigned int width,
 
     ui_resize_canvas_window(hwnd, width, height);
 
+    menu=LoadMenu(winmain_instance, MAKEINTRESOURCE(translate_res(emu_menu)));
+    SetMenu(hwnd,menu);
     ShowWindow(hwnd, winmain_cmd_show);
-
     return hwnd;
 
 }
 
+void ui_update_menu()
+{
+HMENU menu;
+int   i;
+
+    menu = LoadMenu(winmain_instance, MAKEINTRESOURCE(translate_res(emu_menu)));
+    for (i = 0; i < number_of_windows; i++) {
+        SetMenu(window_handles[i], menu);
+    }
+}
+
 /* Resize `w' so that the client rectangle is of the requested size.  */
 void ui_resize_canvas_window(HWND w, unsigned int width, unsigned int height)
 {
@@ -504,6 +539,15 @@ void ui_resize_canvas_window(HWND w, unsigned int width, unsigned int height)
     }
 }
 
+void ui_set_alwaysontop(int alwaysontop)
+{
+    int i;
+
+    for (i = 0; i < number_of_windows; i++)
+        SetWindowPos(window_handles[i], alwaysontop ? HWND_TOPMOST : HWND_NOTOPMOST,
+                        0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
+}
+
 /* Update all the menus according to the current settings.  */
 void ui_update_menus(void)
 {
@@ -528,6 +572,7 @@ static void update_menus(HWND hwnd)
     int i, j;
     int value;
     int result;
+    char *lang;
 
     for (i = 0; grayed_list[i].name != NULL; i++) {
         resources_get_value(grayed_list[i].name, (void *)&value);
@@ -594,6 +639,28 @@ static void update_menus(HWND hwnd)
     CheckMenuItem(menu, IDM_PAUSE,
                   ui_emulation_is_paused() ? MF_CHECKED : MF_UNCHECKED);
 
+    resources_get_value("Language", (void *)&lang);
+    for (i = 0; (ui_lang_menu_entries[i].lang_code != NULL) && (i < countof(ui_lang_menu_entries)); i++) {
+        if (strcmp(lang, ui_lang_menu_entries[i].lang_code) == 0) {
+            CheckMenuItem(menu, ui_lang_menu_entries[i].item_id, MF_CHECKED);
+        } else {
+            CheckMenuItem(menu, ui_lang_menu_entries[i].item_id, MF_UNCHECKED);
+        }
+    }
+
+}
+
+static void ui_set_language(int lang_id)
+{
+    int i;
+
+    for (i = 0; (ui_lang_menu_entries[i].lang_code != NULL)
+        && (i < countof(ui_lang_menu_entries)); i++) {
+        if (ui_lang_menu_entries[i].item_id == lang_id) {
+            resources_set_value("Language", ui_lang_menu_entries[i].lang_code);
+            break;
+        }
+    }
 }
 
 /* ------------------------------------------------------------------------- */
@@ -620,7 +687,7 @@ void ui_error(const char *format, ...)
 
     log_debug(tmp);
     st = system_mbstowcs_alloc(tmp);
-    ui_messagebox(st, TEXT("VICE Error!"), MB_OK | MB_ICONSTOP);
+    ui_messagebox(st, translate_text(IDS_VICE_ERROR), MB_OK | MB_ICONSTOP);
     system_mbstowcs_free(st);
     vsync_suspend_speed_eval();
     lib_free(tmp);
@@ -633,7 +700,7 @@ void ui_error_string(const char *text)
 
     log_debug(text);
     st = system_mbstowcs_alloc(text);
-    ui_messagebox(st, TEXT("VICE Error!"), MB_OK | MB_ICONSTOP);
+    ui_messagebox(st, translate_text(IDS_VICE_ERROR), MB_OK | MB_ICONSTOP);
     system_mbstowcs_free(st);
 }
 
@@ -649,7 +716,7 @@ void ui_message(const char *format, ...)
     va_end(args);
 
     st = system_mbstowcs_alloc(tmp);
-    ui_messagebox(st, TEXT("VICE Information"), MB_OK | MB_ICONASTERISK);
+    ui_messagebox(st, translate_text(IDS_VICE_INFORMATION), MB_OK | MB_ICONASTERISK);
     system_mbstowcs_free(st);
     vsync_suspend_speed_eval();
     lib_free(tmp);
@@ -665,9 +732,9 @@ ui_jam_action_t ui_jam_dialog(const char *format,...)
     va_list ap;
     va_start(ap, format);
     txt = lib_mvsprintf(format, ap);
-    txt2 = lib_msprintf("%s\n\nStart monitor?", txt);
+    txt2 = lib_msprintf(translate_text(IDS_START_MONITOR), txt);
     st = system_mbstowcs_alloc(txt2);
-    ret = ui_messagebox(st, TEXT("VICE CPU JAM"), MB_YESNO);
+    ret = ui_messagebox(st, translate_text(IDS_VICE_CPU_JAM), MB_YESNO);
     system_mbstowcs_free(st);
     lib_free(txt2);
     lib_free(txt);
@@ -681,8 +748,8 @@ int ui_extend_image_dialog(void)
 {
     int ret;
 
-    ret = ui_messagebox(TEXT("Extend image to 40-track format?"),
-                        TEXT("VICE question"), MB_YESNO | MB_ICONQUESTION);
+    ret = ui_messagebox(translate_text(IDS_EXTEND_TO_40_TRACKS),
+                        translate_text(IDS_VICE_QUESTION), MB_YESNO | MB_ICONQUESTION);
     return ret == IDYES;
 }
 
@@ -702,6 +769,9 @@ static void pause_trap(WORD addr, void *data)
 
 void ui_pause_emulation(void)
 {
+    if (network_connected())
+        return;
+
     is_paused = is_paused ? 0 : 1;
     if (is_paused) {
         interrupt_maincpu_trigger_trap(pause_trap, 0);
@@ -716,7 +786,7 @@ int ui_emulation_is_paused(void)
 }
 
 /* ------------------------------------------------------------------------- */
-/* Dispay the current emulation speed.  */
+/* Display the current emulation speed.  */
 static int statustext_display_time = 0;
 
 void ui_display_speed(float percent, float framerate, int warp_flag)
@@ -728,7 +798,7 @@ void ui_display_speed(float percent, float framerate, int warp_flag)
     for (index = 0; index < number_of_windows; index++) {
         title = system_wcstombs_alloc(hwnd_titles[index]);
 
-        buf = lib_msprintf("%s at %d%% speed, %d fps%s",
+        buf = lib_msprintf(intl_speed_at_text,
                            title, (int)(percent + .5),
                            (int)(framerate + .5),
                            warp_flag ? " (warp)" : "");
@@ -743,15 +813,18 @@ void ui_display_speed(float percent, float framerate, int warp_flag)
     if (statustext_display_time > 0) {
         statustext_display_time--;
         if (statustext_display_time == 0)
-            ui_display_statustext("");
+            statusbar_setstatustext("");
     }
 }
 
 
-void ui_display_statustext(const char *text)
+void ui_display_statustext(const char *text, int fade_out)
 {
     statusbar_setstatustext(text);
-    statustext_display_time = 5;
+    if (fade_out > 0)
+        statustext_display_time = 5;
+    else
+        statustext_display_time = 0;
 }
 
 
@@ -786,17 +859,17 @@ void ui_display_drive_current_image(unsigned int drivenum, const char *image)
     char device_str[4];
 
     if (image == NULL || image[0] == 0) {
-        text = util_concat("Detached device ", 
-                           itoa(drivenum + 8, device_str, 10), NULL);
+        text = lib_msprintf(translate_text(IDS_DETACHED_DEVICE_S), 
+                           itoa(drivenum + 8, device_str, 10));
     } else {
-       	util_fname_split(image, &directory_name, &image_name);
-        text = util_concat("Attached ", image_name, " to device#", 
-            itoa(drivenum+8, device_str, 10), NULL);
+        util_fname_split(image, &directory_name, &image_name);
+        text = lib_msprintf(translate_text(IDS_ATTACHED_S_TO_DEVICE_S), image_name,
+            itoa(drivenum+8, device_str, 10));
         lib_free(image_name);
         lib_free(directory_name);
     }
 
-    ui_display_statustext(text);
+    ui_display_statustext(text, 1);
     lib_free(text);
 }
 
@@ -829,15 +902,15 @@ void ui_display_tape_current_image(const char *image)
     char *directory_name, *image_name, *text;
 
     if (image == NULL || image[0] == 0) {
-        text = lib_stralloc("Detached tape");
+        text = lib_stralloc(translate_text(IDS_DETACHED_TAPE));
     } else {
-       	util_fname_split(image, &directory_name, &image_name);
-        text = util_concat("Attached tape ", image_name, NULL);
+        util_fname_split(image, &directory_name, &image_name);
+        text = lib_msprintf(translate_text(IDS_ATTACHED_TAPE_S), image_name);
         lib_free(image_name);
         lib_free(directory_name);
     }
 
-    ui_display_statustext(text);
+    ui_display_statustext(text, 1);
     lib_free(text);
 }
 
@@ -858,10 +931,10 @@ void ui_display_playback(int playback_status, char *version)
     if (playback_status) {
         statusbar_event_status(EVENT_PLAYBACK);
         if (version == NULL || version[0] == 0)
-            sprintf(st, "History recorded with unknown release");
+            sprintf(st, translate_text(IDS_HISTORY_RECORDED_UNKNOWN));
         else 
-            sprintf(st, "History recorded with VICE-%s", version);
-        ui_display_statustext(st);
+            sprintf(st, translate_text(IDS_HISTORY_RECORDED_VICE_S), version);
+        ui_display_statustext(st, 1);
     } else {
         statusbar_event_status(EVENT_OFF);
     }
@@ -896,7 +969,7 @@ void ui_display_paused(int flag)
 
     for (index = 0; index < number_of_windows; index++) {
         title = system_wcstombs_alloc(hwnd_titles[index]);
-        buf = lib_msprintf("%s (%s)", title, flag ? "paused" : "resumed");
+        buf = lib_msprintf("%s (%s)", title, flag ? translate_text(IDS_PAUSED) : translate_text(IDS_RESUMED));
         system_wcstombs_free(title);
         st_buf = system_mbstowcs_alloc(buf);
         SetWindowText(window_handles[index], st_buf);
@@ -1167,21 +1240,21 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
         break;
       case IDM_SETTINGS_SAVE:
         if (resources_save(NULL) < 0)
-            ui_error("Cannot save settings.");
+            ui_error(translate_text(IDS_CANNOT_SAVE_SETTINGS));
         else
-            ui_message("Settings saved successfully.");
+            ui_message(translate_text(IDS_SETTINGS_SAVED_SUCCESS));
         uifliplist_save_settings();
         break;
       case IDM_SETTINGS_LOAD:
         if (resources_load(NULL) < 0) {
-            ui_error("Cannot load settings.");
+            ui_error(translate_text(IDS_CANNOT_LOAD_SETTINGS));
         } else {
-            ui_message("Settings loaded successfully.");
+            ui_message(translate_text(IDS_SETTINGS_LOADED_SUCCESS));
         }
         break;
       case IDM_SETTINGS_DEFAULT:
         resources_set_defaults();
-        ui_message("Default settings restored.");
+        ui_message(translate_text(IDS_DEFAULT_SETTINGS_RESTORED));
         break;
       case IDM_EVENT_DIRECTORY:
       case IDM_EVENT_TOGGLE_RECORD:
@@ -1192,9 +1265,21 @@ static void handle_wm_command(WPARAM wparam, LPARAM lparam, HWND hwnd)
       case IDM_EVENT_RESETMILESTONE | 0x00010000:
         uievent_command(hwnd, wparam);
         break;
+      case IDM_NETWORK_SETTINGS:
+        ui_network_dialog(hwnd);
+        break;
       case IDM_RS232_SETTINGS:
         ui_rs232_settings_dialog(hwnd);
         break;
+      case IDM_LANG_EN:
+      case IDM_LANG_DE:
+      case IDM_LANG_FR:
+      case IDM_LANG_IT:
+      case IDM_LANG_NL:
+      case IDM_LANG_PL:
+      case IDM_LANG_SV:
+        ui_set_language(wparam);
+        break;
       default:
         handle_default_command(wparam, lparam, hwnd);
     }
@@ -1266,8 +1351,7 @@ static void ui_wm_close(HWND window)
     if (confirm_on_exit) {
 //      log_debug("Asking exit confirmation");
         if (MessageBox(window,
-            TEXT("Do you really want to exit?\n\n"
-            "All the data present in the emulated RAM will be lost."),
+            translate_text(IDS_REALLY_EXIT),
             TEXT("VICE"), MB_YESNO | MB_ICONQUESTION | MB_DEFBUTTON2
             | MB_TASKMODAL) == IDYES) {
             quit = 1;
@@ -1280,7 +1364,7 @@ static void ui_wm_close(HWND window)
         SuspendFullscreenMode(window);
         if (save_on_exit) {
             if (resources_save(NULL)<0) {
-                ui_error("Cannot save settings.");
+                ui_error(translate_text(IDS_CANNOT_SAVE_SETTINGS));
             }
         }
         DestroyWindow(window);
@@ -1298,11 +1382,11 @@ static void ui_wm_dropfiles(HWND window, WPARAM wparam)
     DragQueryFile(hDrop, 0, (char *)&szFile, 256);
     if (GetAsyncKeyState(VK_SHIFT) & 0x8000) {
         if (file_system_attach_disk(8, szFile) < 0)
-            ui_error("Cannot attach specified file");
+            ui_error(translate_text(IDS_CANNOT_ATTACH_FILE));
     } else {
         if (autostart_autodetect(szFile, NULL, 0,
             AUTOSTART_MODE_RUN) < 0)
-            ui_error("Cannot autostart specified file.");
+            ui_error(translate_text(IDS_CANNOT_AUTOSTART_FILE));
     }
     DragFinish(hDrop);
 }
@@ -1451,6 +1535,10 @@ static long CALLBACK window_proc(HWND window, UINT msg,
             } else
                 break;
         }
+      case WM_SYSCOMMAND:
+      case WM_NCLBUTTONDOWN:
+        vsync_suspend_speed_eval();
+        break;
     }
 
     return DefWindowProc(window, msg, wparam, lparam);
