@@ -40,6 +40,7 @@
 #include "res.h"
 #include "resources.h"
 #include "system.h"
+#include "translate.h"
 #include "uic128.h"
 #include "uilib.h"
 #include "winmain.h"
@@ -199,14 +200,14 @@ static BOOL CALLBACK functionrom_dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
             break;
           case IDC_C128_FUNCTIONROM_INTERNAL_BROWSE:
             uilib_select_browse(hwnd,
-                                TEXT("Select internal function ROM image"),
+                                translate_text(IDS_SELECT_INT_FUNCTION_ROM),
                                 UILIB_FILTER_ALL,
                                 UILIB_SELECTOR_TYPE_FILE_LOAD,
                                 IDC_C128_FUNCTIONROM_INTERNAL_NAME);
             break;
           case IDC_C128_FUNCTIONROM_EXTERNAL_BROWSE:
             uilib_select_browse(hwnd,
-                                TEXT("Select external function ROM image"),
+                                translate_text(IDS_SELECT_EXT_FUNCTION_ROM),
                                 UILIB_FILTER_ALL,
                                 UILIB_SELECTOR_TYPE_FILE_LOAD,
                                 IDC_C128_FUNCTIONROM_EXTERNAL_NAME);
@@ -241,11 +242,11 @@ void ui_c128_dialog(HWND hwnd)
     psp[0].dwFlags = PSP_USETITLE /*| PSP_HASHELP*/ ;
     psp[0].hInstance = winmain_instance;
 #ifdef _ANONYMOUS_UNION
-    psp[0].pszTemplate = MAKEINTRESOURCE(IDD_C128_MACHINE_SETTINGS_DIALOG);
+    psp[0].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_C128_MACHINE_SETTINGS_DIALOG));
     psp[0].pszIcon = NULL;
 #else
     psp[0].DUMMYUNIONNAME.pszTemplate
-        = MAKEINTRESOURCE(IDD_C128_MACHINE_SETTINGS_DIALOG);
+        = MAKEINTRESOURCE(translate_res(IDD_C128_MACHINE_SETTINGS_DIALOG));
     psp[0].u2.pszIcon = NULL;
 #endif
     psp[0].lParam = 0;
@@ -255,26 +256,26 @@ void ui_c128_dialog(HWND hwnd)
     psp[1].dwFlags = PSP_USETITLE /*| PSP_HASHELP*/ ;
     psp[1].hInstance = winmain_instance;
 #ifdef _ANONYMOUS_UNION
-    psp[1].pszTemplate = MAKEINTRESOURCE(IDD_C128_FUNCTIONROM_SETTINGS_DIALOG);
+    psp[1].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_C128_FUNCTIONROM_SETTINGS_DIALOG));
     psp[1].pszIcon = NULL;
 #else
     psp[1].DUMMYUNIONNAME.pszTemplate
-        = MAKEINTRESOURCE(IDD_C128_FUNCTIONROM_SETTINGS_DIALOG);
+        = MAKEINTRESOURCE(translate_res(IDD_C128_FUNCTIONROM_SETTINGS_DIALOG));
     psp[1].u2.pszIcon = NULL;
 #endif
     psp[1].lParam = 0;
     psp[1].pfnCallback = NULL;
 
     psp[0].pfnDlgProc = machine_dialog_proc;
-    psp[0].pszTitle = TEXT("Machine type");
+    psp[0].pszTitle = translate_text(IDS_MACHINE_TYPE);
     psp[1].pfnDlgProc = functionrom_dialog_proc;
-    psp[1].pszTitle = TEXT("Function ROM");
+    psp[1].pszTitle = translate_text(IDS_FUNCTION_ROM);
 
     psh.dwSize = sizeof(PROPSHEETHEADER);
     psh.dwFlags = PSH_PROPSHEETPAGE | PSH_NOAPPLYNOW;
     psh.hwndParent = hwnd;
     psh.hInstance = winmain_instance;
-    psh.pszCaption = TEXT("C128 settings");
+    psh.pszCaption = translate_text(IDS_C128_SETTINGS);
     psh.nPages = 2;
 #ifdef _ANONYMOUS_UNION
     psh.pszIcon = NULL;
