@@ -40,6 +40,7 @@
 #include "res.h"
 #include "resources.h"
 #include "system.h"
+#include "translate.h"
 #include "uidrivec64vic20.h"
 #include "uilib.h"
 #include "winmain.h"
@@ -430,11 +431,11 @@ void uidrivec64vic20_settings_dialog(HWND hwnd)
         psp[i].hInstance = winmain_instance;
 #ifdef _ANONYMOUS_UNION
         psp[i].pszTemplate
-            = MAKEINTRESOURCE(IDD_DRIVE_SETTINGS_DIALOG_C64VIC20);
+            = MAKEINTRESOURCE(translate_res(IDD_DRIVE_SETTINGS_DIALOG_C64VIC20));
         psp[i].pszIcon = NULL;
 #else
         psp[i].DUMMYUNIONNAME.pszTemplate
-            = MAKEINTRESOURCE(IDD_DRIVE_SETTINGS_DIALOG_C64VIC20);
+            = MAKEINTRESOURCE(translate_res(IDD_DRIVE_SETTINGS_DIALOG_C64VIC20));
         psp[i].u2.pszIcon = NULL;
 #endif
         psp[i].lParam = 0;
@@ -442,19 +443,19 @@ void uidrivec64vic20_settings_dialog(HWND hwnd)
     }
 
     psp[0].pfnDlgProc = callback_8;
-    psp[0].pszTitle = TEXT("Drive 8");
+    psp[0].pszTitle = translate_text(IDS_DRIVE_8);
     psp[1].pfnDlgProc = callback_9;
-    psp[1].pszTitle = TEXT("Drive 9");
+    psp[1].pszTitle = translate_text(IDS_DRIVE_9);
     psp[2].pfnDlgProc = callback_10;
-    psp[2].pszTitle = TEXT("Drive 10");
+    psp[2].pszTitle = translate_text(IDS_DRIVE_10);
     psp[3].pfnDlgProc = callback_11;
-    psp[3].pszTitle = TEXT("Drive 11");
+    psp[3].pszTitle = translate_text(IDS_DRIVE_11);
 
     psh.dwSize = sizeof(PROPSHEETHEADER);
     psh.dwFlags = PSH_PROPSHEETPAGE | PSH_NOAPPLYNOW;
     psh.hwndParent = hwnd;
     psh.hInstance = winmain_instance;
-    psh.pszCaption = TEXT("Drive Settings");
+    psh.pszCaption = translate_text(IDS_DRIVE_SETTINGS);
     psh.nPages = 4;
 #ifdef _ANONYMOUS_UNION
     psh.pszIcon = NULL;
