@@ -38,6 +38,7 @@
 #include "res.h"
 #include "resources.h"
 #include "system.h"
+#include "translate.h"
 #include "uidrivepetcbm2.h"
 #include "uilib.h"
 #include "winmain.h"
@@ -240,10 +241,10 @@ void uidrivepetcbm2_settings_dialog(HWND hwnd)
         psp[i].dwFlags = PSP_USETITLE /*| PSP_HASHELP*/ ;
         psp[i].hInstance = winmain_instance;
 #ifdef _ANONYMOUS_UNION
-        psp[i].pszTemplate = MAKEINTRESOURCE(IDD_DRIVE_SETTINGS_DIALOG_PETCBM2);
+        psp[i].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_DRIVE_SETTINGS_DIALOG_PETCBM2));
         psp[i].pszIcon = NULL;
 #else
-        psp[i].DUMMYUNIONNAME.pszTemplate = MAKEINTRESOURCE(IDD_DRIVE_SETTINGS_DIALOG_PETCBM2);
+        psp[i].DUMMYUNIONNAME.pszTemplate = MAKEINTRESOURCE(translate_res(IDD_DRIVE_SETTINGS_DIALOG_PETCBM2));
         psp[i].u2.pszIcon = NULL;
 #endif
         psp[i].lParam = 0;
@@ -251,15 +252,15 @@ void uidrivepetcbm2_settings_dialog(HWND hwnd)
     }
 
     psp[0].pfnDlgProc = callback_8;
-    psp[0].pszTitle = TEXT("Drive 8");
+    psp[0].pszTitle = translate_text(IDS_DRIVE_8);
     psp[1].pfnDlgProc = callback_9;
-    psp[1].pszTitle = TEXT("Drive 9");
+    psp[1].pszTitle = translate_text(IDS_DRIVE_9);
 
     psh.dwSize = sizeof(PROPSHEETHEADER);
     psh.dwFlags = PSH_PROPSHEETPAGE | PSH_NOAPPLYNOW;
     psh.hwndParent = hwnd;
     psh.hInstance = winmain_instance;
-    psh.pszCaption = TEXT("Drive Settings");
+    psh.pszCaption = translate_text(IDS_DRIVE_SETTINGS);
     psh.nPages = 2;
 #ifdef _ANONYMOUS_UNION
     psh.pszIcon = NULL;
