@@ -27,10 +27,12 @@
 #include <windows.h>
 #include <tchar.h>
 
+#include "joy.h"
 #include "res.h"
 #include "resources.h"
-#include "joy.h"
+#include "translate.h"
 #include "winmain.h"
+#include "intl.h"
 
 /*  These are in joystick.c . */
 extern void joystick_calibrate(HWND hwnd);
@@ -47,16 +49,16 @@ static int current_key_index;
 
 static int keyset[9];
 
-static TCHAR *keydefine_texts[] = {
-    TEXT("Press key for NorthWest"),
-    TEXT("Press key for North"),
-    TEXT("Press key for NorthEast"),
-    TEXT("Press key for East"),
-    TEXT("Press key for SouthEast"),
-    TEXT("Press key for South"),
-    TEXT("Press key for SouthWest"),
-    TEXT("Press key for West"),
-    TEXT("Press key for Fire")
+static int keydefine_texts[] = {
+    IDS_PRESS_KEY_NORTHWEST,
+    IDS_PRESS_KEY_NORTH,
+    IDS_PRESS_KEY_NORTHEAST,
+    IDS_PRESS_KEY_EAST,
+    IDS_PRESS_KEY_SOUTHEAST,
+    IDS_PRESS_KEY_SOUTH,
+    IDS_PRESS_KEY_SOUTHWEST,
+    IDS_PRESS_KEY_WEST,
+    IDS_PRESS_KEY_FIRE
 };
 
 static long CALLBACK real_callback(HWND hwnd, UINT msg, WPARAM wparam,
@@ -93,7 +95,7 @@ static BOOL CALLBACK key_dialog(HWND hwnd, UINT msg, WPARAM wparam,
 {
     switch (msg) {
       case WM_INITDIALOG:
-        SetWindowText(hwnd, keydefine_texts[current_key_index]);
+        SetWindowText(hwnd, translate_text(keydefine_texts[current_key_index]));
         SetWindowLong(hwnd, GWL_WNDPROC, (LONG)real_callback);
         return FALSE;
     }
@@ -113,7 +115,7 @@ static void init_keyset_dialog(HWND hwnd)
         resources_get_value("KeySet1SouthWest", (void *)&keyset[KEYSET_SW]);
         resources_get_value("KeySet1West", (void *)&keyset[KEYSET_W]);
         resources_get_value("KeySet1Fire", (void *)&keyset[KEYSET_FIRE]);
-        SetWindowText(hwnd, TEXT("Configure Keyset A"));
+        SetWindowText(hwnd, translate_text(IDS_CONFIGURE_KEYSET_A));
     } else {
         resources_get_value("KeySet2NorthWest", (void *)&keyset[KEYSET_NW]);
         resources_get_value("KeySet2North", (void *)&keyset[KEYSET_N]);
@@ -124,7 +126,7 @@ static void init_keyset_dialog(HWND hwnd)
         resources_get_value("KeySet2SouthWest", (void *)&keyset[KEYSET_SW]);
         resources_get_value("KeySet2West", (void *)&keyset[KEYSET_W]);
         resources_get_value("KeySet2Fire", (void *)&keyset[KEYSET_FIRE]);
-        SetWindowText(hwnd, TEXT("Configure Keyset B"));
+        SetWindowText(hwnd, translate_text(IDS_CONFIGURE_KEYSET_B));
     }
     SetDlgItemText(hwnd, IDC_KEY_NW,
                    kbd_code_to_string((kbd_code_t)keyset[KEYSET_NW]));
@@ -282,17 +284,17 @@ static void init_joystick_dialog(HWND hwnd)
     int device;
 
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_DEV1);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"None");
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"Numpad + RCtrl");
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"Keyset A");
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"Keyset B");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)intl_translate_text_new(IDS_NONE));
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NUMPAD_AND_RCTRL));
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_KEYSET_A));
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_KEYSET_B));
     joystick_ui_get_device_list(joy_hwnd);
     resources_get_value("JoyDevice1", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value,0);
     joy1 = device = res_value;
 
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE1_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"All buttons used as fire");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_ALL_BUTTONS_AS_FIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyFire1Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -300,12 +302,12 @@ static void init_joystick_dialog(HWND hwnd)
     resources_get_value("JoyAutofire1Speed", (void *)&res_value);
     SetDlgItemInt(hwnd, IDC_JOY_FIRE1_SPEED, res_value, FALSE);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE1_AXIS);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"numeric (see above)");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NUMERIC_SEE_ABOVE));
     joystick_ui_get_autofire_axes(joy_hwnd, device);
     resources_get_value("JoyAutofire1Axis", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_AUTOFIRE1_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"No button - Autofire disabled");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NO_BUTTON_NO_AUTOFIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyAutofire1Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -319,17 +321,17 @@ static void init_joystick_dialog(HWND hwnd)
                             (device >= JOYDEV_HW1));
 
     joy_hwnd = GetDlgItem(hwnd,IDC_JOY_DEV2);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"None");
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"Numpad + RCtrl");
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"Keyset A");
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"Keyset B");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)intl_translate_text_new(IDS_NONE));
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NUMPAD_AND_RCTRL));
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_KEYSET_A));
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_KEYSET_B));
     joystick_ui_get_device_list(joy_hwnd);
     resources_get_value("JoyDevice2", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value,0);
     joy2 = device = res_value;
 
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE2_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"All buttons used as fire");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_ALL_BUTTONS_AS_FIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyFire2Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -337,12 +339,12 @@ static void init_joystick_dialog(HWND hwnd)
     resources_get_value("JoyAutofire2Speed", (void *)&res_value);
     SetDlgItemInt(hwnd, IDC_JOY_FIRE2_SPEED, res_value, FALSE);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE2_AXIS);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"numeric (see above)");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NUMERIC_SEE_ABOVE));
     joystick_ui_get_autofire_axes(joy_hwnd, device);
     resources_get_value("JoyAutofire2Axis", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_AUTOFIRE2_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"No button - Autofire disabled");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NO_BUTTON_NO_AUTOFIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyAutofire2Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -365,7 +367,7 @@ int     res_value;
 
     SendDlgItemMessage(hwnd, IDC_JOY_FIRE1_AXIS, CB_RESETCONTENT, 0, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE1_AXIS);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"numeric (see above)");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NUMERIC_SEE_ABOVE));
     joystick_ui_get_autofire_axes(joy_hwnd, device);
     resources_get_value("JoyAutofire1Axis", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -378,7 +380,7 @@ int     res_value;
 
     SendDlgItemMessage(hwnd, IDC_JOY_FIRE2_AXIS, CB_RESETCONTENT, 0, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE2_AXIS);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"numeric (see above)");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NUMERIC_SEE_ABOVE));
     joystick_ui_get_autofire_axes(joy_hwnd, device);
     resources_get_value("JoyAutofire2Axis", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -391,14 +393,14 @@ int     res_value;
 
     SendDlgItemMessage(hwnd, IDC_JOY_FIRE1_BUTTON, CB_RESETCONTENT, 0, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE1_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"All buttons used as fire");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_ALL_BUTTONS_AS_FIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyFire1Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
 
     SendDlgItemMessage(hwnd, IDC_JOY_AUTOFIRE1_BUTTON, CB_RESETCONTENT, 0, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_AUTOFIRE1_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"No button - Autofire disabled");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NO_BUTTON_NO_AUTOFIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyAutofire1Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -411,14 +413,14 @@ int     res_value;
 
     SendDlgItemMessage(hwnd, IDC_JOY_FIRE2_BUTTON, CB_RESETCONTENT, 0, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_FIRE2_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"All buttons used as fire");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_ALL_BUTTONS_AS_FIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyFire2Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
 
     SendDlgItemMessage(hwnd, IDC_JOY_AUTOFIRE2_BUTTON, CB_RESETCONTENT, 0, 0);
     joy_hwnd = GetDlgItem(hwnd, IDC_JOY_AUTOFIRE2_BUTTON);
-    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)"No button - Autofire disabled");
+    SendMessage(joy_hwnd, CB_ADDSTRING, 0, (LPARAM)translate_text(IDS_NO_BUTTON_NO_AUTOFIRE));
     joystick_ui_get_autofire_buttons(joy_hwnd, device);
     resources_get_value("JoyAutofire2Button", (void *)&res_value);
     SendMessage(joy_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
@@ -443,12 +445,12 @@ static BOOL CALLBACK dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
             return TRUE;
           case IDC_JOY_CONFIG_A:
             current_keyset_index = 0;
-            DialogBox(winmain_instance, (LPCTSTR)IDD_CONFIG_KEYSET_DIALOG,
+            DialogBox(winmain_instance, (LPCTSTR)translate_res(IDD_CONFIG_KEYSET_DIALOG),
                       hwnd, keyset_dialog);
             return TRUE;
           case IDC_JOY_CONFIG_B:
             current_keyset_index = 1;
-            DialogBox(winmain_instance, (LPCTSTR)IDD_CONFIG_KEYSET_DIALOG,
+            DialogBox(winmain_instance, (LPCTSTR)translate_res(IDD_CONFIG_KEYSET_DIALOG),
                       hwnd, keyset_dialog);
             return TRUE;
           case IDC_JOY_DEV1:
@@ -579,7 +581,7 @@ static BOOL CALLBACK dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
 
 void ui_joystick_settings_dialog(HWND hwnd)
 {
-    DialogBox(winmain_instance, (LPCTSTR)IDD_JOY_SETTINGS_DIALOG,
+    DialogBox(winmain_instance, (LPCTSTR)translate_res(IDD_JOY_SETTINGS_DIALOG),
               hwnd,dialog_proc);
 }
 
@@ -609,6 +611,11 @@ void ui_joystick_swap_joystick(void)
     resources_set_value("JoyAutofire1Button",(resource_value_t)device2);
     resources_set_value("JoyAutofire2Button",(resource_value_t)device1);
 
+/* swapping the keyset definitions when swapping the joysticks is
+   improper bahaviour in my opinion, if needed a swap keyset can be
+   made later, for now the keyset swapping is commented out. */
+
+#if 0
     resources_get_value("KeySet1NorthWest",(void *)&device1);
     resources_get_value("KeySet2NorthWest",(void *)&device2);
     resources_set_value("KeySet1NorthWest",(resource_value_t)device2);
@@ -645,4 +652,5 @@ void ui_joystick_swap_joystick(void)
     resources_get_value("KeySet2Fire",(void *)&device2);
     resources_set_value("KeySet1Fire",(resource_value_t)device2);
     resources_set_value("KeySet2Fire",(resource_value_t)device1);
+#endif
 }
