@@ -48,12 +48,14 @@
 #include "res.h"
 #include "resources.h"
 #include "system.h"
+#include "translate.h"
 #include "ui.h"
 #include "uilib.h"
 #include "util.h"
 #include "vdrive-internal.h"
 #include "vsync.h"
 #include "winmain.h"
+#include "intl.h"
 
 
 /* Mingw & pre VC 6 headers doesn't have this definition */
@@ -68,28 +70,25 @@ static int font_loaded;
 static char *res_readonly;
 
 struct uilib_filefilter_s {
-    TCHAR *name;
+    int name;
     TCHAR *pattern;
 };
 typedef struct uilib_filefilter_s uilib_filefilter_t;
 
 static uilib_filefilter_t uilib_filefilter[] = {
-    { TEXT("All files (*.*)"), TEXT("*.*") },
-    { TEXT("VICE palette files (*.vpl)"), TEXT("*.vpl") },
-    { TEXT("VICE snapshot files (*.vsf)"), TEXT("*.vsf") },
-    { TEXT("Disk image files (*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64)"),
-      TEXT("*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64") },
-    { TEXT("Tape image files (*.t64;*.p00;*.tap;*.prg)"),
-      TEXT("*.t64;*.p00;*.tap;*.prg") },
-    { TEXT("Zipped files (*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z)"),
-      TEXT("*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z") },
-    { TEXT("CRT cartridge image files (*.crt)"), TEXT("*.crt") },
-    { TEXT("Raw cartridge image files (*.bin)"), TEXT("*.bin") },
-    { TEXT("VICE flip list files (*.vfl)"), TEXT("*.vfl") },
-    { TEXT("VICE romset files (*.vrs)"), TEXT("*.vrs") },
-    { TEXT("VICE romset archives (*.vra)"), TEXT("*.vra") },
-    { TEXT("VICE keymap files (*.vkm)"), TEXT("*.vkm") },
-    { NULL, NULL }
+    { IDS_ALL_FILES_FILTER, TEXT("*.*") },
+    { IDS_PALETTE_FILES_FILTER, TEXT("*.vpl") },
+    { IDS_SNAPSHOT_FILES_FILTER, TEXT("*.vsf") },
+    { IDS_DISK_IMAGE_FILES_FILTER, TEXT("*.d64;*.d71;*.d80;*.d81;*.d82;*.g64;*.g41;*.x64") },
+    { IDS_TAPE_IMAGE_FILES_FILTER, TEXT("*.t64;*.p00;*.tap;*.prg") },
+    { IDS_ZIPPED_FILES_FILTER, TEXT("*.zip;*.bz2;*.gz;*.d6z;*.d7z;*.d8z;*.g6z;*.g4z;*.x6z") },
+    { IDS_CRT_FILES_FILTER, TEXT("*.crt") },
+    { IDS_RAW_CART_FILES_FILTER, TEXT("*.bin") },
+    { IDS_FLIP_LIST_FILES_FILTER, TEXT("*.vfl") },
+    { IDS_ROMSET_FILES_FILTER, TEXT("*.vrs") },
+    { IDS_ROMSET_ARCHIVES_FILTER, TEXT("*.vra") },
+    { IDS_KEYMAP_FILES_FILTER, TEXT("*.vkm") },
+    { 0, NULL }
 };
 
 struct uilib_fs_style_type_s {
@@ -203,7 +202,7 @@ static UINT APIENTRY uilib_select_tape_hook_proc(HWND hwnd, UINT uimsg,
     preview = GetDlgItem(hwnd, IDC_PREVIEW);
     switch (uimsg) {
       case WM_INITDIALOG:
-        SetWindowText(GetDlgItem(GetParent(hwnd), IDOK), TEXT("&Attach"));
+        SetWindowText(GetDlgItem(GetParent(hwnd), IDOK), translate_text(IDS_ATTACH));
 
         if (font_loaded)
             hfont = CreateFont(-12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
@@ -242,7 +241,7 @@ static UINT APIENTRY uilib_select_tape_hook_proc(HWND hwnd, UINT uimsg,
           case IDC_BLANK_IMAGE:
             if (SendMessage(GetParent(hwnd),
                 CDM_GETSPEC, 256, (LPARAM)filename) <= 1) {
-                ui_error("Please enter a filename.");
+                ui_error(translate_text(IDS_PLEASE_ENTER_A_FILENAME));
                 return -1;
             }
             if (strchr(filename,'.') == NULL) {
@@ -264,14 +263,14 @@ static UINT APIENTRY uilib_select_tape_hook_proc(HWND hwnd, UINT uimsg,
                 }
                 if (util_file_exists(filename)) {
                     int ret;
-                    ret = ui_messagebox(TEXT("Overwrite existing image?"),
-                                        TEXT("VICE question"),
+                    ret = ui_messagebox(translate_text(IDS_OVERWRITE_EXISTING_IMAGE),
+                                        translate_text(IDS_VICE_QUESTION),
                                         MB_YESNO | MB_ICONQUESTION);
                     if (ret != IDYES)
                         return -1;
                 }
                 if (cbmimage_create_image(filename, DISK_IMAGE_TYPE_TAP)) {
-                    ui_error("Cannot create image");
+                    ui_error(translate_text(IDS_CANNOT_CREATE_IMAGE));
                     return -1;
                 }
             }
@@ -337,7 +336,7 @@ static UINT APIENTRY uilib_select_hook_proc(HWND hwnd, UINT uimsg,
     preview = GetDlgItem(hwnd, IDC_PREVIEW);
     switch (uimsg) {
       case WM_INITDIALOG:
-        SetWindowText(GetDlgItem(GetParent(hwnd), IDOK), "&Attach");
+        SetWindowText(GetDlgItem(GetParent(hwnd), IDOK), translate_text(IDS_ATTACH));
         image_type_list = GetDlgItem(hwnd, IDC_BLANK_IMAGE_TYPE);
         for (counter = 0; image_type_name[counter]; counter++) {
             SendMessage(image_type_list, CB_ADDSTRING, 0,
@@ -402,7 +401,7 @@ static UINT APIENTRY uilib_select_hook_proc(HWND hwnd, UINT uimsg,
           case IDC_BLANK_IMAGE:
             if (SendMessage(GetParent(hwnd),
                 CDM_GETSPEC, 256, (LPARAM)st_filename) <= 1) {
-                ui_error("Please enter a filename.");
+                ui_error(translate_text(IDS_PLEASE_ENTER_A_FILENAME));
                 return -1;
             }
             if (_tcschr(st_filename, '.') == NULL) {
@@ -437,8 +436,8 @@ static UINT APIENTRY uilib_select_hook_proc(HWND hwnd, UINT uimsg,
                 system_wcstombs(filename, st_filename, 256);
                 if (util_file_exists(st_filename)) {
                     int ret;
-                    ret = ui_messagebox(TEXT("Overwrite existing image?"),
-                                        TEXT("VICE question"),
+                    ret = ui_messagebox(translate_text(IDS_OVERWRITE_EXISTING_IMAGE),
+                                        translate_text(IDS_VICE_QUESTION),
                                         MB_YESNO | MB_ICONQUESTION);
                     if (ret != IDYES)
                         return -1;
@@ -448,7 +447,7 @@ static UINT APIENTRY uilib_select_hook_proc(HWND hwnd, UINT uimsg,
                 format_name = lib_msprintf("%s,%s", disk_name, disk_id);
                 if (vdrive_internal_create_format_disk_image(st_filename,
                     format_name, image_type[counter]) < 0) {
-                    ui_error("Cannot create image");
+                    ui_error(translate_text(IDS_CANNOT_CREATE_IMAGE));
                     lib_free(format_name);
                     return -1;
                 }
@@ -547,7 +546,7 @@ static void update_filter_history(DWORD current_filter)
 {
     int i;
     DWORD b;
-    for (i = 0, b = 1; uilib_filefilter[i].name != NULL; i++, b <<= 1) {
+    for (i = 0, b = 1; uilib_filefilter[i].name != 0; i++, b <<= 1) {
         if ((b & last_filterlist) 
             && (get_index_from_filterbit(b, last_filterlist)
             == current_filter)) {
@@ -574,10 +573,10 @@ static TCHAR *set_filter(DWORD filterlist, DWORD *filterindex)
     *filterindex = 0;
 
     /* create the strings for the file filters */
-    for (i = 0, b = 1; uilib_filefilter[i].name != NULL; i++, b <<= 1) {
+    for (i = 0, b = 1; uilib_filefilter[i].name != 0; i++, b <<= 1) {
         if (filterlist & b) {
-            j = _tcslen(uilib_filefilter[i].name) + 1;
-            memcpy(current, uilib_filefilter[i].name, j * sizeof(TCHAR));
+            j = _tcslen(translate_text(uilib_filefilter[i].name)) + 1;
+            memcpy(current, translate_text(uilib_filefilter[i].name), j * sizeof(TCHAR));
             current += j;
 
             j = _tcslen(uilib_filefilter[i].pattern) + 1;
@@ -677,7 +676,7 @@ TCHAR *uilib_select_file_autostart(HWND hwnd, const TCHAR *title,
     if (styles[style].TemplateID != 0) {
         ofn.Flags |= OFN_ENABLEHOOK | OFN_ENABLETEMPLATE;
         ofn.lpfnHook = styles[style].hook_proc;
-        ofn.lpTemplateName = MAKEINTRESOURCE(styles[style].TemplateID);
+        ofn.lpTemplateName = MAKEINTRESOURCE(translate_res(styles[style].TemplateID));
     } else {
         ofn.lpfnHook = NULL;
         ofn.lpTemplateName = NULL;
@@ -807,7 +806,7 @@ void ui_show_text(HWND hWnd,
 // of the executable that created the current process.
 // Win32: module handle == instance handle == task [Win3.1 legacy]
 
-                   MAKEINTRESOURCE(IDD_TEXTDLG),
+                   MAKEINTRESOURCE(translate_res(IDD_TEXTDLG)),
                    hWnd,
                    TextDlgProc,
                    (LPARAM)&info);
@@ -892,8 +891,8 @@ void uilib_show_options(HWND param)
     char *options;
 
     options = cmdline_options_string();
-    ui_show_text(param, "Command line options",
-                 "Which command line options are available?", options);
+    ui_show_text(param, translate_text(IDS_COMMAND_LINE_OPTIONS),
+                 translate_text(IDS_COMMAND_OPTIONS_AVAIL), options);
     lib_free(options);
 }
 
@@ -946,3 +945,155 @@ void uilib_dialogbox(uilib_dialogbox_param_t *param)
 
 }
 
+void uilib_get_general_window_extents(HWND hwnd, int *xsize, int *ysize)
+{
+    HDC hdc;
+    HFONT hFont;
+    HFONT hOldFont;
+    int strlen;
+    char *buffer;
+    SIZE  size;
+
+    hFont = (HFONT)SendMessage(hwnd, WM_GETFONT, 0, 0);
+    strlen = SendMessage(hwnd, WM_GETTEXTLENGTH, 0, 0);
+    buffer = malloc(strlen + 1);
+    GetWindowText(hwnd, buffer, strlen + 1);
+
+    hdc = GetDC(hwnd);
+    hOldFont = (HFONT)SelectObject(hdc, hFont);
+
+    GetTextExtentPoint32(hdc, buffer, strlen, &size);
+
+    free(buffer);
+
+    SelectObject(hdc, hOldFont);
+    ReleaseDC(hwnd, hdc);
+
+    *xsize = size.cx;
+    *ysize = size.cy;
+}
+
+void uilib_get_group_extent(HWND hwnd, uilib_dialog_group *group, int *xsize, int *ysize)
+{
+HWND element;
+int x;
+int y;
+
+    if (xsize && ysize) {
+        *xsize = 0;
+        *ysize = 0;
+        while (group->idc) {
+            element = GetDlgItem(hwnd, group->idc);
+            uilib_get_general_window_extents(element, &x, &y);
+            if (group->element_type == 1) x += 20;
+            if (*xsize < x) *xsize = x;
+            *ysize += y;
+            group++;
+        }
+    }
+}
+
+void uilib_move_and_adjust_group_width(HWND hwnd, uilib_dialog_group *group, int xpos)
+{
+HWND element;
+RECT element_rect;
+int xsize;
+int ysize;
+
+    while (group->idc) {
+        element = GetDlgItem(hwnd, group->idc);
+        GetClientRect(element, &element_rect);
+        MapWindowPoints(element, hwnd, (POINT*)&element_rect, 2);
+        uilib_get_general_window_extents(element, &xsize, &ysize);
+        if (group->element_type == 1) xsize += 20;
+        MoveWindow(element, xpos, element_rect.top, xsize, element_rect.bottom - element_rect.top, TRUE);
+        group++;
+    }
+}
+
+void uilib_move_group(HWND hwnd, uilib_dialog_group *group, int xpos)
+{
+HWND element;
+RECT element_rect;
+
+    while (group->idc) {
+        element = GetDlgItem(hwnd, group->idc);
+        GetClientRect(element, &element_rect);
+        MapWindowPoints(element, hwnd, (POINT*)&element_rect, 2);
+        MoveWindow(element, xpos, element_rect.top, element_rect.right - element_rect.left, element_rect.bottom - element_rect.top, TRUE);
+        group++;
+    }
+}
+
+void uilib_adjust_group_width(HWND hwnd, uilib_dialog_group *group)
+{
+HWND element;
+RECT element_rect;
+int xsize;
+int ysize;
+
+    while (group->idc) {
+        element = GetDlgItem(hwnd, group->idc);
+        GetClientRect(element, &element_rect);
+        MapWindowPoints(element, hwnd, (POINT*)&element_rect, 2);
+        uilib_get_general_window_extents(element, &xsize, &ysize);
+        if (group->element_type == 1) xsize += 20;
+        MoveWindow(element, element_rect.left, element_rect.top, xsize, element_rect.bottom - element_rect.top, TRUE);
+        group++;
+    }
+}
+
+void uilib_move_and_adjust_element_width(HWND hwnd, int idc, int xpos)
+{
+HWND element;
+RECT element_rect;
+int xsize;
+int ysize;
+
+    element = GetDlgItem(hwnd, idc);
+    GetClientRect(element, &element_rect);
+    MapWindowPoints(element, hwnd, (POINT*)&element_rect, 2);
+    uilib_get_general_window_extents(element, &xsize, &ysize);
+    MoveWindow(element, xpos, element_rect.top, xsize, element_rect.bottom - element_rect.top, TRUE);
+}
+
+void uilib_adjust_element_width(HWND hwnd, int idc)
+{
+HWND element;
+RECT element_rect;
+int xsize;
+int ysize;
+
+    element = GetDlgItem(hwnd, idc);
+    GetClientRect(element, &element_rect);
+    MapWindowPoints(element, hwnd, (POINT*)&element_rect, 2);
+    uilib_get_general_window_extents(element, &xsize, &ysize);
+    MoveWindow(element, element_rect.left, element_rect.top, xsize, element_rect.bottom - element_rect.top, TRUE);
+}
+
+void uilib_set_element_width(HWND hwnd, int idc, int xsize)
+{
+HWND element;
+RECT element_rect;
+
+    element = GetDlgItem(hwnd, idc);
+    GetClientRect(element, &element_rect);
+    MapWindowPoints(element, hwnd, (POINT*)&element_rect, 2);
+    MoveWindow(element, element_rect.left, element_rect.top, xsize, element_rect.bottom - element_rect.top, TRUE);
+}
+
+void uilib_localize_dialog(HWND hwnd, uilib_localize_dialog_param *param)
+{
+HWND element;
+
+    while (param->idc || param->ids) {
+        if (param->element_type == -1) {
+            SetWindowText(hwnd, intl_translate_text_new(param->ids));
+        } else if (param->element_type == 0) {
+            element = GetDlgItem(hwnd, param->idc);
+            SetWindowText(element, intl_translate_text_new(param->ids));
+        }
+        param++;
+    }
+}
+
