@@ -34,6 +34,7 @@
 #include "res.h"
 #include "resources.h"
 #include "system.h"
+#include "translate.h"
 #include "uiram.h"
 #include "winmain.h"
 
@@ -178,7 +179,7 @@ static BOOL CALLBACK dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
 
 void ui_ram_settings_dialog(HWND hwnd)
 {
-    DialogBox(winmain_instance, MAKEINTRESOURCE(IDD_RAM_SETTINGS_DIALOG), hwnd,
+    DialogBox(winmain_instance, MAKEINTRESOURCE(translate_res(IDD_RAM_SETTINGS_DIALOG)), hwnd,
               dialog_proc);
 }
 
