@@ -27,15 +27,26 @@
 #ifndef _UIROM_H
 #define _UIROM_H
 
+#include <tchar.h>
+
+#define UIROM_TYPE_MAIN  0
+#define UIROM_TYPE_DRIVE 1
+#define UIROM_TYPE_OTHER 2
+#define UIROM_TYPE_MAX   3
+
 struct uirom_settings_s {
-    const char *realname;
+    unsigned int type;
+    const TCHAR *realname;
     const char *resname;
     unsigned int idc_filename;
     unsigned int idc_browse;
+    unsigned int idc_resource;
 };
 typedef struct uirom_settings_s uirom_settings_t;
 
-extern void uirom_settings_dialog(HWND hwnd, unsigned int idd_dialog,
+extern void uirom_settings_dialog(HWND hwnd, unsigned int idd_dialog_main,
+                                  unsigned int idd_dialog_drive,
+                                  const unsigned int *idd_dialog_resources,
                                   const uirom_settings_t *uirom_settings);
 
 #endif
