@@ -42,9 +42,12 @@
 #include "resources.h"
 #include "sid.h"
 #include "system.h"
+#include "translate.h"
 #include "ui.h"
 #include "uisid.h"
 #include "winmain.h"
+#include "uilib.h"
+#include "intl.h"
 
 
 static const TCHAR *ui_sid_engine[] = 
@@ -59,10 +62,10 @@ static const TCHAR *ui_sid_engine[] =
     NULL
 };
 
-static const TCHAR *ui_sid_samplemethod[] = 
+static const int ui_sid_samplemethod[] = 
 {
-    TEXT("fast"), TEXT("interpolating"), TEXT("resampling"),
-    TEXT("fast resampling"), NULL
+    IDS_FAST, IDS_INTERPOLATING, IDS_RESAMPLING,
+    IDS_FAST_RESAMPLING, 0
 };
 
 static const int ui_sid_c64baseaddress[] =
@@ -91,7 +94,7 @@ static void enable_resid_sid_controls(HWND hwnd)
     is_enabled = (engine == SID_ENGINE_RESID);
 
     EnableWindow(GetDlgItem(hwnd, IDC_SID_RESID_SAMPLING), is_enabled);
-    EnableWindow(GetDlgItem(hwnd, IDC_SID_RESID_PASSBAND), is_enabled);
+    EnableWindow(GetDlgItem(hwnd, IDC_SID_RESID_PASSBAND_VALUE), is_enabled);
 }
 
 static void enable_hardsid_sid_controls(HWND hwnd)
@@ -131,7 +134,7 @@ static void CreateAndGetSidAddress(HWND hwnd, int mode)
         hadr = ui_sid_cbm2baseaddress;
         break;
       default:
-        ui_error("This machine may not have a SID");
+        ui_error(intl_translate_text_new(IDS_THIS_MACHINE_NO_SID));
         return;
     }
 
@@ -160,6 +163,23 @@ static void init_general_sid_dialog(HWND hwnd)
     int res_value;
     int res_value_loop;
 
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_GENGROUP1);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_GENGROUP1));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_GENGROUP2);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_GENGROUP2));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_6581);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_6581));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_8580);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_8580));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_GENGROUP3);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_GENGROUP3));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_STEREO);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_STEREO_AT));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_FILTERS);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_FILTERS));
+
+//  Setup status
+
     resources_get_value("SidFilters", (void *)&res_value);
     CheckDlgButton(hwnd, IDC_SID_FILTERS, res_value
                    ? BST_CHECKED : BST_UNCHECKED);
@@ -186,6 +206,63 @@ static void init_general_sid_dialog(HWND hwnd)
     enable_general_sid_controls(hwnd);
 }
 
+static void resize_general_sid_dialog(HWND hwnd)
+{
+int xsize, ysize;
+HWND child_hwnd;
+RECT rect;
+RECT child_rect;
+int xpos;
+
+    GetClientRect(hwnd, &rect);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_GENGROUP1);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, rect.right - 2 * child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_6581);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, xsize + 20, child_rect.bottom - child_rect.top, TRUE);
+    xpos = child_rect.left + xsize + 20 + 10;
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_8580);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, xpos, child_rect.top, xsize + 20, child_rect.bottom - child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_GENGROUP2);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, rect.right - 2 * child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_STEREO);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, xsize + 20, child_rect.bottom - child_rect.top, TRUE);
+    xpos = child_rect.left + xsize + 20 + 10;
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_STEREOADDRESS);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, xpos, child_rect.top, child_rect.right - child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_GENGROUP3);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, rect.right - 2 * child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_FILTERS);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, xsize + 20, child_rect.bottom - child_rect.top, TRUE);
+}
+
 static void init_resid_sid_dialog(HWND hwnd)
 {
     HWND sid_hwnd;
@@ -193,28 +270,84 @@ static void init_resid_sid_dialog(HWND hwnd)
     int res_value_loop;
     TCHAR st[10];
 
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_GROUP);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_RESID_GROUP));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_SAMPLE);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_RESID_SAMPLE));
+    sid_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_PASSBAND);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_SID_RESID_PASSBAND));
+
     resources_get_value("SidResidSampling", (void *)&res_value);
     sid_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_SAMPLING);
     for (res_value_loop = 0; ui_sid_samplemethod[res_value_loop];
         res_value_loop++) {
         SendMessage(sid_hwnd, CB_ADDSTRING, 0,
-                    (LPARAM)ui_sid_samplemethod[res_value_loop]);
+                    (LPARAM)intl_translate_text_new(ui_sid_samplemethod[res_value_loop]));
     }
     SendMessage(sid_hwnd, CB_SETCURSEL, (WPARAM)res_value, 0);
 
     resources_get_value("SidResidPassband", (void *)&res_value);
     _stprintf(st, TEXT("%d"), res_value);
-    SetDlgItemText(hwnd, IDC_SID_RESID_PASSBAND, st);
+    SetDlgItemText(hwnd, IDC_SID_RESID_PASSBAND_VALUE, st);
 
     enable_resid_sid_controls(hwnd);
 }
 
+static void resize_resid_sid_dialog(HWND hwnd)
+{
+int xsize, ysize;
+HWND child_hwnd;
+RECT rect;
+RECT child_rect;
+int xpos;
+
+    GetClientRect(hwnd, &rect);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_GROUP);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, rect.right - 2 * child_rect.left, rect.bottom - 2 * child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_SAMPLE);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, xsize, child_rect.bottom - child_rect.top, TRUE);
+    xpos = child_rect.left + xsize + 10;
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_PASSBAND);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, xsize, child_rect.bottom - child_rect.top, TRUE);
+    if (xpos < child_rect.left + xsize + 10) {
+        xpos = child_rect.left + xsize + 10;
+    }
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_SAMPLING);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, xpos, child_rect.top, child_rect.right - child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_RESID_PASSBAND_VALUE);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, xpos, child_rect.top, child_rect.right - child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+}
+
 static void init_hardsid_sid_dialog(HWND hwnd)
 {
     HWND sid_hwnd;
     int res_value;
     unsigned int available, device;
 
+    sid_hwnd = GetDlgItem(hwnd, IDC_HARDSID_GROUP);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_HARDSID_GROUP));
+    sid_hwnd = GetDlgItem(hwnd, IDC_HARDSID_LEFT_LABEL);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_HARDSID_LEFT_LABEL));
+    sid_hwnd = GetDlgItem(hwnd, IDC_HARDSID_RIGHT_LABEL);
+    SetWindowText(sid_hwnd, intl_translate_text_new(IDS_HARDSID_RIGHT_LABEL));
+
     available = hardsid_available();
     device = 0;
 
@@ -250,6 +383,48 @@ static void init_hardsid_sid_dialog(HWND hwnd)
     enable_hardsid_sid_controls(hwnd);
 }
 
+static void resize_hardsid_sid_dialog(HWND hwnd)
+{
+int xsize, ysize;
+HWND child_hwnd;
+RECT rect;
+RECT child_rect;
+int xpos;
+
+    GetClientRect(hwnd, &rect);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_HARDSID_GROUP);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, rect.right - 2 * child_rect.left, rect.bottom - 2 * child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_HARDSID_LEFT_LABEL);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, xsize, child_rect.bottom - child_rect.top, TRUE);
+    xpos = child_rect.left + xsize + 10;
+
+    child_hwnd = GetDlgItem(hwnd, IDC_HARDSID_RIGHT_LABEL);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    uilib_get_general_window_extents(child_hwnd, &xsize, &ysize);
+    MoveWindow(child_hwnd, child_rect.left, child_rect.top, xsize, child_rect.bottom - child_rect.top, TRUE);
+    if (xpos < child_rect.left + xsize + 10) {
+        xpos = child_rect.left + xsize + 10;
+    }
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_HARDSID_LEFT_ENGINE);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, xpos, child_rect.top, child_rect.right - child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+
+    child_hwnd = GetDlgItem(hwnd, IDC_SID_HARDSID_RIGHT_ENGINE);
+    GetClientRect(child_hwnd, &child_rect);
+    MapWindowPoints(child_hwnd, hwnd, (POINT*)&child_rect, 2);
+    MoveWindow(child_hwnd, xpos, child_rect.top, child_rect.right - child_rect.left, child_rect.bottom - child_rect.top, TRUE);
+}
+
 static void end_general_dialog(HWND hwnd)
 {
     resources_set_value("SidFilters", (resource_value_t)
@@ -302,6 +477,9 @@ static BOOL CALLBACK general_dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
         system_init_dialog(hwnd);
         init_general_sid_dialog(hwnd);
         return TRUE;
+      case WM_SIZE:
+        resize_general_sid_dialog(hwnd);
+        break;
     }
     return FALSE;
 }
@@ -314,7 +492,7 @@ static void end_resid_dialog(HWND hwnd)
                         SendMessage(GetDlgItem(hwnd, IDC_SID_RESID_SAMPLING),
                         CB_GETCURSEL, 0, 0));
 
-    GetDlgItemText(hwnd, IDC_SID_RESID_PASSBAND, st, 4);
+    GetDlgItemText(hwnd, IDC_SID_RESID_PASSBAND_VALUE, st, 4);
     resources_set_value("SidResidPassband", (resource_value_t)_ttoi(st));
 }
 
@@ -339,6 +517,9 @@ static BOOL CALLBACK resid_dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
         system_init_dialog(hwnd);
         init_resid_sid_dialog(hwnd);
         return TRUE;
+      case WM_SIZE:
+        resize_resid_sid_dialog(hwnd);
+        break;
     }
     return FALSE;
 }
@@ -397,6 +578,9 @@ static BOOL CALLBACK hardsid_dialog_proc(HWND hwnd, UINT msg, WPARAM wparam,
         system_init_dialog(hwnd);
         init_hardsid_sid_dialog(hwnd);
         return TRUE;
+      case WM_SIZE:
+        resize_hardsid_sid_dialog(hwnd);
+        break;
     }
     return FALSE;
 }
@@ -438,18 +622,19 @@ void ui_sid_settings_dialog(HWND hwnd)
     psp[2].dwFlags = PSP_USETITLE /*| PSP_HASHELP*/ ;
     psp[2].hInstance = winmain_instance;
 #ifdef _ANONYMOUS_UNION
-    psp[2].pszTemplate = MAKEINTRESOURCE(IDD_SID_HARDSID_SETTINGS_DIALOG);
+    psp[2].pszTemplate = MAKEINTRESOURCE(translate_res(IDD_SID_HARDSID_SETTINGS_DIALOG));
     psp[2].pszIcon = NULL;
 #else
     psp[2].DUMMYUNIONNAME.pszTemplate
-        = MAKEINTRESOURCE(IDD_SID_HARDSID_SETTINGS_DIALOG);
+        = MAKEINTRESOURCE(translate_res(IDD_SID_HARDSID_SETTINGS_DIALOG));
     psp[2].u2.pszIcon = NULL;
 #endif
     psp[2].lParam = 0;
     psp[2].pfnCallback = NULL;
 
     psp[0].pfnDlgProc = general_dialog_proc;
-    psp[0].pszTitle = TEXT("General");
+//    psp[0].pszTitle = translate_text(IDS_GENERAL);
+    psp[0].pszTitle = intl_translate_text_new(IDS_GENERAL);
     psp[1].pfnDlgProc = resid_dialog_proc;
     psp[1].pszTitle = TEXT("ReSID");
     psp[2].pfnDlgProc = hardsid_dialog_proc;
@@ -459,7 +644,8 @@ void ui_sid_settings_dialog(HWND hwnd)
     psh.dwFlags = PSH_PROPSHEETPAGE | PSH_NOAPPLYNOW;
     psh.hwndParent = hwnd;
     psh.hInstance = winmain_instance;
-    psh.pszCaption = TEXT("SID settings");
+//    psh.pszCaption = translate_text(IDS_SID_SETTINGS);
+    psh.pszCaption = intl_translate_text_new(IDS_SID_SETTINGS);
     psh.nPages = 3;
 #ifdef _ANONYMOUS_UNION
     psh.pszIcon = NULL;
