@@ -40,9 +40,13 @@
 #include "lib.h"
 #include "log.h"
 #include "machine-drive.h"
+#include "network.h"
 #include "resources.h"
 #include "serial.h"
 #include "snapshot.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "ui.h"
 #include "vdrive-bam.h"
@@ -109,45 +113,87 @@ int file_system_resources_init(void)
 
 /* ------------------------------------------------------------------------- */
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-device8", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice8",
-      (void *)ATTACH_DEVICE_FS, "<type>",
-      "Set device type for device #8 (0: NONE, 1: FS, 2: REAL, 3: RAW)" },
+      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
+      IDCLS_SET_DEVICE_TYPE_8 },
     { "-device9", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice9",
-      (void *)ATTACH_DEVICE_FS, "<type>",
-      "Set device type for device #9 (0: NONE, 1: FS, 2: REAL, 3: RAW)" },
+      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
+      IDCLS_SET_DEVICE_TYPE_9 },
     { "-device10", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice10",
-      (void *)ATTACH_DEVICE_FS, "<type>",
-      "Set device type for device #10 (0: NONE, 1: FS, 2: REAL, 3: RAW)" },
+      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
+      IDCLS_SET_DEVICE_TYPE_10 },
     { "-device11", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice11",
-      (void *)ATTACH_DEVICE_FS, "<type>",
-      "Set device type for device #11 (0: NONE, 1: FS, 2: REAL, 3: RAW)" },
+      (void *)ATTACH_DEVICE_FS, IDCLS_P_TYPE,
+      IDCLS_SET_DEVICE_TYPE_11 },
     { "-attach8ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
       (resource_value_t)1,
-      NULL, "Attach disk image for drive #8 read only" },
+      0, IDCLS_ATTACH_READ_ONLY_8 },
     { "-attach8rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
       (resource_value_t)0,
-      NULL, "Attach disk image for drive #8 read write (if possible)" },
+      0, IDCLS_ATTACH_READ_WRITE_8 },
     { "-attach9ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
       (resource_value_t)1,
-      NULL, "Attach disk image for drive #9 read only" },
+      0, IDCLS_ATTACH_READ_ONLY_9 },
     { "-attach9rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
       (resource_value_t)0,
-      NULL, "Attach disk image for drive #9 read write (if possible)" },
+      0, IDCLS_ATTACH_READ_WRITE_9 },
     { "-attach10ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
       (resource_value_t)1,
-      NULL, "Attach disk image for drive #10 read only" },
+      0, IDCLS_ATTACH_READ_ONLY_10 },
     { "-attach10rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
       (resource_value_t)0,
-      NULL, "Attach disk image for drive #10 read write (if possible)" },
+      0, IDCLS_ATTACH_READ_WRITE_10 },
     { "-attach11ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
       (resource_value_t)1,
-      NULL, "Attach disk image for drive #11 read only" },
+      0, IDCLS_ATTACH_READ_ONLY_11 },
     { "-attach11rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
       (resource_value_t)0,
-      NULL, "Attach disk image for drive #11 read write (if possible)" },
+      0, IDCLS_ATTACH_READ_WRITE_11 },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-device8", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice8",
+      (void *)ATTACH_DEVICE_FS, N_("<type>"),
+      N_("Set device type for device #8 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
+    { "-device9", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice9",
+      (void *)ATTACH_DEVICE_FS, N_("<type>"),
+      N_("Set device type for device #9 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
+    { "-device10", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice10",
+      (void *)ATTACH_DEVICE_FS, N_("<type>"),
+      N_("Set device type for device #10 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
+    { "-device11", SET_RESOURCE, 1, NULL, NULL, "FileSystemDevice11",
+      (void *)ATTACH_DEVICE_FS, N_("<type>"),
+      N_("Set device type for device #11 (0: NONE, 1: FS, 2: REAL, 3: RAW)") },
+    { "-attach8ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
+      (resource_value_t)1,
+      NULL, N_("Attach disk image for drive #8 read only") },
+    { "-attach8rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice8Readonly",
+      (resource_value_t)0,
+      NULL, N_("Attach disk image for drive #8 read write (if possible)") },
+    { "-attach9ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
+      (resource_value_t)1,
+      NULL, N_("Attach disk image for drive #9 read only") },
+    { "-attach9rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice9Readonly",
+      (resource_value_t)0,
+      NULL, N_("Attach disk image for drive #9 read write (if possible)") },
+    { "-attach10ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
+      (resource_value_t)1,
+      NULL, N_("Attach disk image for drive #10 read only") },
+    { "-attach10rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice10Readonly",
+      (resource_value_t)0,
+      NULL, N_("Attach disk image for drive #10 read write (if possible)") },
+    { "-attach11ro", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
+      (resource_value_t)1,
+      NULL, N_("Attach disk image for drive #11 read only") },
+    { "-attach11rw", SET_RESOURCE, 0, NULL, NULL, "AttachDevice11Readonly",
+      (resource_value_t)0,
+      NULL, N_("Attach disk image for drive #11 read write (if possible)") },
+    { NULL }
+};
+#endif
 
 int file_system_cmdline_options_init(void)
 {
@@ -407,7 +453,7 @@ static void detach_disk_image_and_free(disk_image_t *image, vdrive_t *floppy,
     detach_disk_image(image, floppy, unit);
     
     if ((image != NULL) && (image == oldimg))
-        lib_free(image);
+        disk_image_destroy(image);
 }
 
 static int attach_disk_image(disk_image_t **imgptr, vdrive_t *floppy,
@@ -455,7 +501,7 @@ static int attach_disk_image(disk_image_t **imgptr, vdrive_t *floppy,
 
     detach_disk_image_and_free(*imgptr, floppy, unit);
 
-    *imgptr = (disk_image_t *)lib_malloc(sizeof(disk_image_t));
+    *imgptr = disk_image_create();
     image = *imgptr;
 
     memcpy(image, &new_image, sizeof(disk_image_t));
@@ -485,7 +531,7 @@ static int attach_disk_image(disk_image_t **imgptr, vdrive_t *floppy,
     if (err) {
         disk_image_close(image);
         disk_image_media_destroy(image);
-        lib_free(image);
+        disk_image_destroy(image);
         *imgptr = NULL;
     }
     return err;
@@ -521,6 +567,11 @@ int file_system_attach_disk(unsigned int unit, const char *filename)
    if (event_playback_active())
         return -1;
 
+    if (network_connected()) {
+        network_attach_image(unit, filename);
+        return 0;
+    }
+
    return file_system_attach_disk_internal(unit, filename);
 }
 
@@ -561,9 +612,19 @@ static void file_system_detach_disk_internal(int unit)
 
 void file_system_detach_disk(int unit)
 {
-   if (event_playback_active())
+    char event_data[2];
+
+    if (event_playback_active())
         return;
 
+    event_data[0] = (char)unit;
+    event_data[1] = 0;
+
+    if (network_connected()) {
+        network_event_record(EVENT_ATTACHDISK, (void *)event_data, 2);
+        return;
+    }
+
    file_system_detach_disk_internal(unit);
 }
 
