@@ -4,7 +4,7 @@
  * Written by
  *  Teemu Rantanen <tvr@cs.hut.fi>
  *  Ettore Perazzoli <ettore@comm2000.it>
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -36,6 +36,7 @@
 
 extern int autostart_init(CLOCK _min_cycles, int _handle_drive_true_emulation,
                           int _blnsw, int _pnt, int _pntr, int _lnmx);
+extern void autostart_shutdown(void);
 
 extern int autostart_autodetect(const char *file_name,
                                 const char *program_name,
@@ -53,5 +54,7 @@ extern void autostart_advance(void);
 extern int autostart_device(int num);
 extern void autostart_reset(void);
 
-#endif /* !_AUTOSTART_H */
+extern int autostart_ignore_reset;
+
+#endif
 
