@@ -32,6 +32,7 @@
 #include <string.h>
 
 #include "c64-resources.h"
+#include "c64_256k.h"
 #include "c64cart.h"
 #include "c64cia.h"
 #include "c64io.h"
@@ -46,7 +47,9 @@
 #include "maincpu.h"
 #include "mem.h"
 #include "monitor.h"
+#include "plus60k.h"
 #include "ram.h"
+#include "ramcart.h"
 #include "reu.h"
 #include "sid.h"
 #include "vicii-mem.h"
@@ -172,7 +175,10 @@ BYTE REGPARM1 zero_read(WORD addr)
         return pport.data_read;
     }
 
-    return mem_ram[addr & 0xff];
+    if (c64_256k_enabled)
+        return c64_256k_ram_segment0_read(addr);
+    else
+        return mem_ram[addr & 0xff];
 }
 
 void REGPARM2 zero_store(WORD addr, BYTE value)
@@ -182,7 +188,10 @@ void REGPARM2 zero_store(WORD addr, BYTE value)
     switch ((BYTE)addr) {
       case 0:
         if (vbank == 0) {
-            vicii_mem_vbank_store((WORD)0, vicii_read_phi1_lowlevel());
+            if (c64_256k_enabled==1)
+               c64_256k_ram_segment0_store((WORD)0, vicii_read_phi1_lowlevel());
+            else
+                vicii_mem_vbank_store((WORD)0, vicii_read_phi1_lowlevel());
         } else {
             mem_ram[0] = vicii_read_phi1_lowlevel();
             machine_handle_pending_alarms(maincpu_rmw_flag + 1);
@@ -194,7 +203,10 @@ void REGPARM2 zero_store(WORD addr, BYTE value)
         break;
       case 1:
         if (vbank == 0) {
-            vicii_mem_vbank_store((WORD)1, vicii_read_phi1_lowlevel());
+            if (c64_256k_enabled==1)
+                c64_256k_ram_segment0_store((WORD)1, vicii_read_phi1_lowlevel());
+            else
+                vicii_mem_vbank_store((WORD)1, vicii_read_phi1_lowlevel());
         } else {
             mem_ram[1] = vicii_read_phi1_lowlevel();
             machine_handle_pending_alarms(maincpu_rmw_flag + 1);
@@ -206,7 +218,10 @@ void REGPARM2 zero_store(WORD addr, BYTE value)
         break;
       default:
         if (vbank == 0) {
-            vicii_mem_vbank_store(addr, value);
+            if (c64_256k_enabled==1)
+                c64_256k_ram_segment0_store(addr, value);
+            else
+                vicii_mem_vbank_store(addr, value);
         } else {
             mem_ram[addr] = value;
         }
@@ -292,6 +307,114 @@ BYTE REGPARM1 colorram_read(WORD addr)
 
 /* ------------------------------------------------------------------------- */
 
+/* init 256k memory table changes */
+
+static int check_256k_ram_write(int k, int i, int j)
+{
+  if (mem_write_tab[k][i][j]==vicii_mem_vbank_39xx_store ||
+      mem_write_tab[k][i][j]==vicii_mem_vbank_3fxx_store ||
+      mem_write_tab[k][i][j]==vicii_mem_vbank_store ||
+      mem_write_tab[k][i][j]==ram_hi_store ||
+      mem_write_tab[k][i][j]==ram_store)
+   return 1;
+  else
+    return 0;
+}
+
+void c64_256k_init_config(void)
+{
+  int i,j,k;
+
+  if (c64_256k_enabled)
+  {
+    mem_limit_c64_256k_init(mem_read_limit_tab);
+    for (i = 0; i < NUM_CONFIGS; i++)
+    {
+      for (j = 1; j <= 0xff; j++)
+      {
+        for (k = 0; k < NUM_VBANKS; k++)
+        {
+          if (check_256k_ram_write(k,i,j)==1)
+          {
+            if (j<0x40)
+              mem_write_tab[k][i][j]=c64_256k_ram_segment0_store;
+            if (j>0x3f && j<0x80)
+              mem_write_tab[k][i][j]=c64_256k_ram_segment1_store;
+            if (j>0x7f && j<0xc0)
+              mem_write_tab[k][i][j]=c64_256k_ram_segment2_store;
+            if (j>0xbf)
+              mem_write_tab[k][i][j]=c64_256k_ram_segment3_store;
+          }
+        }
+        if (mem_read_tab[i][j]==ram_read)
+        {
+          if (j<0x40)
+            mem_read_tab[i][j]=c64_256k_ram_segment0_read;
+          if (j>0x3f && j<0x80)
+            mem_read_tab[i][j]=c64_256k_ram_segment1_read;
+          if (j>0x7f && j<0xc0)
+            mem_read_tab[i][j]=c64_256k_ram_segment2_read;
+          if (j>0xbf)
+            mem_read_tab[i][j]=c64_256k_ram_segment3_read;
+        }
+      }
+    }
+  }
+}
+
+/* ------------------------------------------------------------------------- */
+
+/* init plus60k memory table changes */
+
+static void plus60k_init_config(void)
+{
+  int i,j,k;
+
+  if (plus60k_enabled)
+  {
+    mem_limit_plus60k_init(mem_read_limit_tab);
+    for (i = 0; i < NUM_CONFIGS; i++)
+    {
+      for (j = 0x10; j <= 0xff; j++)
+      {
+        for (k = 0; k < NUM_VBANKS; k++)
+        {
+          if (mem_write_tab[k][i][j]==vicii_mem_vbank_39xx_store)
+            mem_write_tab[k][i][j]=plus60k_vicii_mem_vbank_39xx_store;
+          if (mem_write_tab[k][i][j]==vicii_mem_vbank_3fxx_store)
+            mem_write_tab[k][i][j]=plus60k_vicii_mem_vbank_3fxx_store;
+          if (mem_write_tab[k][i][j]==vicii_mem_vbank_store)
+            mem_write_tab[k][i][j]=plus60k_vicii_mem_vbank_store;
+          if (mem_write_tab[k][i][j]==ram_hi_store)
+            mem_write_tab[k][i][j]=plus60k_ram_hi_store;
+          if (mem_write_tab[k][i][j]==vicii_store && j==0xd0 && plus60k_base==0xd040)
+            mem_write_tab[k][i][j]=plus60k_vicii_store_old;
+          if (mem_write_tab[k][i][j]==vicii_store && j==0xd1 && plus60k_base==0xd100)
+            mem_write_tab[k][i][j]=plus60k_vicii_store;
+          if (mem_write_tab[k][i][j]==vicii_store && j==0xd1 && plus60k_base==0xd040)
+            mem_write_tab[k][i][j]=plus60k_vicii_store0;
+          if (mem_write_tab[k][i][j]==vicii_store && j>0xd1)
+            mem_write_tab[k][i][j]=plus60k_vicii_store0;
+          if (mem_write_tab[k][i][j]==ram_store)
+            mem_write_tab[k][i][j]=plus60k_ram_store;
+        }
+        if (mem_read_tab[i][j]==vicii_read && j==0xd0 && plus60k_base==0xd040)
+          mem_read_tab[i][j]=plus60k_vicii_read_old;
+        if (mem_read_tab[i][j]==vicii_read && j==0xd1 && plus60k_base==0xd100)
+          mem_read_tab[i][j]=plus60k_vicii_read;
+        if (mem_read_tab[i][j]==vicii_read && j==0xd1 && plus60k_base==0xd040)
+          mem_read_tab[i][j]=plus60k_vicii_read0;
+        if (mem_read_tab[i][j]==vicii_read && j>0xd1)
+          mem_read_tab[i][j]=plus60k_vicii_read0;
+        if (mem_read_tab[i][j]==ram_read)
+          mem_read_tab[i][j]=plus60k_ram_read;
+      }
+    }
+  }
+}
+
+/* ------------------------------------------------------------------------- */
+
 void mem_set_write_hook(int config, int page, store_func_t *f)
 {
     int i;
@@ -457,6 +580,9 @@ void mem_initialize_memory(void)
     /* Setup initial memory configuration.  */
     mem_pla_config_changed();
     cartridge_init_config();
+    ramcart_init_config();
+    plus60k_init_config();
+    c64_256k_init_config();
 }
 
 /* ------------------------------------------------------------------------- */
