@@ -32,11 +32,16 @@
 #include "actionreplay.h"
 #include "c64cart.h"
 #include "c64cartmem.h"
+#include "c64export.h"
 #include "types.h"
 #include "util.h"
 #include "vicii-phi1.h"
 
 
+static const c64export_resource_t export_res = {
+    "Action Replay", 1, 1, 1, 1
+};
+
 static unsigned int ar_active;
 
 
@@ -127,6 +132,9 @@ int actionreplay_bin_attach(const char *filename, BYTE *rawcart)
         UTIL_FILE_LOAD_SKIP_ADDRESS) < 0)
         return -1;
 
+    if (c64export_add(&export_res) < 0)
+        return -1;
+
     return 0;
 }
 
@@ -146,6 +154,14 @@ int actionreplay_crt_attach(FILE *fd, BYTE *rawcart)
             return -1;
     }
 
+    if (c64export_add(&export_res) < 0)
+        return -1;
+
     return 0;
 }
 
+void actionreplay_detach(void)
+{
+    c64export_remove(&export_res);
+}
+
