@@ -47,7 +47,11 @@
 #include "mem.h"
 #include "resources.h"
 #include "retroreplay.h"
+#include "stb.h"
 #include "supersnapshot.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "util.h"
 
 
@@ -151,55 +155,113 @@ static int attach_cartridge_cmdline(const char *param, void *extra_param)
     return cartridge_attach_image((int)extra_param, param);
 }
 
+#ifdef HAS_TRANSLATION
+static const cmdline_option_t cmdline_options[] =
+{
+    { "-cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
+      (void *)1, 0,
+      IDCLS_CART_ATTACH_DETACH_RESET },
+    { "+cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
+      (void *)0, 0,
+      IDCLS_CART_ATTACH_DETACH_NO_RESET },
+    { "-cartcrt", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_CRT, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_CRT_CART },
+    { "-cart8", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_GENERIC_8KB, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_GENERIC_8KB_CART },
+    { "-cart16", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_GENERIC_16KB, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_GENERIC_16KB_CART },
+    { "-cartar", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_ACTION_REPLAY, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_ACTION_REPLAY_CART },
+    { "-cartrr", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_RETRO_REPLAY, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_RETRO_REPLAY_CART },
+    { "-cartide", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_IDE64, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_IDE64_CART },
+    { "-cartap", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_ATOMIC_POWER, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_ATOMIC_POWER_CART },
+    { "-cartepyx", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_EPYX_FASTLOAD, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_EPYX_FASTLOAD_CART },
+    { "-cartss4", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_SUPER_SNAPSHOT, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_SS4_CART },
+    { "-cartss5", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_SUPER_SNAPSHOT_V5, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_SS5_CART },
+    { "-cartieee488", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_IEEE488, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_CBM_IEEE488_CART },
+    { "-cartwestermann", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_WESTERMANN, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_WESTERMANN_CART },
+    { "-cartstb", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_STRUCTURED_BASIC, NULL, NULL,
+      IDCLS_P_NAME, IDCLS_ATTACH_RAW_STB_CART },
+    { "-cartexpert", CALL_FUNCTION, 0, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_EXPERT, NULL, NULL,
+      0, IDCLS_ENABLE_EXPERT_CART },
+    { NULL }
+};
+#else
 static const cmdline_option_t cmdline_options[] =
 {
     { "-cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
       (void *)1, NULL,
-      "Reset machine if a cartridge is attached or detached" },
+      N_("Reset machine if a cartridge is attached or detached") },
     { "+cartreset", SET_RESOURCE, 0, NULL, NULL, "CartridgeReset",
       (void *)0, NULL,
-      "Do not reset machine if a cartridge is attached or detached" },
+      N_("Do not reset machine if a cartridge is attached or detached") },
     { "-cartcrt", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_CRT, NULL, NULL,
-      "<name>", "Attach CRT cartridge image" },
+      N_("<name>"), N_("Attach CRT cartridge image") },
     { "-cart8", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_GENERIC_8KB, NULL, NULL,
-      "<name>", "Attach generic 8KB cartridge image" },
+      N_("<name>"), N_("Attach generic 8KB cartridge image") },
     { "-cart16", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_GENERIC_16KB, NULL, NULL,
-      "<name>", "Attach generic 16KB cartridge image" },
+      N_("<name>"), N_("Attach generic 16KB cartridge image") },
     { "-cartar", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_ACTION_REPLAY, NULL, NULL,
-      "<name>", "Attach raw 32KB Action Replay cartridge image" },
+      N_("<name>"), N_("Attach raw 32KB Action Replay cartridge image") },
     { "-cartrr", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_RETRO_REPLAY, NULL, NULL,
-      "<name>", "Attach raw 64KB Retro Replay cartridge image" },
+      N_("<name>"), N_("Attach raw 64KB Retro Replay cartridge image") },
     { "-cartide", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_IDE64, NULL, NULL,
-      "<name>", "Attach raw 64KB IDE64 cartridge image" },
+      N_("<name>"), N_("Attach raw 64KB IDE64 cartridge image") },
     { "-cartap", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_ATOMIC_POWER, NULL, NULL,
-      "<name>", "Attach raw 32KB Atomic Power cartridge image" },
+      N_("<name>"), N_("Attach raw 32KB Atomic Power cartridge image") },
     { "-cartepyx", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_EPYX_FASTLOAD, NULL, NULL,
-      "<name>", "Attach raw 8KB Epyx fastload cartridge image" },
+      N_("<name>"), N_("Attach raw 8KB Epyx fastload cartridge image") },
     { "-cartss4", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_SUPER_SNAPSHOT, NULL, NULL,
-      "<name>", "Attach raw 32KB Super Snapshot cartridge image" },
+      N_("<name>"), N_("Attach raw 32KB Super Snapshot cartridge image") },
     { "-cartss5", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_SUPER_SNAPSHOT_V5, NULL, NULL,
-      "<name>", "Attach raw 64KB Super Snapshot cartridge image" },
+      N_("<name>"), N_("Attach raw 64KB Super Snapshot cartridge image") },
     { "-cartieee488", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_IEEE488, NULL, NULL,
-      "<name>", "Attach CBM IEEE488 cartridge image" },
+      N_("<name>"), N_("Attach CBM IEEE488 cartridge image") },
     { "-cartwestermann", CALL_FUNCTION, 1, attach_cartridge_cmdline,
       (void *)CARTRIDGE_WESTERMANN, NULL, NULL,
-      "<name>", "Attach raw 16KB Westermann learning cartridge image" },
+      N_("<name>"), N_("Attach raw 16KB Westermann learning cartridge image") },
+    { "-cartstb", CALL_FUNCTION, 1, attach_cartridge_cmdline,
+      (void *)CARTRIDGE_STRUCTURED_BASIC, NULL, NULL,
+      N_("<name>"), N_("Attach Structured Basic cartridge image") },
     { "-cartexpert", CALL_FUNCTION, 0, attach_cartridge_cmdline,
       (void *)CARTRIDGE_EXPERT, NULL, NULL,
-      NULL, "Enable expert cartridge" },
+      NULL, N_("Enable expert cartridge") },
     { NULL }
 };
+#endif
 
 int cartridge_cmdline_options_init(void)
 {
@@ -289,6 +351,10 @@ int cartridge_attach_image(int type, const char *filename)
         if (crt_attach(filename, rawcart) < 0)
             goto done;
         break;
+      case CARTRIDGE_STRUCTURED_BASIC:
+        if (stb_bin_attach(filename, rawcart) < 0)
+            goto done;
+        break;
       default:
         goto done;
     }
