@@ -37,6 +37,7 @@
 #include "c64tpi.h"
 #include "c64cartmem.h"
 #include "cartridge.h"
+#include "comal80.h"
 #include "crt.h"
 #include "epyxfastload.h"
 #include "expert.h"
@@ -50,6 +51,9 @@
 #include "resources.h"
 #include "retroreplay.h"
 #include "ide64.h"
+#include "ramcart.h"
+#include "ross.h"
+#include "stb.h"
 #include "supergames.h"
 #include "supersnapshot.h"
 #include "types.h"
@@ -137,6 +141,10 @@ BYTE REGPARM1 cartridge_read_io1(WORD addr)
         return expert_io1_read(addr);
       case CARTRIDGE_MAGIC_FORMEL:
         return magicformel_io1_read(addr);
+      case CARTRIDGE_ROSS:
+        return ross_io1_read(addr);
+      case CARTRIDGE_STRUCTURED_BASIC:
+        return stb_io1_read(addr);
     }
     return vicii_read_phi1();
 }
@@ -169,6 +177,9 @@ void REGPARM2 cartridge_store_io1(WORD addr, BYTE value)
       case CARTRIDGE_FINAL_III:
         final_v3_io1_store(addr, value);
         break;
+      case CARTRIDGE_COMAL80:
+        comal80_io1_store(addr, value);
+        break;
       case CARTRIDGE_SIMONS_BASIC:
         cartridge_config_changed(1, 1, CMODE_WRITE);
         break;
@@ -218,6 +229,9 @@ void REGPARM2 cartridge_store_io1(WORD addr, BYTE value)
       case CARTRIDGE_MAGIC_FORMEL:
         magicformel_io1_store(addr, value);
         break;
+      case CARTRIDGE_STRUCTURED_BASIC:
+        stb_io1_store(addr, value);
+        break;
     }
     return;
 }
@@ -259,6 +273,8 @@ BYTE REGPARM1 cartridge_read_io2(WORD addr)
         return roml_banks[0x1f00 + (addr & 0xff)];
       case CARTRIDGE_MAGIC_FORMEL:
         return magicformel_io2_read(addr);
+      case CARTRIDGE_ROSS:
+        return ross_io2_read(addr);
     }
     return vicii_read_phi1();
 }
@@ -307,6 +323,10 @@ void REGPARM2 cartridge_store_io2(WORD addr, BYTE value)
 
 BYTE REGPARM1 roml_read(WORD addr)
 {
+    if (ramcart_enabled)
+    {
+      return ramcart_roml_read(addr);
+    }
     switch (mem_cartridge_type) {
       case CARTRIDGE_ZAXXON:
         return zaxxon_roml_read(addr);
@@ -340,6 +360,11 @@ BYTE REGPARM1 roml_read(WORD addr)
 
 void REGPARM2 roml_store(WORD addr, BYTE value)
 {
+    if (ramcart_enabled)
+    {
+      ramcart_roml_store(addr,value);
+      return;
+    }
     switch (mem_cartridge_type) {
       case CARTRIDGE_SUPER_SNAPSHOT:
         supersnapshot_v4_roml_store(addr, value);
@@ -516,6 +541,9 @@ void cartridge_init_config(void)
       case CARTRIDGE_SUPER_GAMES:
         supergames_config_init();
         break;
+      case CARTRIDGE_COMAL80:
+        comal80_config_init();
+        break;
       case CARTRIDGE_GENERIC_8KB:
       case CARTRIDGE_REX:
         generic_8kb_config_init();
@@ -574,6 +602,12 @@ void cartridge_init_config(void)
       case CARTRIDGE_MAGIC_FORMEL:
         magicformel_config_init();
         break;
+      case CARTRIDGE_ROSS:
+        ross_config_init();
+        break;
+      case CARTRIDGE_STRUCTURED_BASIC:
+        stb_config_init();
+        break;
       default:
         cartridge_config_changed(2, 2, CMODE_READ);
     }
@@ -655,6 +689,9 @@ void cartridge_attach(int type, BYTE *rawcart)
       case CARTRIDGE_SUPER_GAMES:
         supergames_config_setup(rawcart);
         break;
+      case CARTRIDGE_COMAL80:
+        comal80_config_setup(rawcart);
+        break;
       case CARTRIDGE_EXPERT:
         expert_config_setup(rawcart);
         break;
@@ -668,6 +705,12 @@ void cartridge_attach(int type, BYTE *rawcart)
       case CARTRIDGE_MAGIC_FORMEL:
         magicformel_config_setup(rawcart);
         break;
+      case CARTRIDGE_ROSS:
+        ross_config_setup(rawcart);
+        break;
+      case CARTRIDGE_STRUCTURED_BASIC:
+        stb_config_setup(rawcart);
+        break;
       default:
         mem_cartridge_type = CARTRIDGE_NONE;
     }
@@ -696,12 +739,21 @@ void cartridge_detach(int type)
       case CARTRIDGE_EPYX_FASTLOAD:
         epyxfastload_detach();
         break;
+      case CARTRIDGE_REX:
+        rex_detach();
+        break;
       case CARTRIDGE_EXPERT:
         expert_detach();
         break;
       case CARTRIDGE_FINAL_I:
         final_v1_detach();
         break;
+      case CARTRIDGE_WESTERMANN:
+        westermann_detach();
+        break;
+      case CARTRIDGE_WARPSPEED:
+        warpspeed_detach();
+        break;
       case CARTRIDGE_FINAL_III:
         final_v3_detach();
         break;
@@ -720,6 +772,9 @@ void cartridge_detach(int type)
       case CARTRIDGE_KCS_POWER:
         kcs_detach();
         break;
+      case CARTRIDGE_SIMONS_BASIC:
+        simon_detach();
+        break;
       case CARTRIDGE_MAGIC_FORMEL:
         magicformel_detach();
         break;
@@ -729,6 +784,15 @@ void cartridge_detach(int type)
       case CARTRIDGE_SUPER_GAMES:
         supergames_detach();
         break;
+      case CARTRIDGE_COMAL80:
+        comal80_detach();
+        break;
+      case CARTRIDGE_STRUCTURED_BASIC:
+        stb_detach();
+        break;
+      case CARTRIDGE_ROSS:
+        ross_detach();
+        break;
       case CARTRIDGE_SUPER_SNAPSHOT:
         supersnapshot_v4_detach();
         break;
@@ -802,5 +866,3 @@ void cartridge_romlbank_set(unsigned int bank)
 {
     roml_bank = (int)bank;
 }
-
-
