@@ -35,6 +35,7 @@
 #include "c64cart.h"
 #include "c64cartmem.h"
 #include "cartridge.h"
+#include "comal80.h"
 #include "crt.h"
 #include "epyxfastload.h"
 #include "expert.h"
@@ -43,6 +44,8 @@
 #include "kcs.h"
 #include "magicformel.h"
 #include "resources.h"
+#include "ross.h"
+#include "stb.h"
 #include "supergames.h"
 #include "supersnapshot.h"
 #include "types.h"
@@ -95,7 +98,17 @@ int crt_attach(const char *filename, BYTE *rawcart)
             return -1;
         break;
       case CARTRIDGE_WESTERMANN:
+        rc = westermann_crt_attach(fd, rawcart);
+        fclose(fd);
+        if (rc < 0)
+            return -1;
+        break;
       case CARTRIDGE_WARPSPEED:
+        rc = warpspeed_crt_attach(fd, rawcart);
+        fclose(fd);
+        if (rc < 0)
+            return -1;
+        break;
       case CARTRIDGE_FINAL_I:
         rc = final_v1_crt_attach(fd, rawcart);
         fclose(fd);
@@ -114,8 +127,13 @@ int crt_attach(const char *filename, BYTE *rawcart)
         if (rc < 0)
             return -1;
         break;
-      case CARTRIDGE_KCS_POWER:
       case CARTRIDGE_SIMONS_BASIC:
+        rc = simon_crt_attach(fd, rawcart);
+        fclose(fd);
+        if (rc < 0)
+            return -1;
+        break;
+      case CARTRIDGE_KCS_POWER:
         rc = kcs_crt_attach(fd, rawcart);
         fclose(fd);
         if (rc < 0)
@@ -170,13 +188,24 @@ int crt_attach(const char *filename, BYTE *rawcart)
         if (rc < 0)
             return -1;
         break;
+      case CARTRIDGE_COMAL80:
+        rc = comal80_crt_attach(fd, rawcart);
+        fclose(fd);
+        if (rc < 0)
+            return -1;
+        break;
       case CARTRIDGE_EPYX_FASTLOAD:
-      case CARTRIDGE_REX:
         rc = epyxfastload_crt_attach(fd, rawcart);
         fclose(fd);
         if (rc < 0)
             return -1;
         break;
+      case CARTRIDGE_REX:
+        rc = rex_crt_attach(fd, rawcart);
+        fclose(fd);
+        if (rc < 0)
+            return -1;
+        break;
       case CARTRIDGE_EXPERT:
         rc = expert_crt_attach(fd, rawcart);
         fclose(fd);
@@ -201,6 +230,18 @@ int crt_attach(const char *filename, BYTE *rawcart)
         if (rc < 0)
             return -1;
         break;
+      case CARTRIDGE_STRUCTURED_BASIC:
+        rc = stb_crt_attach(fd, rawcart);
+        fclose(fd);
+        if (rc < 0)
+            return -1;
+        break;
+      case CARTRIDGE_ROSS:
+        rc = ross_crt_attach(fd, rawcart);
+        fclose(fd);
+        if (rc < 0)
+            return -1;
+        break;
       default:
         fclose(fd);
         return -1;
