@@ -36,7 +36,9 @@ extern BYTE REGPARM1 epyxfastload_io2_read(WORD addr);
 extern void epyxfastload_config_init(void);
 extern void epyxfastload_config_setup(BYTE *rawcart);
 extern int epyxfastload_crt_attach(FILE *fd, BYTE *rawcart);
+extern int rex_crt_attach(FILE *fd, BYTE *rawbyte);
 extern void epyxfastload_detach(void);
+extern void rex_detach(void);
 
 #endif
 
