@@ -38,6 +38,9 @@
 #include "ide64.h"
 #include "log.h"
 #include "resources.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "util.h"
 #include "vicii-phi1.h"
@@ -241,23 +244,43 @@ int ide64_resources_init(void)
     return resources_register(resources);
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-IDE64image", SET_RESOURCE, 1, NULL, NULL, "IDE64Image", NULL,
-      "<name>", "Specify name of IDE64 image file" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_IDE64_NAME },
     { "-IDE64cyl", SET_RESOURCE, 1, NULL, NULL, "IDE64Cylinders", NULL,
-      "<value>", "Set number of cylinders for the IDE64 emulation" },
+      IDCLS_P_VALUE, IDCLS_SET_AMOUNT_CYLINDERS_IDE64 },
     { "-IDE64hds", SET_RESOURCE, 1, NULL, NULL, "IDE64Heads", NULL,
-      "<value>", "Set number of heads for the IDE64 emulation" },
+      IDCLS_P_VALUE, IDCLS_SET_AMOUNT_HEADS_IDE64 },
     { "-IDE64sec", SET_RESOURCE, 1, NULL, NULL, "IDE64Sectors", NULL,
-      "<value>", "Set number of sectors for the IDE64 emulation" },
+      IDCLS_P_VALUE, IDCLS_SET_AMOUNT_SECTORS_IDE64 },
     { "-IDE64autosize", SET_RESOURCE, 0, NULL, NULL,
       "IDE64AutodetectSize", (void *)1,
-      NULL, "Autodetect geometry of formatted images" },
+      0, IDCLS_AUTODETECT_IDE64_GEOMETRY },
     { "+IDE64autosize", SET_RESOURCE, 0, NULL, NULL,
       "IDE64AutodetectSize", (void *)0,
-      NULL, "Do not autoetect geometry of formatted images" },
+      0, IDCLS_NO_AUTODETECT_IDE64_GEOMETRY },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-IDE64image", SET_RESOURCE, 1, NULL, NULL, "IDE64Image", NULL,
+      N_("<name>"), N_("Specify name of IDE64 image file") },
+    { "-IDE64cyl", SET_RESOURCE, 1, NULL, NULL, "IDE64Cylinders", NULL,
+      N_("<value>"), N_("Set number of cylinders for the IDE64 emulation") },
+    { "-IDE64hds", SET_RESOURCE, 1, NULL, NULL, "IDE64Heads", NULL,
+      N_("<value>"), N_("Set number of heads for the IDE64 emulation") },
+    { "-IDE64sec", SET_RESOURCE, 1, NULL, NULL, "IDE64Sectors", NULL,
+      N_("<value>"), N_("Set number of sectors for the IDE64 emulation") },
+    { "-IDE64autosize", SET_RESOURCE, 0, NULL, NULL,
+      "IDE64AutodetectSize", (void *)1,
+      NULL, N_("Autodetect geometry of formatted images") },
+    { "+IDE64autosize", SET_RESOURCE, 0, NULL, NULL,
+      "IDE64AutodetectSize", (void *)0,
+      NULL, N_("Do not autodetect geometry of formatted images") },
+    { NULL }
+};
+#endif
 
 int ide64_cmdline_options_init(void)
 {
@@ -756,10 +779,10 @@ int ide64_bin_attach(const char *filename, BYTE *rawcart)
 
     if (ide_disk)
         log_message(LOG_DEFAULT,
-                    _("IDE64: Using imagefile `%s'."), ide64_image_file);
+                    "IDE64: Using imagefile `%s'.", ide64_image_file);
     else
         log_message(LOG_DEFAULT,
-                    _("IDE64: Cannot use image file `%s'. NO DRIVE EMULATION!"),
+                    "IDE64: Cannot use image file `%s'. NO DRIVE EMULATION!",
                     ide64_image_file);
 
     if (!settings_autodetect_size)
@@ -775,7 +798,7 @@ int ide64_bin_attach(const char *filename, BYTE *rawcart)
         /* read header */
         res = fread(idebuf, 1, 24, ide_disk);
         if (res < 24) {
-            log_message(LOG_DEFAULT, _("IDE64: Couldn't read disk geometry from image, using default 8MB."));
+            log_message(LOG_DEFAULT, "IDE64: Couldn't read disk geometry from image, using default 8MB.");
             return 0;
         }
         /* check signature */
@@ -809,7 +832,7 @@ int ide64_bin_attach(const char *filename, BYTE *rawcart)
 		break;		/* OK */
 	    }
 	    
-            log_message(LOG_DEFAULT, _("IDE64: Disk is not formatted, using default 8MB."));
+            log_message(LOG_DEFAULT, "IDE64: Disk is not formatted, using default 8MB.");
             return 0;
 	}
 
@@ -817,9 +840,9 @@ int ide64_bin_attach(const char *filename, BYTE *rawcart)
 	    cyl++;
 	    heads++;
     	    size = cyl * heads * sectors;
-    	    log_message(LOG_DEFAULT, _("IDE64: using %i/%i/%i CHS geometry, %lu sectors total."), cyl, heads, sectors, size);
+    	    log_message(LOG_DEFAULT, "IDE64: using %i/%i/%i CHS geometry, %lu sectors total.", cyl, heads, sectors, size);
 	} else {
-    	    log_message(LOG_DEFAULT, _("IDE64: LBA geometry, %lu sectors total."), size);
+    	    log_message(LOG_DEFAULT, "IDE64: LBA geometry, %lu sectors total.", size);
 	}
 
         settings_cylinders = cyl;
