@@ -38,6 +38,9 @@
 #include "machine.h"
 #include "psid.h"
 #include "resources.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "ui.h"
 #include "vsidui.h"
@@ -119,26 +122,49 @@ static int cmdline_psid_tune(const char *param, void *extra_param)
     return 0;
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
     /* The Video Standard options are copied from the machine files. */
     { "-pal", SET_RESOURCE, 0, NULL, NULL, "MachineVideoStandard",
       (resource_value_t)MACHINE_SYNC_PAL,
-      NULL, "Use PAL sync factor" },
+      0, IDCLS_USE_PAL_SYNC_FACTOR },
     { "-ntsc", SET_RESOURCE, 0, NULL, NULL, "MachineVideoStandard",
       (resource_value_t)MACHINE_SYNC_NTSC,
-      NULL, "Use NTSC sync factor" },
+      0, IDCLS_USE_NTSC_SYNC_FACTOR },
     { "-ntscold", SET_RESOURCE, 0, NULL, NULL, "MachineVideoStandard",
       (resource_value_t)MACHINE_SYNC_NTSCOLD,
-      NULL, "Use old NTSC sync factor" },
+      0, IDCLS_USE_OLD_NTSC_SYNC_FACTOR },
     { "-vsid", CALL_FUNCTION, 0, cmdline_vsid_mode, NULL, NULL, NULL,
-      NULL, "SID player mode" },
+      0, IDCLS_SID_PLAYER_MODE },
     { "-keepenv", CALL_FUNCTION, 0, cmdline_keepenv, NULL, NULL, NULL,
-      NULL, "Override PSID settings for Video standard and SID model" },
+      0, IDCLS_OVERWRITE_PSID_SETTINGS },
     { "-tune", CALL_FUNCTION, 1, cmdline_psid_tune, NULL, NULL, NULL,
-      "<number>", "Specify PSID tune <number>" },
+      IDCLS_P_NUMBER, IDCLS_SPECIFY_PSID_TUNE_NUMBER },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] =
+{
+    /* The Video Standard options are copied from the machine files. */
+    { "-pal", SET_RESOURCE, 0, NULL, NULL, "MachineVideoStandard",
+      (resource_value_t)MACHINE_SYNC_PAL,
+      NULL, N_("Use PAL sync factor") },
+    { "-ntsc", SET_RESOURCE, 0, NULL, NULL, "MachineVideoStandard",
+      (resource_value_t)MACHINE_SYNC_NTSC,
+      NULL, N_("Use NTSC sync factor") },
+    { "-ntscold", SET_RESOURCE, 0, NULL, NULL, "MachineVideoStandard",
+      (resource_value_t)MACHINE_SYNC_NTSCOLD,
+      NULL, N_("Use old NTSC sync factor") },
+    { "-vsid", CALL_FUNCTION, 0, cmdline_vsid_mode, NULL, NULL, NULL,
+      NULL, N_("SID player mode") },
+    { "-keepenv", CALL_FUNCTION, 0, cmdline_keepenv, NULL, NULL, NULL,
+      NULL, N_("Override PSID settings for Video standard and SID model") },
+    { "-tune", CALL_FUNCTION, 1, cmdline_psid_tune, NULL, NULL, NULL,
+      N_("<number>"), N_("Specify PSID tune <number>") },
+    { NULL }
+};
+#endif
 
 int psid_init_cmdline_options(void)
 {
