@@ -48,6 +48,9 @@
 #include "resources.h"
 #include "reu.h"
 #include "snapshot.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "util.h"
 
@@ -223,18 +226,33 @@ void reu_resources_shutdown(void)
 
 /* ------------------------------------------------------------------------- */
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
     { "-reu", SET_RESOURCE, 0, NULL, NULL, "REU", (resource_value_t)1,
-      NULL, "Enable the RAM expansion unit" },
+      0, IDCLS_ENABLE_REU },
     { "+reu", SET_RESOURCE, 0, NULL, NULL, "REU", (resource_value_t)0,
-      NULL, "Disable the RAM expansion unit" },
+      0, IDCLS_DISABLE_REU },
     { "-reuimage", SET_RESOURCE, 1, NULL, NULL, "REUfilename", NULL,
-      "<name>", "Specify name of REU image" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_REU_NAME },
     { "-reusize", SET_RESOURCE, 1, NULL, NULL, "REUsize", NULL,
-      "<size in KB>", "Size of the RAM expansion unit" },
+      IDCLS_P_SIZE_IN_KB, IDCLS_REU_SIZE },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] =
+{
+    { "-reu", SET_RESOURCE, 0, NULL, NULL, "REU", (resource_value_t)1,
+      NULL, N_("Enable the RAM expansion unit") },
+    { "+reu", SET_RESOURCE, 0, NULL, NULL, "REU", (resource_value_t)0,
+      NULL, N_("Disable the RAM expansion unit") },
+    { "-reuimage", SET_RESOURCE, 1, NULL, NULL, "REUfilename", NULL,
+      N_("<name>"), N_("Specify name of REU image") },
+    { "-reusize", SET_RESOURCE, 1, NULL, NULL, "REUsize", NULL,
+      N_("<size in KB>"), N_("Size of the RAM expansion unit") },
+    { NULL }
+};
+#endif
 
 int reu_cmdline_options_init(void)
 {
@@ -263,11 +281,14 @@ void reu_reset(void)
     reu_blocklen_low_shadow = 0;
 
     if (reu_size >= (256 << 10))
-        reu[REU_REG_R_STATUS] = 0x50;
+        reu[REU_REG_R_STATUS] = 0x10;
     else
-        reu[REU_REG_R_STATUS] = 0x40;
+        reu[REU_REG_R_STATUS] = 0x00;
 
-    reu[REU_REG_W_COMMAND] = 0x4A;
+    reu[REU_REG_W_COMMAND] = 0x10;
+
+    reu[REU_REG_RW_BLOCKLEN_LOW]  = 0xFF;
+    reu[REU_REG_RW_BLOCKLEN_HIGH] = 0xFF;
 }
 
 static int reu_activate(void)
