@@ -80,6 +80,12 @@
 #include "vicii.h"
 #include "video.h"
 #include "vsync.h"
+#include "../c64/c64export.h"
+
+int c64export_query(const c64export_resource_t *export_res)
+{
+    return 0;
+}
 
 
 machine_context_t machine_context;
@@ -230,9 +236,16 @@ static void cbm2_monitor_init(void)
 {
     unsigned int dnr;
     monitor_cpu_type_t asm6502;
-    monitor_cpu_type_t *asmarray[2] = { &asm6502, NULL };
     monitor_interface_t *drive_interface_init[DRIVE_NUM];
 
+#ifdef MINIXVMD
+    monitor_cpu_type_t *asmarray[2];
+    asmarray[0]=&asm6502;
+    asmarray[1]=NULL;
+#else
+    monitor_cpu_type_t *asmarray[2] = { &asm6502, NULL };
+#endif
+
     asm6502_init(&asm6502);
 
     for (dnr = 0; dnr < DRIVE_NUM; dnr++)
@@ -413,9 +426,13 @@ static void machine_vsync_hook(void)
 }
 
 /* Dummy - no restore key.  */
-int machine_set_restore_key(int v)
+void machine_set_restore_key(int v)
 {
-    return 0;   /* key not used -> lookup in keymap */
+}
+
+int machine_has_restore_key(void)
+{
+    return 0;
 }
 
 /* ------------------------------------------------------------------------- */
