@@ -47,6 +47,7 @@
 #include "ram.h"
 #include "resources.h"
 #include "sid.h"
+#include "sid-resources.h"
 #include "types.h"
 #include "vsync.h"
 #include "vicii-mem.h"
@@ -206,16 +207,6 @@ void cbm2_set_tpi1cb(int a) {
 
 /* ------------------------------------------------------------------------- */
 
-const char *mem_romset_resources_list[] = {
-    "KernalName", "ChargenName", "BasicName",
-    "Cart1Name", "Cart2Name", "Cart4Name", "Cart6Name",
-    "DosName2031", "DosName1001",
-    "DosName1541", "DosName1571", "DosName1581", "DosName1541ii",
-    NULL
-};
-
-/* ------------------------------------------------------------------------- */
-
 /* Enable/disable the Emulator ID.  */
 void mem_toggle_emu_id(int flag)
 {
@@ -539,25 +530,25 @@ static void REGPARM2 store_dummy(WORD addr, BYTE value)
 
 BYTE REGPARM1 read_watch(WORD addr)
 {
-    mon_watch_push_load_addr(addr, e_comp_space);
+    monitor_watch_push_load_addr(addr, e_comp_space);
     return _mem_read_tab[cbm2mem_bank_exec][addr >> 8](addr);
 }
 
 void REGPARM2 store_watch(WORD addr, BYTE value)
 {
-    mon_watch_push_store_addr(addr, e_comp_space);
+    monitor_watch_push_store_addr(addr, e_comp_space);
     _mem_write_tab[cbm2mem_bank_exec][addr >> 8](addr, value);
 }
 
 BYTE REGPARM1 read_ind_watch(WORD addr)
 {
-    mon_watch_push_load_addr(addr, e_comp_space);
+    monitor_watch_push_load_addr(addr, e_comp_space);
     return _mem_read_tab[cbm2mem_bank_ind][addr >> 8](addr);
 }
 
 void REGPARM2 store_ind_watch(WORD addr, BYTE value)
 {
-    mon_watch_push_store_addr(addr, e_comp_space);
+    monitor_watch_push_store_addr(addr, e_comp_space);
     _mem_write_tab[cbm2mem_bank_ind][addr >> 8](addr, value);
 }
 
@@ -598,7 +589,10 @@ void REGPARM2 store_io(WORD addr, BYTE value)
           case 0xd900:
             return;                     /* disk units */
           case 0xda00:
-            sid_store((WORD)(addr & 0xff), value);
+            if (sid_stereo && addr >= sid_stereo_address_start && addr < sid_stereo_address_end)
+              sid2_store(addr, value);
+            else
+              sid_store((WORD)(addr & 0xff), value);
             return;
           case 0xdb00:
             return;                     /* coprocessor */
@@ -640,6 +634,17 @@ BYTE REGPARM1 read_io(WORD addr)
           case 0xd900:
             return read_unused(addr);
           case 0xda00:
+            if (sid_stereo && addr >= sid_stereo_address_start && addr < sid_stereo_address_end)
+            {
+              if (cbm2_isC500)
+              {
+                return sid2_read(addr);
+              }
+              else
+              {
+                return 0xff;            /* 2 MHz too fast for SID */
+              }
+            }
             if (cbm2_isC500) {
                 return sid_read(addr);
             } else {
