@@ -58,14 +58,23 @@ typedef struct cmdline_option_s {
        `need_arg' is zero.  */
     void *resource_value;
 
+#ifdef HAS_TRANSLATION
+    /* ID of the string to display after the option name in the help screen. */
+    int param_name;
+
+    /* ID of the description string. */
+    int description;
+#else
     /* String to display after the option name in the help screen.  (Can be
        NULL).  */
     const char *param_name;
 
     /* Description string.  */
     const char *description;
+#endif
 } cmdline_option_t;
 
+
 typedef struct cmdline_option_ram_s {
     /* Name of command-line option.  */
     char *name;
@@ -89,15 +98,24 @@ typedef struct cmdline_option_ram_s {
        `need_arg' is zero.  */
     void *resource_value;
 
+#ifdef HAS_TRANSLATION
+    /* ID of the string to display after the option name in the help screen. */
+    int param_name;
+
+    /* ID of the description string. */
+    int description;
+#else
     /* String to display after the option name in the help screen.  (Can be
        NULL).  */
     const char *param_name;
 
     /* Description string.  */
     const char *description;
+#endif
 } cmdline_option_ram_t;
 
 extern int cmdline_init(void);
+
 extern int cmdline_register_options(const cmdline_option_t *c);
 extern void cmdline_shutdown(void);
 extern int cmdline_parse(int *argc, char **argv);
@@ -105,4 +123,3 @@ extern void cmdline_show_help(void *userparam);
 extern char *cmdline_options_string(void);
 
 #endif
-
