@@ -39,9 +39,13 @@
 #include "log.h"
 #include "machine.h"
 #include "maincpu.h"
+#include "network.h"
 #include "resources.h"
 #include "snapshot.h"
 #include "tap.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "ui.h"
 
@@ -148,21 +152,39 @@ int datasette_resources_init(void)
 
 /*---------- Commandline options --------------------------------------*/
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
       "DatasetteResetWithCPU", (resource_value_t)1,
-      NULL, "Enable automatic Datasette-Reset" },
+      0, IDCLS_ENABLE_AUTO_DATASETTE_RESET },
     { "+dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
       "DatasetteResetWithCPU", (resource_value_t)0,
-      NULL, "Disable automatic Datasette-Reset" },
+      0, IDCLS_DISABLE_AUTO_DATASETTE_RESET },
     { "-dszerogapdelay", SET_RESOURCE, 1, NULL, NULL,
       "DatasetteZeroGapDelay", NULL,
-      "<value>", "Set delay in cycles for a zero in the tap" },
+      IDCLS_P_VALUE, IDCLS_SET_ZERO_TAP_DELAY },
     { "-dsspeedtuning", SET_RESOURCE, 1, NULL, NULL,
       "DatasetteSpeedTuning", NULL,
-      "<value>", "Set number of cycles added to each gap in the tap" },
+      IDCLS_P_VALUE, IDCLS_SET_CYCLES_ADDED_GAP_TAP },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
+      "DatasetteResetWithCPU", (resource_value_t)1,
+      NULL, N_("Enable automatic Datasette-Reset") },
+    { "+dsresetwithcpu", SET_RESOURCE, 0, NULL, NULL,
+      "DatasetteResetWithCPU", (resource_value_t)0,
+      NULL, N_("Disable automatic Datasette-Reset") },
+    { "-dszerogapdelay", SET_RESOURCE, 1, NULL, NULL,
+      "DatasetteZeroGapDelay", NULL,
+      N_("<value>"), N_("Set delay in cycles for a zero in the tap") },
+    { "-dsspeedtuning", SET_RESOURCE, 1, NULL, NULL,
+      "DatasetteSpeedTuning", NULL,
+      N_("<value>"), N_("Set number of cycles added to each gap in the tap") },
+    { NULL }
+};
+#endif
 
 
 int datasette_cmdline_options_init(void)
@@ -565,6 +587,8 @@ void datasette_set_tape_image(tap_t *image)
         current_image->current_file_seek_position = 0;
         last_tap = next_tap = 0;
         fullwave = 0;
+    } else {
+        datasette_set_tape_sense(0);
     }
 
     ui_set_tape_status(current_image ? 1 : 0);
@@ -645,7 +669,10 @@ static void datasette_event_record(int command)
 
     rec_cmd = (DWORD)command;
 
-    event_record(EVENT_DATASETTE, (void *)&rec_cmd, sizeof(DWORD));
+    if (network_connected())
+        network_event_record(EVENT_DATASETTE, (void *)&rec_cmd, sizeof(DWORD));
+    else
+        event_record(EVENT_DATASETTE, (void *)&rec_cmd, sizeof(DWORD));
 }
 
 void datasette_event_playback(CLOCK offset, void *data)
@@ -713,8 +740,8 @@ void datasette_control(int command)
         return;
 
     datasette_event_record(command);
-
-    datasette_control_internal(command);
+    if (!network_connected())
+        datasette_control_internal(command);
 }
 
 void datasette_set_motor(int flag)
