@@ -38,6 +38,9 @@
 #include "lib.h"
 #include "log.h"
 #include "resources.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "ui.h"
 #include "util.h"
@@ -117,48 +120,93 @@ int debug_resources_init(void)
     return resources_register(resources);
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
 #ifdef DEBUG
     { "-trace_maincpu", SET_RESOURCE, 0, NULL, NULL,
       "MainCPU_TRACE", (resource_value_t)1,
-      NULL, "Trace the main CPU" },
+      0, IDCLS_TRACE_MAIN_CPU },
     { "+trace_maincpu", SET_RESOURCE, 0, NULL, NULL,
       "MainCPU_TRACE", (resource_value_t)0,
-      NULL, "Do not trace the main CPU" },
+      0, IDCLS_DONT_TRACE_MAIN_CPU },
     { "-trace_drive0", SET_RESOURCE, 0, NULL, NULL,
       "Drive0CPU_TRACE", (resource_value_t)1,
-      NULL, "Trace the drive0 CPU" },
+      0, IDCLS_TRACE_DRIVE0_CPU },
     { "+trace_drive0", SET_RESOURCE, 0, NULL, NULL,
       "Drive0CPU_TRACE", (resource_value_t)0,
-      NULL, "Do not trace the drive0 CPU" },
+      0, IDCLS_DONT_TRACE_DRIVE0_CPU },
     { "-trace_drive1", SET_RESOURCE, 0, NULL, NULL,
       "Drive1CPU_TRACE", (resource_value_t)1,
-      NULL, "Trace the drive1 CPU" },
+      0, IDCLS_TRACE_DRIVE1_CPU },
     { "+trace_drive1", SET_RESOURCE, 0, NULL, NULL,
       "Drive1CPU_TRACE", (resource_value_t)0,
-      NULL, "Do not trace the drive1 CPU" },
+      0, IDCLS_DONT_TRACE_DRIVE1_CPU },
 #if DRIVE_NUM > 2
     { "-trace_drive2", SET_RESOURCE, 0, NULL, NULL,
       "Drive2CPU_TRACE", (resource_value_t)1,
-      NULL, "Trace the drive2 CPU" },
+      0, IDCLS_TRACE_DRIVE2_CPU },
     { "+trace_drive2", SET_RESOURCE, 0, NULL, NULL,
       "Drive2CPU_TRACE", (resource_value_t)0,
-      NULL, "Do not trace the drive2 CPU" },
+      0, IDCLS_DONT_TRACE_DRIVE2_CPU },
 #endif
 #if DRIVE_NUM > 3
     { "-trace_drive3", SET_RESOURCE, 0, NULL, NULL,
       "Drive3CPU_TRACE", (resource_value_t)1,
-      NULL, "Trace the drive3 CPU" },
+      0, IDCLS_TRACE_DRIVE3_CPU },
     { "+trace_drive3", SET_RESOURCE, 0, NULL, NULL,
       "Drive3CPU_TRACE", (resource_value_t)0,
-      NULL, "Do not trace the drive3 CPU" },
+      0, IDCLS_DONT_TRACE_DRIVE3_CPU },
 #endif
     { "-trace_mode", SET_RESOURCE, 1, NULL, NULL,
       "TraceMode", NULL,
-      "<value>", "0=normal 1=small 2=history" },
+      IDCLS_P_VALUE, IDCLS_TRACE_MODE },
 #endif
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+#ifdef DEBUG
+    { "-trace_maincpu", SET_RESOURCE, 0, NULL, NULL,
+      "MainCPU_TRACE", (resource_value_t)1,
+      NULL, N_("Trace the main CPU") },
+    { "+trace_maincpu", SET_RESOURCE, 0, NULL, NULL,
+      "MainCPU_TRACE", (resource_value_t)0,
+      NULL, N_("Do not trace the main CPU") },
+    { "-trace_drive0", SET_RESOURCE, 0, NULL, NULL,
+      "Drive0CPU_TRACE", (resource_value_t)1,
+      NULL, N_("Trace the drive0 CPU") },
+    { "+trace_drive0", SET_RESOURCE, 0, NULL, NULL,
+      "Drive0CPU_TRACE", (resource_value_t)0,
+      NULL, N_("Do not trace the drive0 CPU") },
+    { "-trace_drive1", SET_RESOURCE, 0, NULL, NULL,
+      "Drive1CPU_TRACE", (resource_value_t)1,
+      NULL, N_("Trace the drive1 CPU") },
+    { "+trace_drive1", SET_RESOURCE, 0, NULL, NULL,
+      "Drive1CPU_TRACE", (resource_value_t)0,
+      NULL, N_("Do not trace the drive1 CPU") },
+#if DRIVE_NUM > 2
+    { "-trace_drive2", SET_RESOURCE, 0, NULL, NULL,
+      "Drive2CPU_TRACE", (resource_value_t)1,
+      NULL, N_("Trace the drive2 CPU") },
+    { "+trace_drive2", SET_RESOURCE, 0, NULL, NULL,
+      "Drive2CPU_TRACE", (resource_value_t)0,
+      NULL, N_("Do not trace the drive2 CPU") },
+#endif
+#if DRIVE_NUM > 3
+    { "-trace_drive3", SET_RESOURCE, 0, NULL, NULL,
+      "Drive3CPU_TRACE", (resource_value_t)1,
+      NULL, N_("Trace the drive3 CPU") },
+    { "+trace_drive3", SET_RESOURCE, 0, NULL, NULL,
+      "Drive3CPU_TRACE", (resource_value_t)0,
+      NULL, N_("Do not trace the drive3 CPU") },
+#endif
+    { "-trace_mode", SET_RESOURCE, 1, NULL, NULL,
+      "TraceMode", NULL,
+      N_("<value>"), N_("Trace mode (0=normal 1=small 2=history)") },
+#endif
+    { NULL }
+};
+#endif
 
 int debug_cmdline_options_init(void)
 {
@@ -384,8 +432,12 @@ inline static void debug_history_step(const char *st)
 
         if (strncmp(st, debug_buffer + debug_buffer_ptr, strlen(st)) != 0) {
             event_playback_stop();
-            ui_error("Playback error: %s different from line %d of file "
-                     "debug%06d", st, debug_file_line, debug_file_current - 1);
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_PLAYBACK_ERROR_DIFFERENT)
+#else
+            ui_error(_("Playback error: %s different from line %d of file debug%06d")
+#endif
+                     , st, debug_file_line, debug_file_current - 1);
         }
 
         debug_buffer_ptr += line_len;
