@@ -127,10 +127,11 @@ static int disk_image_check_for_d64(disk_image_t *image)
     image->type = DISK_IMAGE_TYPE_D64;
     image->tracks = checkimage_tracks;
     if (checkimage_errorinfo) {
-        image->error_info = (BYTE *)lib_calloc(1, MAX_BLOCKS_1541);
+        fsimage_error_info_destroy(fsimage);
+        fsimage_error_info_create(fsimage);
         if (fseek(fsimage->fd, (long)(256 * checkimage_blocks), SEEK_SET) < 0)
             return 0;
-        if (fread(image->error_info, 1, checkimage_blocks, fsimage->fd)
+        if (fread(fsimage->error_info, 1, checkimage_blocks, fsimage->fd)
             < checkimage_blocks)
             return 0;
     }
