@@ -102,11 +102,6 @@ static void restore_int(via_context_t *via_context, unsigned int int_num,
     interrupt_restore_irq(drive_context->cpu->int_status, int_num, value);
 }
 
-#define iec_drivex_write(a)             (((drive_context_t *)(via_context->context))->func->iec_write(a))
-#define iec_drivex_read()               (((drive_context_t *)(via_context->context))->func->iec_read())
-#define parallel_cable_drivex_write(a,b) (((drive_context_t *)(via_context->context))->func->parallel_cable_write(a,b))
-
-
 static void undump_pra(via_context_t *via_context, BYTE byte)
 {
     drivevia1_context_t *via1p;
@@ -118,18 +113,18 @@ static void undump_pra(via_context_t *via_context, BYTE byte)
     if (via1p->drive->type == DRIVE_TYPE_1570
         || via1p->drive->type == DRIVE_TYPE_1571
         || via1p->drive->type == DRIVE_TYPE_1571CR) {
-        drive_sync_set_1571(byte & 0x20, drive_context);
+        drivesync_set_1571(byte & 0x20, drive_context);
         glue1571_side_set((byte >> 2) & 1, via1p->drive);
     } else
 
     if (via1p->drive->parallel_cable_enabled
         && (via1p->drive->type == DRIVE_TYPE_1541
         || via1p->drive->type == DRIVE_TYPE_1541II))
-        parallel_cable_drivex_write(byte, 0);
+        parallel_cable_drive_write(byte, 0, via1p->number);
 }
 
-inline static void store_pra(via_context_t *via_context, BYTE byte,
-                             BYTE oldpa_value, WORD addr)
+static void store_pra(via_context_t *via_context, BYTE byte, BYTE oldpa_value,
+                      WORD addr)
 {
     drivevia1_context_t *via1p;
     drive_context_t *drive_context;
@@ -141,7 +136,7 @@ inline static void store_pra(via_context_t *via_context, BYTE byte,
         || via1p->drive->type == DRIVE_TYPE_1571
         || via1p->drive->type == DRIVE_TYPE_1571CR) {
         if ((oldpa_value ^ byte) & 0x20)
-            drive_sync_set_1571(byte & 0x20, drive_context);
+            drivesync_set_1571(byte & 0x20, drive_context);
         if ((oldpa_value ^ byte) & 0x04)
             glue1571_side_set((byte >> 2) & 1, via1p->drive);
         if ((oldpa_value ^ byte) & 0x02)
@@ -150,10 +145,11 @@ inline static void store_pra(via_context_t *via_context, BYTE byte,
         if (via1p->drive->parallel_cable_enabled
             && (via1p->drive->type == DRIVE_TYPE_1541
             || via1p->drive->type == DRIVE_TYPE_1541II))
-            parallel_cable_drivex_write(byte,
-                                        (((addr == VIA_PRA)
-                                        && ((via_context->via[VIA_PCR]
-                                        & 0xe) == 0xa)) ? 1 : 0));
+            parallel_cable_drive_write(byte,
+                                       (((addr == VIA_PRA)
+                                       && ((via_context->via[VIA_PCR]
+                                       & 0xe) == 0xa)) ? 1 : 0),
+                                       via1p->number);
     }
 }
 
@@ -183,12 +179,12 @@ static void undump_prb(via_context_t *via_context, BYTE byte)
                            | (iecbus->cpu_port >> 7)
                            | ((iecbus->cpu_bus << 3) & 0x80));
     } else {
-        iec_drivex_write((BYTE)(~byte));
+        iec_drive_write((BYTE)(~byte), via1p->number);
     }
 }
 
-inline static void store_prb(via_context_t *via_context, BYTE byte,
-                             BYTE p_oldpb, WORD addr)
+static void store_prb(via_context_t *via_context, BYTE byte, BYTE p_oldpb,
+                      WORD addr)
 {
     drivevia1_context_t *via1p;
 
@@ -215,7 +211,7 @@ inline static void store_prb(via_context_t *via_context, BYTE byte,
                                | (iecbus->cpu_port >> 7)
                                | ((iecbus->cpu_bus << 3) & 0x80));
         } else {
-            iec_drivex_write((BYTE)(~byte));
+            iec_drive_write((BYTE)(~byte), via1p->number);
         }
     }
 }
@@ -228,11 +224,11 @@ static void undump_pcr(via_context_t *via_context, BYTE byte)
 #if 0
     /* FIXME: Is this correct? */
     if (via1p->number != 0)
-        viad2_update_pcr(byte, &drive[0]);
+        via2d_update_pcr(byte, &drive[0]);
 #endif
 }
 
-inline static BYTE store_pcr(via_context_t *via_context, BYTE byte, WORD addr)
+static BYTE store_pcr(via_context_t *via_context, BYTE byte, WORD addr)
 {
     return byte;
 }
@@ -241,15 +237,15 @@ static void undump_acr(via_context_t *via_context, BYTE byte)
 {
 }
 
-inline static void store_acr(via_context_t *via_context, BYTE byte)
+static void store_acr(via_context_t *via_context, BYTE byte)
 {
 }
 
-inline static void store_sr(via_context_t *via_context, BYTE byte)
+static void store_sr(via_context_t *via_context, BYTE byte)
 {
 }
 
-inline static void store_t2l(via_context_t *via_context, BYTE byte)
+static void store_t2l(via_context_t *via_context, BYTE byte)
 {
 }
 
@@ -257,7 +253,7 @@ static void reset(via_context_t *via_context)
 {
 }
 
-inline static BYTE read_pra(via_context_t *via_context, WORD addr)
+static BYTE read_pra(via_context_t *via_context, WORD addr)
 {
     BYTE byte;
     drivevia1_context_t *via1p;
@@ -286,7 +282,7 @@ inline static BYTE read_pra(via_context_t *via_context, WORD addr)
     return byte;
 }
 
-inline static BYTE read_prb(via_context_t *via_context)
+static BYTE read_prb(via_context_t *via_context)
 {
     BYTE byte;
     BYTE orval;
@@ -305,7 +301,7 @@ inline static BYTE read_prb(via_context_t *via_context)
                | iecbus->drv_port) ^ 0x85) | orval;
     } else {
         byte = (((via_context->via[VIA_PRB] & 0x1a)
-               | iec_drivex_read()) ^ 0x85) | orval;
+               | iec_drive_read(via1p->number)) ^ 0x85) | orval;
     }
 
     return byte;
