@@ -3,7 +3,7 @@
  *
  * Written by
  *  Ettore Perazzoli <ettore@comm2000.it>
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -30,7 +30,7 @@
 
 #include "types.h"
 
-extern BYTE emulator_id[];
+extern BYTE REGPARM1 emuid_read(WORD addr);
 
 #endif
 
