@@ -46,9 +46,13 @@
 #include "log.h"
 #include "machine.h"
 #include "maincpu.h"
+#include "network.h"
 #include "resources.h"
 #include "snapshot.h"
 #include "tape.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "ui.h"
 #include "util.h"
@@ -60,15 +64,6 @@
 #define EVENT_MILESTONE_SNAPSHOT "milestone" FSDEV_EXT_SEP_STR "vsf"
 
 
-struct event_list_s {
-    unsigned int type;
-    CLOCK clk;
-    unsigned int size;
-    void *data;
-    struct event_list_s *next;
-};
-typedef struct event_list_s event_list_t;
-
 struct event_image_list_s {
     char *orig_filename;
     char *mapped_filename;
@@ -76,7 +71,7 @@ struct event_image_list_s {
 };
 typedef struct event_image_list_s event_image_list_t;
 
-static event_list_t *event_list_base = NULL, *event_list_current;
+static event_list_state_t *event_list = NULL;
 static event_image_list_t *event_image_list_base = NULL;
 static int image_number;
 
@@ -115,15 +110,19 @@ static char *event_snapshot_path(const char *snapshot_file)
 /* searches for a filename in the image list    */
 /* returns 0 if found                           */
 /* returns 1 and appends it if not found        */
-static int event_image_append(const char *filename, char **mapped_name)
+static int event_image_append(const char *filename, 
+                              char **mapped_name, int append)
 {
     event_image_list_t *event_image_list_ptr = event_image_list_base;
 
     while (event_image_list_ptr->next != NULL) {
         if (strcmp(filename, event_image_list_ptr->next->orig_filename) == 0) {
-            if (mapped_name != NULL)
-                *mapped_name = lib_stralloc(event_image_list_ptr->next->mapped_filename);
-
+            if (mapped_name != NULL) {
+                if (append == 0)
+                    *mapped_name = lib_stralloc(event_image_list_ptr->next->mapped_filename);
+                else
+                    event_image_list_ptr->next->mapped_filename = lib_stralloc(*mapped_name);
+            }
             return 0;
         }
 
@@ -144,18 +143,15 @@ static int event_image_append(const char *filename, char **mapped_name)
 }
 
 
-void event_record_attach_image(unsigned int unit, const char *filename,
-                        unsigned int read_only)
+void event_record_attach_in_list(event_list_state_t *list, unsigned int unit,
+                                 const char *filename, unsigned int read_only)
 {
     char *event_data;
     unsigned int size;
 
-    if (record_active == 0)
-        return;
-
-    event_list_current->type = EVENT_ATTACHIMAGE;
-    event_list_current->clk = maincpu_clk;
-    event_list_current->next
+    list->current->type = EVENT_ATTACHIMAGE;
+    list->current->clk = maincpu_clk;
+    list->current->next
         = (event_list_t *)lib_calloc(1, sizeof(event_list_t));
 
     size = strlen(filename) + 3;
@@ -165,7 +161,7 @@ void event_record_attach_image(unsigned int unit, const char *filename,
     event_data[1] = read_only;
     strcpy(&event_data[2], filename);
 
-    if (event_image_append(filename, NULL) == 1) {
+    if (event_image_append(filename, NULL, 0) == 1) {
         FILE *fd;
         size_t file_len = 0;
         
@@ -185,9 +181,18 @@ void event_record_attach_image(unsigned int unit, const char *filename,
         size += file_len;
     }
 
-    event_list_current->size = size;
-    event_list_current->data = event_data;
-    event_list_current = event_list_current->next;
+    list->current->size = size;
+    list->current->data = event_data;
+    list->current = list->current->next;
+}
+
+void event_record_attach_image(unsigned int unit, const char *filename,
+                               unsigned int read_only)
+{
+    if (record_active == 0)
+        return;
+
+    event_record_attach_in_list(event_list, unit, filename, read_only);
 }
 
 
@@ -196,7 +201,7 @@ static void event_playback_attach_image(void *data, unsigned int size)
     unsigned int unit, read_only;
     char *orig_filename, *filename;
     size_t file_len;
-    char str[16];
+    char *str;
 
     unit = (unsigned int)((char*)data)[0];
     read_only = (unsigned int)((char*)data)[1];
@@ -206,26 +211,39 @@ static void event_playback_attach_image(void *data, unsigned int size)
     if (file_len > 0) {
         FILE *fd;
 
-        sprintf(str, "img%04d", image_number++);
-        filename = util_concat(event_snapshot_dir, str, FSDEV_EXT_SEP_STR,
+        str = archdep_tmpnam();
+        filename = util_concat(str, FSDEV_EXT_SEP_STR,
                                 util_get_extension(orig_filename), NULL);
+        lib_free(str);
 
         fd = fopen(filename, MODE_WRITE);
         if (fd == NULL) {
-            ui_error("Cannot create image file %s", filename);
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_CANNOT_CREATE_IMAGE_S), filename);
+#else
+            ui_error(_("Cannot create image file %s"), filename);
+#endif
             goto error;
         }
 
         if (fwrite((char*)data + strlen(orig_filename) + 3, file_len, 1, fd) != 1) {
-            ui_error("Cannot write image file %s", filename);
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_CANNOT_WRITE_IMAGE_FILE_S), filename);
+#else
+            ui_error(_("Cannot write image file %s"), filename);
+#endif
             goto error;
         }
 
         fclose(fd);
-        event_image_append(orig_filename, &filename);
+        event_image_append(orig_filename, &filename, 1);
     } else {
-        if (event_image_append(orig_filename, &filename) != 0) {
-            ui_error("Cannot find mapped name for %s", orig_filename);
+        if (event_image_append(orig_filename, &filename, 0) != 0) {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_CANNOT_FIND_MAPPED_NAME_S), orig_filename);
+#else
+            ui_error(_("Cannot find mapped name for %s"), orig_filename);
+#endif
             return;
         }
     }
@@ -245,11 +263,12 @@ error:
 }
 
 
-void event_record(unsigned int type, void *data, unsigned int size)
+void event_record_in_list(event_list_state_t *list, unsigned int type,
+                          void *data, unsigned int size)
 {
     void *event_data = NULL;
 
-    if (record_active == 0)
+    if (record_active == 0 && !network_connected())
         return;
 
     /*log_debug("EVENT RECORD %i CLK %i", type, maincpu_clk);*/
@@ -259,36 +278,47 @@ void event_record(unsigned int type, void *data, unsigned int size)
         next_timestamp_clk -= maincpu_clk;
       case EVENT_KEYBOARD_MATRIX:
       case EVENT_KEYBOARD_RESTORE:
+      case EVENT_KEYBOARD_DELAY:
       case EVENT_JOYSTICK_VALUE:
       case EVENT_DATASETTE:
       case EVENT_ATTACHDISK:
       case EVENT_ATTACHTAPE:
+      case EVENT_ATTACHIMAGE:
       case EVENT_INITIAL:
+      case EVENT_SYNC_TEST:
         event_data = lib_malloc(size);
         memcpy(event_data, data, size);
         break;
       case EVENT_LIST_END:
       case EVENT_OVERFLOW:
+      case EVENT_KEYBOARD_CLEAR:
         break;
       default:
         /*log_error(event_log, "Unknow event type %i.", type);*/
         return;
     }
 
-    event_list_current->type = type;
-    event_list_current->clk = maincpu_clk;
-    event_list_current->size = size;
-    event_list_current->data = event_data;
-    event_list_current->next
+    list->current->type = type;
+    list->current->clk = maincpu_clk;
+    list->current->size = size;
+    list->current->data = event_data;
+    list->current->next
         = (event_list_t *)lib_calloc(1, sizeof(event_list_t));
-    event_list_current = event_list_current->next;
+    list->current = list->current->next;
 }
 
+void event_record(unsigned int type, void *data, unsigned int size)
+{
+    if (!network_connected())
+        event_record_in_list(event_list, type, data, size);
+}
+
+
 static void next_alarm_set(void)
 {
     CLOCK new_value;
 
-    new_value = event_list_current->clk;
+    new_value = event_list->current->clk;
 
     if (maincpu_clk > CLKGUARD_SUB_MIN
         && new_value < maincpu_clk - CLKGUARD_SUB_MIN)
@@ -299,7 +329,7 @@ static void next_alarm_set(void)
 
 static void next_current_list(void)
 {
-    event_list_current = event_list_current->next;
+    event_list->current = event_list->current->next;
 }
 
 static void event_alarm_handler(CLOCK offset, void *data)
@@ -318,22 +348,22 @@ static void event_alarm_handler(CLOCK offset, void *data)
     /*log_debug("EVENT PLAYBACK %i CLK %i", event_list_current->type,
               event_list_current->clk);*/
 
-    switch (event_list_current->type) {
+    switch (event_list->current->type) {
       case EVENT_KEYBOARD_MATRIX:
-        keyboard_event_playback(offset, event_list_current->data);
+        keyboard_event_playback(offset, event_list->current->data);
         break;
       case EVENT_KEYBOARD_RESTORE:
-        keyboard_restore_event_playback(offset, event_list_current->data);
+        keyboard_restore_event_playback(offset, event_list->current->data);
         break;
       case EVENT_JOYSTICK_VALUE:
-        joystick_event_playback(offset, event_list_current->data);
+        joystick_event_playback(offset, event_list->current->data);
         break;
       case EVENT_DATASETTE:
-        datasette_event_playback(offset, event_list_current->data);
+        datasette_event_playback(offset, event_list->current->data);
         break;
       case EVENT_ATTACHIMAGE:
-        event_playback_attach_image(event_list_current->data,
-                                    event_list_current->size);
+        event_playback_attach_image(event_list->current->data,
+                                    event_list->current->size);
         break;
       case EVENT_ATTACHDISK:
       case EVENT_ATTACHTAPE:
@@ -342,8 +372,8 @@ static void event_alarm_handler(CLOCK offset, void *data)
             unsigned int unit;
             const char *filename;
 
-            unit = (unsigned int)((char*)event_list_current->data)[0];
-            filename = &((char*)event_list_current->data)[1];
+            unit = (unsigned int)((char*)event_list->current->data)[0];
+            filename = &((char*)event_list->current->data)[1];
             
             if (unit == 1)
                 tape_image_event_playback(unit, filename);
@@ -352,7 +382,7 @@ static void event_alarm_handler(CLOCK offset, void *data)
         }
         break;
       case EVENT_RESETCPU:
-        machine_reset_event_playback(offset, event_list_current->data);
+        machine_reset_event_playback(offset, event_list->current->data);
         break;
       case EVENT_TIMESTAMP:
         ui_display_event_time(current_timestamp++, playback_time);
@@ -363,28 +393,93 @@ static void event_alarm_handler(CLOCK offset, void *data)
       case EVENT_OVERFLOW:
         break;
       default:
-        log_error(event_log, "Unknow event type %i.", event_list_current->type);
+        log_error(event_log, "Unknow event type %i.", event_list->current->type);
     }
 
-    if (event_list_current->type != EVENT_LIST_END
-        && event_list_current->type != EVENT_RESETCPU) {
+    if (event_list->current->type != EVENT_LIST_END
+        && event_list->current->type != EVENT_RESETCPU) {
         next_current_list();
         next_alarm_set();
     }
 }
 
 /*-----------------------------------------------------------------------*/
-
-static void create_list(void)
+void event_playback_event_list(event_list_state_t *list)
 {
-    event_list_base = (event_list_t *)lib_calloc(1, sizeof(event_list_t));
-    event_list_current = event_list_base;
+    event_list_t *current = list->base;
 
+    while (current->type != EVENT_LIST_END) {
+        switch (current->type) {
+            case EVENT_SYNC_TEST:
+                break;
+            case EVENT_KEYBOARD_DELAY:
+                keyboard_register_delay(*(unsigned int*)current->data);
+                break;
+            case EVENT_KEYBOARD_MATRIX:
+                keyboard_event_delayed_playback(current->data);
+                break;
+            case EVENT_KEYBOARD_RESTORE:
+                keyboard_restore_event_playback(0, current->data);
+                break;
+            case EVENT_KEYBOARD_CLEAR:
+                keyboard_register_clear();
+                break;
+            case EVENT_JOYSTICK_DELAY:
+                joystick_register_delay(*(unsigned int*)current->data);
+                break;
+            case EVENT_JOYSTICK_VALUE:
+                joystick_event_delayed_playback(current->data);
+                break;
+            case EVENT_DATASETTE:
+                datasette_event_playback(0, current->data);
+                break;
+            case EVENT_RESETCPU:
+                machine_reset_event_playback(0, current->data);
+                break;
+            case EVENT_ATTACHDISK:
+            case EVENT_ATTACHTAPE:
+              {
+                /* in fact this is only for detaching */
+                unsigned int unit;
+
+                unit = (unsigned int)((char*)current->data)[0];
+            
+                if (unit == 1)
+                    tape_image_event_playback(1, NULL);
+                else
+                    file_system_event_playback(unit, NULL);
+                break;
+              }
+            case EVENT_ATTACHIMAGE:
+                event_playback_attach_image(current->data, current->size);
+                break;
+            default:
+                log_error(event_log, "Unknow event type %i.", current->type);
+        }
+        current = current->next;
+    }
+}
+
+void event_register_event_list(event_list_state_t *list)
+{
+    list->base = (event_list_t *)lib_calloc(1, sizeof(event_list_t));
+    list->current = list->base;
+}
+
+void event_init_image_list(void)
+{
     event_image_list_base = 
         (event_image_list_t *)lib_calloc(1, sizeof(event_image_list_t));
     image_number = 0;
 }
 
+static void create_list(void)
+{
+    event_list = (event_list_state_t *)lib_malloc(sizeof(event_list_state_t));
+    event_register_event_list(event_list);
+    event_init_image_list();
+}
+
 
 static void cut_list(event_list_t *cut_base)
 {
@@ -400,7 +495,7 @@ static void cut_list(event_list_t *cut_base)
     }
 }
 
-static void destroy_image_list(void)
+void event_destroy_image_list(void)
 {
     event_image_list_t *d1, *d2;
  
@@ -418,31 +513,35 @@ static void destroy_image_list(void)
     event_image_list_base = NULL;
 }
 
+void event_clear_list(event_list_state_t *list)
+{
+    if (list != NULL && list->base != NULL)
+        cut_list(list->base);
+}
+
 static void destroy_list(void)
 {
-    cut_list(event_list_base);
-    destroy_image_list();
-
-    event_list_base = NULL;
-    event_list_current = NULL;
+    event_clear_list(event_list);
+    lib_free(event_list);
+    event_destroy_image_list();
 }
 
 static void warp_end_list(void)
 {
     event_list_t *curr;
 
-    curr = event_list_base;
+    curr = event_list->base;
 
     while (curr->type != EVENT_LIST_END) {
 
         if (curr->type == EVENT_ATTACHIMAGE)
-            event_image_append(&((char*)curr->data)[2], NULL);
+            event_image_append(&((char*)curr->data)[2], NULL, 0);
 
         curr = curr->next;
     }
 
     memset(curr, 0, sizeof(event_list_t));
-    event_list_current = curr;
+    event_list->current = curr;
 }
 /*-----------------------------------------------------------------------*/
 /* writes or replaces version string in the initial event                */
@@ -452,36 +551,36 @@ static void event_write_version(void)
     BYTE *data;
     unsigned int ver_idx;
 
-    if (event_list_base->type != EVENT_INITIAL) {
+    if (event_list->base->type != EVENT_INITIAL) {
         /* EVENT_INITIAL is missing (bug in 1.14.xx); fix it */
         event_list_t *new_event;
 
         new_event = (event_list_t *)lib_calloc(1, sizeof(event_list_t));
-        new_event->clk = event_list_base->clk;
+        new_event->clk = event_list->base->clk;
         new_event->size = strlen(event_start_snapshot) + 2;
         new_event->type = EVENT_INITIAL;
         data = lib_malloc(new_event->size);
         data[0] = EVENT_START_MODE_FILE_SAVE;
         strcpy((char *)&data[1], event_start_snapshot);
         new_event->data = data;
-        new_event->next = event_list_base;
-        event_list_base = new_event;
+        new_event->next = event_list->base;
+        event_list->base = new_event;
     }
 
-    data = event_list_base->data;
+    data = event_list->base->data;
 
     ver_idx = 1;
     if (data[0] == EVENT_START_MODE_FILE_SAVE)
         ver_idx += strlen((char *)&data[1]) + 1;
 
-    event_list_base->size = ver_idx + strlen(VERSION) + 1;
-    new_data = lib_malloc(event_list_base->size);
+    event_list->base->size = ver_idx + strlen(VERSION) + 1;
+    new_data = lib_malloc(event_list->base->size);
 
     memcpy(new_data, data, ver_idx);
 
     strcpy((char *)&new_data[ver_idx], VERSION);
 
-    event_list_base->data = new_data;
+    event_list->base->data = new_data;
     lib_free(data);
 }
 
@@ -519,7 +618,11 @@ static void event_record_start_trap(WORD addr, void *data)
       case EVENT_START_MODE_FILE_SAVE:
         if (machine_write_snapshot(event_snapshot_path(event_start_snapshot),
                                     1, 1, 0) < 0) {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_CANT_CREATE_START_SNAP_S), 
+#else
             ui_error(_("Could not create start snapshot file %s."), 
+#endif
                         event_snapshot_path(event_start_snapshot));
             ui_display_recording(0);
             return;
@@ -534,7 +637,11 @@ static void event_record_start_trap(WORD addr, void *data)
       case EVENT_START_MODE_FILE_LOAD:
         if (machine_read_snapshot(
                 event_snapshot_path(event_end_snapshot), 1) < 0) {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_ERROR_READING_END_SNAP_S),
+#else
             ui_error(_("Error reading end snapshot file %s."),
+#endif
                         event_snapshot_path(event_end_snapshot));
             return;
         }
@@ -553,8 +660,8 @@ static void event_record_start_trap(WORD addr, void *data)
         current_timestamp = 0;
         break;
       case EVENT_START_MODE_PLAYBACK:
-        cut_list(event_list_current->next);
-        destroy_image_list();
+        cut_list(event_list->current->next);
+        event_destroy_image_list();
         event_write_version();
         record_active = 1;
         next_timestamp_clk = maincpu_clk;
@@ -597,7 +704,11 @@ static void event_record_stop_trap(WORD addr, void *data)
 {
     if (machine_write_snapshot(
             event_snapshot_path(event_end_snapshot), 1, 1, 1) < 0) {
+#ifdef HAS_TRANSLATION
+        ui_error(translate_text(IDGS_CANT_CREATE_END_SNAP_S),
+#else
         ui_error(_("Could not create end snapshot file %s."),
+#endif
                     event_snapshot_path(event_end_snapshot));
         return;
     }
@@ -630,13 +741,16 @@ static unsigned int playback_reset_ack = 0;
 
 void event_reset_ack(void)
 {
+    if (event_list == NULL)
+        return;
+
     if (playback_reset_ack) {
         playback_reset_ack = 0;
         next_alarm_set();
     }
 
-    if (event_list_current 
-        && event_list_current->type == EVENT_RESETCPU)
+    if (event_list->current 
+        && event_list->current->type == EVENT_RESETCPU)
     {
         next_current_list();
         next_alarm_set();
@@ -658,7 +772,11 @@ static void event_playback_start_trap(WORD addr, void *data)
         event_snapshot_path(event_end_snapshot), &major, &minor, machine_name);
 
     if (s == NULL) {
+#ifdef HAS_TRANSLATION
+        ui_error(translate_text(IDGS_CANT_OPEN_END_SNAP_S), 
+#else
         ui_error(_("Could not open end snapshot file %s."), 
+#endif
                     event_snapshot_path(event_end_snapshot));
         ui_display_playback(0, NULL);
         return;
@@ -669,17 +787,21 @@ static void event_playback_start_trap(WORD addr, void *data)
 
     if (event_snapshot_read_module(s, 1) < 0) {
         snapshot_close(s);
+#ifdef HAS_TRANSLATION
+        ui_error(translate_text(IDGS_CANT_FIND_SECTION_END_SNAP));
+#else
         ui_error(_("Could not find event section in end snapshot file."));
+#endif
         ui_display_playback(0, NULL);
         return;
     }
 
     snapshot_close(s);
 
-    event_list_current = event_list_base;
+    event_list->current = event_list->base;
 
-    if (event_list_current->type == EVENT_INITIAL) {
-        BYTE *data = (BYTE *)(event_list_current->data);
+    if (event_list->current->type == EVENT_INITIAL) {
+        BYTE *data = (BYTE *)(event_list->current->data);
         switch (data[0]) {
           case EVENT_START_MODE_FILE_SAVE:
             /*log_debug("READING %s", (char *)(&data[1]));*/
@@ -689,15 +811,19 @@ static void event_playback_start_trap(WORD addr, void *data)
                     event_snapshot_path(event_start_snapshot), 0) < 0)
             {
                 char *st = lib_stralloc(event_snapshot_path((char *)(&data[1])));
+#ifdef HAS_TRANSLATION
+                ui_error(translate_text(IDGS_ERROR_READING_START_SNAP_TRIED),
+#else
                 ui_error(_("Error reading start snapshot file. Tried %s and %s"),
+#endif
                             st, event_snapshot_path(event_start_snapshot));
                 lib_free(st);
                 ui_display_playback(0, NULL);
                 return;
             }
 
-            if (event_list_current->size > strlen(&data[1]) + 2)
-                strncpy(event_version, (char *)(&data[strlen(&data[1]) + 2]), 15);
+            if (event_list->current->size > strlen((char *)&data[1]) + 2)
+                strncpy(event_version, (char *)(&data[strlen((char *)&data[1]) + 2]), 15);
 
             next_current_list();
             next_alarm_set();
@@ -705,7 +831,7 @@ static void event_playback_start_trap(WORD addr, void *data)
           case EVENT_START_MODE_RESET:
             /*log_debug("RESET MODE!");*/
             machine_trigger_reset(MACHINE_RESET_MODE_HARD);
-            if (event_list_current->size > 1)
+            if (event_list->current->size > 1)
                 strncpy(event_version, (char *)(&data[1]), 15);
             next_current_list();
             /* Alarm will be set if reset is ack'ed.  */
@@ -715,7 +841,11 @@ static void event_playback_start_trap(WORD addr, void *data)
     } else {
         if (machine_read_snapshot(
                 event_snapshot_path(event_start_snapshot), 0) < 0) {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_ERROR_READING_START_SNAP));
+#else
             ui_error(_("Error reading start snapshot file."));
+#endif
             ui_display_playback(0, NULL);
             return;
         }
@@ -768,7 +898,11 @@ static void event_record_set_milestone_trap(WORD addr, void *data)
 {
     if (machine_write_snapshot(
         event_snapshot_path(event_end_snapshot), 1, 1, 1) < 0) {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_CANT_CREATE_END_SNAP_S),
+#else
             ui_error(_("Could not create end snapshot file %s."),
+#endif
                         event_snapshot_path(event_end_snapshot));
     } else {
         milestone_timestamp_alarm = next_timestamp_clk;
@@ -797,7 +931,11 @@ static void event_record_reset_milestone_trap(WORD addr, void *data)
 
     if (machine_read_snapshot(
             event_snapshot_path(event_end_snapshot), 1) < 0) {
+#ifdef HAS_TRANSLATION
+        ui_error(translate_text(IDGS_ERROR_READING_END_SNAP_S),
+#else
         ui_error(_("Error reading end snapshot file %s."),
+#endif
                     event_snapshot_path(event_end_snapshot));
         return;
     }
@@ -826,6 +964,15 @@ int event_record_reset_milestone(void)
     return 0;
 }
 
+int event_network_start(void)
+{
+    return 0;
+}
+
+int event_network_stop(void)
+{
+    return 0;
+}
 /*-----------------------------------------------------------------------*/
 
 int event_record_active(void)
@@ -859,7 +1006,7 @@ int event_snapshot_read_module(struct snapshot_s *s, int event_mode)
     destroy_list();
     create_list();
 
-    curr = event_list_base;
+    curr = event_list->base;
     num_of_timestamps = 0;
     playback_time = 0;
     next_timestamp_clk = CLOCK_MAX;
@@ -961,7 +1108,7 @@ int event_snapshot_write_module(struct snapshot_s *s, int event_mode)
     if (m == NULL)
         return -1;
 
-    curr = event_list_base;
+    curr = event_list->base;
 
     while (curr != NULL) {
         if (curr->type != EVENT_TIMESTAMP
@@ -1069,11 +1216,19 @@ static int cmdline_help(const char *param, void *extra_param)
     return event_playback_start();
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-playback", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
-      NULL, "Playback recorded events" },
+      0, IDCLS_PLAYBACK_RECORDED_EVENTS },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-playback", CALL_FUNCTION, 0, cmdline_help, NULL, NULL, NULL,
+      NULL, N_("Playback recorded events") },
+    { NULL }
+};
+#endif
 
 int event_cmdline_options_init(void)
 {
