@@ -2,7 +2,7 @@
  * fsdevice.h - File system device.
  *
  * Written by
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * Based on old code by
  *  Teemu Rantanen <tvr@cs.hut.fi>
@@ -36,8 +36,9 @@
 #ifndef _FSDEVICE_H
 #define _FSDEVICE_H
 
-extern int fsdevice_init_resources(void);
-extern int fsdevice_init_cmdline_options(void);
+extern int fsdevice_cmdline_options_init(void);
+extern int fsdevice_resources_init(void);
+extern void fsdevice_resources_shutdown(void);
 
 extern int fsdevice_attach(unsigned int device, const char *name);
 extern void fsdevice_set_directory(char *filename, unsigned int unit);
