@@ -33,9 +33,20 @@
 #include <limits.h>
 #endif
 
+#ifndef PATH_MAX
+#  ifdef MAX_PATH
+#    define PATH_MAX MAX_PATH
+#  else
+#    define PATH_MAX 1024
+#  endif
+#endif
+
 #include "archdep.h"
 #include "cmdline.h"
 #include "fsdevice.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 
 
@@ -53,17 +64,31 @@ static int cmdline_fsdirectory(const char *param, void *extra_param)
     return 0;
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-fs8", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)8, NULL, NULL,
-      "<name>", "Use <name> as directory for file system device #8" },
+      IDCLS_P_NAME, IDCLS_USE_AS_DIRECTORY_FSDEVICE_8 },
     { "-fs9", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)9, NULL, NULL,
-      "<name>", "Use <name> as directory for file system device #9" },
+      IDCLS_P_NAME, IDCLS_USE_AS_DIRECTORY_FSDEVICE_9 },
     { "-fs10", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)10, NULL, NULL,
-      "<name>", "Use <name> as directory for file system device #10" },
+      IDCLS_P_NAME, IDCLS_USE_AS_DIRECTORY_FSDEVICE_10 },
     { "-fs11", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)11, NULL, NULL,
-      "<name>", "Use <name> as directory for file system device #11" },
+      IDCLS_P_NAME, IDCLS_USE_AS_DIRECTORY_FSDEVICE_11 },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-fs8", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)8, NULL, NULL,
+      N_("<name>"), N_("Use <name> as directory for file system device #8") },
+    { "-fs9", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)9, NULL, NULL,
+      N_("<name>"), N_("Use <name> as directory for file system device #9") },
+    { "-fs10", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)10, NULL, NULL,
+      N_("<name>"), N_("Use <name> as directory for file system device #10") },
+    { "-fs11", CALL_FUNCTION, 1, cmdline_fsdirectory, (void *)11, NULL, NULL,
+      N_("<name>"), N_("Use <name> as directory for file system device #11") },
+    { NULL }
+};
+#endif
 
 int fsdevice_cmdline_options_init(void)
 {
