@@ -31,6 +31,14 @@
 #include <limits.h>
 #endif
 
+#ifndef PATH_MAX
+#  ifdef MAX_PATH
+#    define PATH_MAX MAX_PATH
+#  else
+#    define PATH_MAX 1024
+#  endif
+#endif
+
 #include "tape.h"
 #include "types.h"
 
