@@ -39,8 +39,34 @@
 #include "palette.h"
 #include "resources.h"
 #include "screenshot.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "ui.h"
+#include "util.h"
+#include "vsync.h"
 
+static ffmpegdrv_codec_t avi_audio_codeclist[] = { 
+    { CODEC_ID_MP2, "MP2" },
+    { CODEC_ID_MP3, "MP3" },
+    { 0, NULL }
+};
+
+static ffmpegdrv_codec_t avi_video_codeclist[] = { 
+    { CODEC_ID_MPEG4, "MPEG4 (DivX)" },
+    { CODEC_ID_MPEG1VIDEO, "MPEG1" },
+    { CODEC_ID_FFV1, "FFV1 (lossless)" },
+    { 0, NULL }
+};
+
+ffmpegdrv_format_t ffmpegdrv_formatlist[] =
+{
+    { "avi", avi_audio_codeclist, avi_video_codeclist },
+    { "wav", NULL, NULL },
+    { "mp3", NULL, NULL },
+    { "mp2", NULL, NULL },
+    { NULL, NULL, NULL }
+};
 
 /* general */
 static ffmpeglib_t ffmpeglib;
@@ -69,11 +95,31 @@ static AVFrame *picture, *tmp_picture;
 static double video_pts;
 
 /* resources */
+static char *ffmpeg_format = NULL;
+static int format_index;
 static int audio_bitrate;
 static int video_bitrate;
+static int audio_codec;
+static int video_codec;
 
 static int ffmpegdrv_init_file(void);
 
+static int set_format(resource_value_t v, void *param)
+{
+    int i;
+
+    format_index = -1;
+    util_string_set(&ffmpeg_format, (const char *)v);
+    for (i = 0; ffmpegdrv_formatlist[i].name != NULL; i++)
+        if (strcmp(ffmpeg_format, ffmpegdrv_formatlist[i].name) == 0)
+            format_index = i;
+
+    if (format_index < 0)
+        return -1;
+    else
+        return 0;
+}
+
 static int set_audio_bitrate(resource_value_t v, void *param)
 {
     audio_bitrate = (CLOCK)v;
@@ -86,20 +132,42 @@ static int set_audio_bitrate(resource_value_t v, void *param)
 static int set_video_bitrate(resource_value_t v, void *param)
 {
     video_bitrate = (CLOCK)v;
-    if (video_bitrate < 100000 || audio_bitrate > 10000000)
+    if (video_bitrate < 100000 || video_bitrate > 10000000)
         video_bitrate = 800000;
 
     return 0;
 }
 
+static int set_audio_codec(resource_value_t v, void *param)
+{
+    audio_codec = (int)v;
+    return 0;
+}
+
+static int set_video_codec(resource_value_t v, void *param)
+{
+    video_codec = (int)v;
+    return 0;
+
+}
+
 /*---------- Resources ------------------------------------------------*/
 static const resource_t resources[] = {
+    { "FFMPEGFormat", RES_STRING, (resource_value_t)"avi",
+      (void *)&ffmpeg_format,
+      set_format, NULL },
     { "FFMPEGAudioBitrate", RES_INTEGER, (resource_value_t)64000,
       (void *)&audio_bitrate,
       set_audio_bitrate, NULL },
     { "FFMPEGVideoBitrate", RES_INTEGER, (resource_value_t)800000,
       (void *)&video_bitrate,
       set_video_bitrate, NULL },
+    { "FFMPEGAudioCodec", RES_INTEGER, (resource_value_t)CODEC_ID_MP3,
+      (void *)&audio_codec,
+      set_audio_codec, NULL },
+    { "FFMPEGVideoCodec", RES_INTEGER, (resource_value_t)CODEC_ID_MPEG4,
+      (void *)&video_codec,
+      set_video_codec, NULL },
     { NULL }
 };
 
@@ -113,16 +181,27 @@ int ffmpegdrv_resources_init(void)
 
 /*---------- Commandline options --------------------------------------*/
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-ffmpegaudiobitrate", SET_RESOURCE, 1, NULL, NULL,
       "FFMPEGAudioBitrate", NULL,
-      "<value>", "Set bitrate for audio stream in media file" },
+      IDCLS_P_VALUE, IDCLS_SET_AUDIO_STREAM_BITRATE },
     { "-ffmpegvideobitrate", SET_RESOURCE, 1, NULL, NULL,
       "FFMPEGVideoBitrate", NULL,
-      "<value>", "Set bitrate for video stream in media file" },
+      IDCLS_P_VALUE, IDCLS_SET_VIDEO_STREAM_BITRATE },
     { NULL }
 };
-
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-ffmpegaudiobitrate", SET_RESOURCE, 1, NULL, NULL,
+      "FFMPEGAudioBitrate", NULL,
+      N_("<value>"), N_("Set bitrate for audio stream in media file") },
+    { "-ffmpegvideobitrate", SET_RESOURCE, 1, NULL, NULL,
+      "FFMPEGVideoBitrate", NULL,
+      N_("<value>"), N_("Set bitrate for video stream in media file") },
+    { NULL }
+};
+#endif
 
 int ffmpegdrv_cmdline_options_init(void)
 {
@@ -249,10 +328,9 @@ void ffmpegdrv_init_audio(int speed, int channels,
 /* triggered by soundffmpegaudio->write */
 void ffmpegdrv_encode_audio(ffmpegdrv_audio_in_t *audio_in)
 {
-    int out_size;
-    
     if (audio_st) {
-        out_size = (*ffmpeglib.p_avcodec_encode_audio)(&audio_st->codec, 
+#if FFMPEG_VERSION_INT==0x000408
+        int out_size = (*ffmpeglib.p_avcodec_encode_audio)(&audio_st->codec, 
                         audio_outbuf, audio_outbuf_size, audio_in->buffer);
         /* FIXME: Some sync needed ?? */
     
@@ -262,6 +340,25 @@ void ffmpegdrv_encode_audio(ffmpegdrv_audio_in_t *audio_in)
 
         audio_pts = (double)audio_st->pts.val * ffmpegdrv_oc->pts_num 
                     / ffmpegdrv_oc->pts_den;
+#else
+        AVPacket pkt;
+        AVCodecContext *c;
+        av_init_packet(&pkt);
+        c = &audio_st->codec;
+        pkt.size = (*ffmpeglib.p_avcodec_encode_audio)(c, 
+                        audio_outbuf, audio_outbuf_size, audio_in->buffer);
+        pkt.pts = c->coded_frame->pts;
+        pkt.flags |= PKT_FLAG_KEY;
+        pkt.stream_index = audio_st->index;
+        pkt.data = audio_outbuf;
+
+        if ((*ffmpeglib.p_av_write_frame)(ffmpegdrv_oc, &pkt) != 0)
+            log_debug("ffmpegdrv_encode_audio: Error while writing audio frame");
+
+        audio_pts = (double)audio_st->pts.val * audio_st->time_base.num 
+                    / audio_st->time_base.den;
+#endif
+
     }
 
     audio_in->used = 0;
@@ -310,6 +407,8 @@ static AVFrame* ffmpegdrv_alloc_picture(int pix_fmt, int width, int height)
     picture = (AVFrame*)lib_malloc(sizeof(AVFrame));
     memset(picture, 0, sizeof(AVFrame));
 
+    picture->pts = AV_NOPTS_VALUE;
+
     size = (*ffmpeglib.p_avpicture_get_size)(pix_fmt, width, height);
     picture_buf = (unsigned char *)lib_malloc(size);
     memset(picture_buf, 0, size);
@@ -429,9 +528,12 @@ static void ffmpegdrv_init_video(screenshot_t *screenshot)
     video_width = c->width = (screenshot->width + 15) & ~0xf; 
     video_height = c->height = (screenshot->height + 15) & ~0xf;
     /* frames per second */
-    c->frame_rate = 50;  /* FIXME */
+    c->frame_rate = (int)(vsync_get_refresh_frequency() + 0.5);
     c->frame_rate_base = 1;
     c->gop_size = 12; /* emit one intra frame every twelve frames at most */
+    /* FFV1 isn't strict standard compliant */
+    if (c->codec_id == CODEC_ID_FFV1)
+        c->strict_std_compliance = -1;
 
     video_st = st;
     video_pts = 0;
@@ -454,12 +556,20 @@ static int ffmpegdrv_init_file(void)
     (*ffmpeglib.p_dump_format)(ffmpegdrv_oc, 0, ffmpegdrv_oc->filename, 1);
 
     if (video_st && (ffmpegdrv_open_video(ffmpegdrv_oc, video_st) < 0)) {
+#ifdef HAS_TRANSLATION
+        ui_error(translate_text(IDGS_FFMPEG_CANNOT_OPEN_VSTREAM));
+#else
         ui_error(_("ffmpegdrv: Cannot open video stream"));
+#endif
         screenshot_stop_recording();
         return -1;
     }
     if (audio_st && (ffmpegdrv_open_audio(ffmpegdrv_oc, audio_st) < 0)) {
+#ifdef HAS_TRANSLATION
+        ui_error(translate_text(IDGS_FFMPEG_CANNOT_OPEN_ASTREAM));
+#else
         ui_error(_("ffmpegdrv: Cannot open audio stream"));
+#endif
         screenshot_stop_recording();
         return -1;
     }
@@ -468,7 +578,11 @@ static int ffmpegdrv_init_file(void)
         if ((*ffmpeglib.p_url_fopen)(&ffmpegdrv_oc->pb, ffmpegdrv_oc->filename,
                             URL_WRONLY) < 0) 
         {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_FFMPEG_CANNOT_OPEN_S), ffmpegdrv_oc->filename);
+#else
             ui_error(_("ffmpegdrv: Cannot open %s"), ffmpegdrv_oc->filename);
+#endif
             screenshot_stop_recording();
             return -1;
         }
@@ -494,7 +608,7 @@ static int ffmpegdrv_save(screenshot_t *screenshot, const char *filename)
     video_init_done = 0;
     file_init_done = 0;
 
-    ffmpegdrv_fmt = (*ffmpeglib.p_guess_format)(NULL, filename, NULL);
+    ffmpegdrv_fmt = (*ffmpeglib.p_guess_format)(ffmpeg_format, NULL, NULL);
 
     if (!ffmpegdrv_fmt)
         ffmpegdrv_fmt = (*ffmpeglib.p_guess_format)("mpeg", NULL, NULL);
@@ -504,12 +618,21 @@ static int ffmpegdrv_save(screenshot_t *screenshot, const char *filename)
         return -1;
     }
 
-    /* force MP3 audio stream for MPEG4 video streams */
-    if (ffmpegdrv_fmt->video_codec == CODEC_ID_MPEG4 
-        && ffmpegdrv_fmt->audio_codec == CODEC_ID_MP2 
-        && (*ffmpeglib.p_avcodec_find_encoder)(CODEC_ID_MP3) != NULL)
-    {
-        ffmpegdrv_fmt->audio_codec = CODEC_ID_MP3;
+    if (format_index >= 0) {
+
+        ffmpegdrv_format_t *format = &ffmpegdrv_formatlist[format_index];
+
+        if (format->audio_codecs !=NULL
+            && (*ffmpeglib.p_avcodec_find_encoder)(audio_codec) != NULL)
+        {
+            ffmpegdrv_fmt->audio_codec = audio_codec;
+        }
+
+        if (format->video_codecs !=NULL
+            && (*ffmpeglib.p_avcodec_find_encoder)(video_codec) != NULL)
+        {
+            ffmpegdrv_fmt->video_codec = video_codec;
+        }
     }
 
     ffmpegdrv_oc = (AVFormatContext*)lib_malloc(sizeof(AVFormatContext));
@@ -553,7 +676,8 @@ static int ffmpegdrv_close(screenshot_t *screenshot)
     
     /* free the streams */
     for(i = 0; i < ffmpegdrv_oc->nb_streams; i++) {
-        (*ffmpeglib.p___av_freep)((void**)&ffmpegdrv_oc->streams[i]);
+        (*ffmpeglib.p_av_free)((void *)ffmpegdrv_oc->streams[i]);
+        ffmpegdrv_oc->streams[i] = NULL;
     }
 
 
@@ -601,8 +725,19 @@ static int ffmpegdrv_record(screenshot_t *screenshot)
     if (ffmpegdrv_oc->oformat->flags & AVFMT_RAWPICTURE) {
         /* raw video case. The API will change slightly in the near
            futur for that */
+#if FFMPEG_VERSION_INT==0x000408
         ret = (*ffmpeglib.p_av_write_frame)(ffmpegdrv_oc, video_st->index,
                        (unsigned char *)picture, sizeof(AVPicture));
+#else
+        AVPacket pkt;
+        av_init_packet(&pkt);
+        pkt.flags |= PKT_FLAG_KEY;
+        pkt.stream_index = video_st->index;
+        pkt.data = (uint8_t*)picture;
+        pkt.size = sizeof(AVPicture);
+
+        ret = (*ffmpeglib.p_av_write_frame)(ffmpegdrv_oc, &pkt);
+#endif
     } else {
         /* encode the image */
         out_size = (*ffmpeglib.p_avcodec_encode_video)(c, video_outbuf, 
@@ -610,9 +745,20 @@ static int ffmpegdrv_record(screenshot_t *screenshot)
         /* if zero size, it means the image was buffered */
         if (out_size != 0) {
             /* write the compressed frame in the media file */
-            /* XXX: in case of B frames, the pts is not yet valid */
+#if FFMPEG_VERSION_INT==0x000408
             ret = (*ffmpeglib.p_av_write_frame)(ffmpegdrv_oc, video_st->index,
                                         video_outbuf, out_size);
+#else
+            AVPacket pkt;
+            av_init_packet(&pkt);
+            pkt.pts = c->coded_frame->pts;
+            if (c->coded_frame->key_frame)
+                pkt.flags |= PKT_FLAG_KEY;
+            pkt.stream_index = video_st->index;
+            pkt.data = video_outbuf;
+            pkt.size = out_size;
+            ret = (*ffmpeglib.p_av_write_frame)(ffmpegdrv_oc, &pkt);
+#endif
         } else {
             ret = 0;
         }
@@ -622,8 +768,13 @@ static int ffmpegdrv_record(screenshot_t *screenshot)
         return -1;
     }
 
+#if FFMPEG_VERSION_INT==0x000408
     video_pts = (double)video_st->pts.val * ffmpegdrv_oc->pts_num 
                     / ffmpegdrv_oc->pts_den;
+#else
+    video_pts = (double)video_st->pts.val * video_st->time_base.num 
+                    / video_st->time_base.den;
+#endif
 
     return 0;
 }
@@ -638,15 +789,16 @@ static int ffmpegdrv_write(screenshot_t *screenshot)
 static gfxoutputdrv_t ffmpeg_drv[] = {
     {
         "FFMPEG",
-        "AVI video (MPEG4/MP3)",
-        "avi",
+        "FFMPEG",
+        NULL,
         NULL,
         ffmpegdrv_close,
         ffmpegdrv_write,
         ffmpegdrv_save,
         ffmpegdrv_record
     },
-    {
+/*
+{
         "FFMPEG",
         "MPEG video (MPEG1/MP2)",
         "mpeg",
@@ -676,6 +828,7 @@ static gfxoutputdrv_t ffmpeg_drv[] = {
         ffmpegdrv_save,
         ffmpegdrv_record
     },
+*/
     { NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL }
 };
 
@@ -695,5 +848,6 @@ void gfxoutput_init_ffmpeg(void)
 void ffmpegdrv_shutdown(void)
 {
     ffmpeglib_close(&ffmpeglib);
+    lib_free(ffmpeg_format);
 }
 
