@@ -25,9 +25,6 @@
  *
  */
 
-/* FIXME: For now, we avoid ISO characters completely to avoid problems with
-   MS-DOS.  But we should provide some automatic conversion instead.  */
-
 const char info_license_text[] =
 "                 GNU GENERAL PUBLIC LICENSE\n"
 "                    Version 2, June 1991\n"
@@ -372,17 +369,19 @@ const char info_contrib_text[] =
 "  datasette support, the VIC20 video emulation and some ui stuff\n"
 "  in the Win32 and MSDOS port. He also wrote the BeOS port and\n"
 "  implemented video/audio capture support.\n"
+"  Improved history recording/playback and implented support for\n"
+"  video recording and netlink feature. Various bug(fixe)s. ;-)\n"
 "\n"
 "  Martin Pottendorfer <Martin.Pottendorfer@aut.alcatel.at>\n"
 "  Implemented Gnome Port based on Oliver Schaertels GTK+ port\n"
 "  Added support code for internationalization based on gettext\n"
-"  Translated the Unix Port to German\n"
+"  Translated the UI to German\n"
 "  Implemented the fliplists + ui (unix).\n"
 "\n"
 "  Spiro Trikaliotis <Spiro.Trikaliotis@gmx.de> wrote the Win32\n"
 "  console implementation for the built-in monitor, corrected some\n"
-"  REU related bugs, added support for the TFE and RR-Net (cs8900a),\n"
-"  and wrote some further patches.\n"
+"  REU related bugs, added support for the TFE and RR-Net\n"
+"  (cs8900a), and wrote some further patches.\n"
 "\n"
 "  David Hansel <david@hansels.net> wrote the Star NL10 printer\n"
 "  driver, implemented IEC devices and improved the tape emulation.\n"
@@ -390,6 +389,14 @@ const char info_contrib_text[] =
 "  Markus Brenner <markus@brenner.de> added VDC emulation to x128\n"
 "  and added support for some more cartridges.\n"
 "\n"
+"  Marco van den Heuvel <blackystardust68@yahoo.com> Translated\n"
+"  the UI to Dutch. Internationalization support for the Win32\n"
+"  port. Wrote the GEORAM and RamCart cartridge code. Wrote the\n"
+"  c64 +60K and 256K expansions code. Made the ethernet support for\n"
+"  the Msdos port. Maintains the QNX 6.x, Solaris and newly\n"
+"  resurrected OS/2 binary ports. Added new .crt support. Added new\n"
+"  screenshot formats. And lots of other fixes.\n"
+"\n"
 "Former team members:\n"
 "\n"
 "  Daniel Sladic <sladic@eecg.toronto.edu>\n"
@@ -450,7 +457,7 @@ const char info_contrib_text[] =
 "  VICE `deb' package for the Debian distribution, and also\n"
 "  helped proofreading the documentation.\n"
 "\n"
-"  Marko M\"akel\"a <msmakela@nic.funet.fi> wrote lots of CPU\n"
+"  Marko Mkel <msmakela@nic.funet.fi> wrote lots of CPU\n"
 "  documentation.\n"
 "\n"
 "  Chris Sharp <sharpc@hurlsey.ibm.com> wrote the AIX sound\n"
@@ -541,17 +548,16 @@ const char info_contrib_text[] =
 "  text lister.\n"
 "\n"
 "  Peter Karlsson <peter@softwolves.pp.se> provided the swedish\n"
-"  translation for the Unix ports.\n"
+"  UI translations.\n"
 "\n"
-"  Paul Dub <dube.paul@sympatico.ca> alias Kaddict\n"
-"  Translated the Unix Port to French\n"
-"  Will work on translations to the other ports, Win32 first\n"
+"  Paul Dub from Rivire-du-Loup, Qubec, provided the french\n"
+"  translation for both Unix and Windows ports"
 "\n"
 "  Nathan Huizinga <nathan.huizinga@chess.nl> added support for\n"
 "  Expert and Super Snapshot carts.\n"
 "\n"
 "  Andrea Musuruane <musuruan@bmm.it> provided the italian\n"
-"  translation for the Unix ports\n" 
+"  UI translations.\n" 
 "\n"
 "  Flooder <flooder@gower.pl> provided the polish\n"
 "  translation for the Unix ports\n" 
@@ -599,6 +605,8 @@ const char info_contrib_text[] =
 "\n"
 "  Rami Rasanen <raipe@neutech.fi> rewrote the VIC20 sound code.\n"
 "\n"
+"  iAN CooG <ian7102@libero.it> contributed various small patches.\n"
+"\n"
 "(We hope we have not forgotten anybody; if you think we have,\n"
 "please tell us.)\n"
 "\n"
