@@ -41,6 +41,7 @@
 #include "joy.h"
 #include "joystick.h"
 #include "maincpu.h"
+#include "network.h"
 #include "snapshot.h"
 #include "ui.h"
 #include "types.h"
@@ -55,6 +56,7 @@ BYTE joystick_value[JOYSTICK_NUM] = { 0, 0, 0 };
 
 /* Latched joystick status.  */
 static BYTE latch_joystick_value[JOYSTICK_NUM] = { 0, 0, 0 };
+static BYTE network_joystick_value[JOYSTICK_NUM] = { 0, 0, 0 };
 
 /* to prevent illegal direction combinations */
 static const BYTE joystick_opposite_direction[] = 
@@ -62,10 +64,25 @@ static const BYTE joystick_opposite_direction[] =
 
 static alarm_t *joystick_alarm = NULL;
 
+static CLOCK joystick_delay;
 
 static void joystick_latch_matrix(CLOCK offset)
 {
-    memcpy(joystick_value, latch_joystick_value, sizeof(joystick_value));
+    BYTE idx;
+
+    if (network_connected()) {
+        idx = network_joystick_value[0];
+        if (idx > 0)
+            joystick_value[idx] = network_joystick_value[idx];
+        else
+            memcpy(joystick_value, network_joystick_value, sizeof(joystick_value));
+    } else {
+        idx = latch_joystick_value[0];
+        if (idx > 0)
+            joystick_value[idx] = latch_joystick_value[idx];
+        else
+            memcpy(joystick_value, latch_joystick_value, sizeof(joystick_value));
+    }
     ui_display_joyport(joystick_value);
 }
 
@@ -94,20 +111,42 @@ static void joystick_latch_handler(CLOCK offset, void *data)
     joystick_event_record(); 
 }
 
+void joystick_event_delayed_playback(void *data)
+{
+    memcpy(network_joystick_value, data, sizeof(latch_joystick_value));
+    alarm_set(joystick_alarm, maincpu_clk + joystick_delay);
+}
+
+void joystick_register_delay(unsigned int delay)
+{
+    joystick_delay = delay;
+}
 /*-----------------------------------------------------------------------*/
+static void joystick_process_latch(void)
+{
+    if (network_connected()) {
+        CLOCK joystick_delay = JOYSTICK_RAND();
+        network_event_record(EVENT_JOYSTICK_DELAY,
+                (void *)&joystick_delay, sizeof(joystick_delay));
+        network_event_record(EVENT_JOYSTICK_VALUE, 
+                (void *)latch_joystick_value, sizeof(latch_joystick_value));
+    } 
+    else
+    {
+        alarm_set(joystick_alarm, maincpu_clk + JOYSTICK_RAND());
+    }
+}
 
 void joystick_set_value_absolute(unsigned int joyport, BYTE value)
 {
     if (event_playback_active())
         return;
 
-    latch_joystick_value[joyport] = value;
-    alarm_set(joystick_alarm, maincpu_clk + JOYSTICK_RAND());
-}
-
-BYTE joystick_get_value_absolute(unsigned int joyport)
-{
-    return latch_joystick_value[joyport];
+    if (latch_joystick_value[joyport] != value) {
+        latch_joystick_value[joyport] = value;
+        latch_joystick_value[0] = (BYTE)joyport;
+        joystick_process_latch();
+    }
 }
 
 void joystick_set_value_or(unsigned int joyport, BYTE value)
@@ -117,7 +156,8 @@ void joystick_set_value_or(unsigned int joyport, BYTE value)
 
     latch_joystick_value[joyport] |= value;
     latch_joystick_value[joyport] &= ~joystick_opposite_direction[value & 0xf];
-    alarm_set(joystick_alarm, maincpu_clk + JOYSTICK_RAND());
+    latch_joystick_value[0] = (BYTE)joyport;
+    joystick_process_latch();
 }
 
 void joystick_set_value_and(unsigned int joyport, BYTE value)
@@ -126,12 +166,14 @@ void joystick_set_value_and(unsigned int joyport, BYTE value)
         return;
 
     latch_joystick_value[joyport] &= value;
-    alarm_set(joystick_alarm, maincpu_clk + JOYSTICK_RAND());
+    latch_joystick_value[0] = (BYTE)joyport;
+    joystick_process_latch();
 }
 
 void joystick_clear(unsigned int joyport)
 {
     latch_joystick_value[joyport] = 0;
+    latch_joystick_value[0] = (BYTE)joyport;
     joystick_latch_matrix(0);
 }
 
