@@ -42,9 +42,11 @@ extern void joystick_set_value_or(unsigned int joyport, BYTE value);
 extern void joystick_set_value_and(unsigned int joyport, BYTE value);
 extern void joystick_clear(unsigned int joyport);
 extern void joystick_clear_all(void);
-extern BYTE joystick_get_value_absolute(unsigned int joyport);
 
 extern void joystick_event_playback(CLOCK offset, void *data);
+extern void joystick_event_delayed_playback(void *data);
+extern void joystick_register_delay(unsigned int delay);
+
 extern int joystick_snapshot_write_module(struct snapshot_s *s);
 extern int joystick_snapshot_read_module(struct snapshot_s *s);
 
