@@ -38,6 +38,9 @@
 #include "lib.h"
 #include "maincpu.h"
 #include "mem.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 
 
@@ -119,12 +122,21 @@ static int kdb_buf_feed_cmdline(const char *param, void *extra_param)
     return 0;
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
     { "-keybuf", CALL_FUNCTION, 1, kdb_buf_feed_cmdline, NULL, NULL, NULL,
-      "<string>", "Put the specified string into the keyboard buffer" },
+      IDCLS_P_STRING, IDCLS_PUT_STRING_INTO_KEYBUF },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] =
+{
+    { "-keybuf", CALL_FUNCTION, 1, kdb_buf_feed_cmdline, NULL, NULL, NULL,
+      N_("<string>"), N_("Put the specified string into the keyboard buffer") },
+    { NULL }
+};
+#endif
 
 int kbdbuf_cmdline_options_init(void)
 {
