@@ -46,6 +46,7 @@
 #include "log.h"
 #include "machine.h"
 #include "maincpu.h"
+#include "network.h"
 #include "resources.h"
 #include "snapshot.h"
 #include "sysfile.h"
@@ -63,18 +64,31 @@ int rev_keyarr[KBD_COLS];
 static int latch_keyarr[KBD_ROWS];
 static int latch_rev_keyarr[KBD_COLS];
 
+static int network_keyarr[KBD_ROWS];
+static int network_rev_keyarr[KBD_COLS];
+
 static alarm_t *keyboard_alarm;
 
 static log_t keyboard_log = LOG_DEFAULT;
 
 static keyboard_machine_func_t keyboard_machine_func = NULL;
 
+static CLOCK keyboard_delay;
+
+static int keyboard_clear = 0;
 
 static void keyboard_latch_matrix(CLOCK offset)
 {
-    memcpy(keyarr, latch_keyarr, sizeof(keyarr));
-    memcpy(rev_keyarr, latch_rev_keyarr, sizeof(rev_keyarr));
-
+    if (network_connected())
+    {
+        memcpy(keyarr, network_keyarr, sizeof(keyarr));
+        memcpy(rev_keyarr, network_rev_keyarr, sizeof(rev_keyarr));
+    }
+    else
+    {
+        memcpy(keyarr, latch_keyarr, sizeof(keyarr));
+        memcpy(rev_keyarr, latch_rev_keyarr, sizeof(rev_keyarr));
+    }
     if (keyboard_machine_func != NULL)
         keyboard_machine_func(keyarr);
 }
@@ -95,6 +109,7 @@ static int keyboard_set_latch_keyarr(int row, int col, int value)
 }
 
 /*-----------------------------------------------------------------------*/
+static void keyboard_key_clear_internal(void);
 
 static void keyboard_event_record(void)
 {
@@ -131,6 +146,30 @@ static void keyboard_latch_handler(CLOCK offset, void *data)
     keyboard_event_record();
 }
 
+void keyboard_event_delayed_playback(void *data)
+{
+    int row, col;
+
+    memcpy(network_keyarr, data, sizeof(network_keyarr));
+
+    for (row = 0; row < KBD_ROWS; row++) {
+        for (col = 0; col < KBD_COLS; col++) {
+            if (network_keyarr[row] & (1 << col))
+                network_rev_keyarr[col] |= 1 << row;
+            else
+                network_rev_keyarr[col] &= ~(1 << row);
+        }
+    }
+
+    if (keyboard_clear == 1) {
+#ifdef COMMON_KBD
+        keyboard_key_clear_internal();
+#endif
+        keyboard_clear = 0;
+    }
+
+    alarm_set(keyboard_alarm, maincpu_clk + keyboard_delay);
+}
 /*-----------------------------------------------------------------------*/
 
 void keyboard_set_keyarr(int row, int col, int value)
@@ -141,14 +180,6 @@ void keyboard_set_keyarr(int row, int col, int value)
     alarm_set(keyboard_alarm, maincpu_clk + KEYBOARD_RAND());
 }
 
-void keyboard_set_keyarr_and_latch(int row, int col, int value)
-{
-    if (keyboard_set_latch_keyarr(row, col, value) < 0)
-        return;
-
-    keyboard_latch_matrix(0);
-}
-
 void keyboard_clear_keymatrix(void)
 {
     memset(keyarr, 0, sizeof(keyarr));
@@ -162,6 +193,15 @@ void keyboard_register_machine(keyboard_machine_func_t func)
     keyboard_machine_func = func;
 }
 
+void keyboard_register_delay(unsigned int delay)
+{
+    keyboard_delay = delay;
+}
+
+void keyboard_register_clear(void)
+{
+    keyboard_clear = 1;
+}
 /*-----------------------------------------------------------------------*/
 
 #ifdef COMMON_KBD
@@ -257,10 +297,19 @@ void keyboard_key_pressed(signed long key)
 
     /* Restore */
     if (((key == key_ctrl_restore1) || (key == key_ctrl_restore2))
-        && machine_set_restore_key(1))
+        && machine_has_restore_key())
     {
-        event_data = (DWORD)1;
-        event_record(EVENT_KEYBOARD_RESTORE, (void*)&event_data, sizeof(DWORD));
+            event_data = (DWORD)1;
+        if (network_connected()) {
+            network_event_record(EVENT_KEYBOARD_RESTORE, 
+                    (void*)&event_data, sizeof(DWORD));
+        }
+        else
+        {
+            machine_set_restore_key(1);
+            event_record(EVENT_KEYBOARD_RESTORE, 
+                        (void*)&event_data, sizeof(DWORD));
+        }
         return;
     }
 
@@ -286,7 +335,7 @@ void keyboard_key_pressed(signed long key)
 
     latch = 0;
 
-    for (i = 0; keyconvmap[i].sym != 0; ++i) {
+    for (i = 0; i < keyc_num; ++i) {
         if (key == keyconvmap[i].sym) {
             if (keyboard_key_pressed_matrix(keyconvmap[i].row,
                                             keyconvmap[i].column,
@@ -301,7 +350,17 @@ void keyboard_key_pressed(signed long key)
 
     if (latch) {
         keyboard_set_latch_keyarr(key_latch_row, key_latch_column, 1);
-        alarm_set(keyboard_alarm, maincpu_clk + KEYBOARD_RAND());
+        if (network_connected()) {
+            CLOCK keyboard_delay = KEYBOARD_RAND();
+            network_event_record(EVENT_KEYBOARD_DELAY,
+                    (void *)&keyboard_delay, sizeof(keyboard_delay));
+            network_event_record(EVENT_KEYBOARD_MATRIX, 
+                    (void *)latch_keyarr, sizeof(latch_keyarr));
+        }
+        else
+        {
+            alarm_set(keyboard_alarm, maincpu_clk + KEYBOARD_RAND());
+        }
     }
 }
 
@@ -347,10 +406,19 @@ void keyboard_key_released(signed long key)
 
     /* Restore */
     if (((key == key_ctrl_restore1) || (key == key_ctrl_restore2))
-        && machine_set_restore_key(0))
+        && machine_has_restore_key())
     {
         event_data = (DWORD)0;
-        event_record(EVENT_KEYBOARD_RESTORE, (void *)&event_data, sizeof(DWORD));
+        if (network_connected()) {
+            network_event_record(EVENT_KEYBOARD_RESTORE, 
+                    (void*)&event_data, sizeof(DWORD));
+        }
+        else
+        {
+            machine_set_restore_key(0);
+            event_record(EVENT_KEYBOARD_RESTORE, (void *)&event_data, 
+                sizeof(DWORD));
+        }
         return;
     }
 
@@ -364,7 +432,7 @@ void keyboard_key_released(signed long key)
 
     latch = 0;
 
-    for (i = 0; keyconvmap[i].sym != 0; i++) {
+    for (i = 0; i < keyc_num; i++) {
         if (key == keyconvmap[i].sym) {
             if (keyboard_key_released_matrix(keyconvmap[i].row,
                                              keyconvmap[i].column,
@@ -380,21 +448,39 @@ void keyboard_key_released(signed long key)
     }
 
     if (latch) {
-        /*keyboard_set_latch_keyarr(key_latch_row, key_latch_column, 0);*/
-        alarm_set(keyboard_alarm, maincpu_clk + KEYBOARD_RAND());
+        if (network_connected()) {
+            CLOCK keyboard_delay = KEYBOARD_RAND();
+            network_event_record(EVENT_KEYBOARD_DELAY,
+                        (void *)&keyboard_delay, sizeof(keyboard_delay));
+            network_event_record(EVENT_KEYBOARD_MATRIX, 
+                        (void *)latch_keyarr, sizeof(latch_keyarr));
+        }
+        else
+        {
+            alarm_set(keyboard_alarm, maincpu_clk + KEYBOARD_RAND());
+        }
     }
 }
 
+static void keyboard_key_clear_internal(void)
+{
+    keyboard_clear_keymatrix();
+    joystick_clear_all();
+    virtual_shift_down = left_shift_down = right_shift_down = 0;
+    joystick_joypad_clear();
+}
+
 void keyboard_key_clear(void)
 {
     if (event_playback_active())
         return;
 
-    keyboard_clear_keymatrix();
-    joystick_clear_all();
-    virtual_shift_down = left_shift_down = right_shift_down = 0;
-    joystick_joypad_clear();
-    return;
+    if (network_connected()) {
+        network_event_record(EVENT_KEYBOARD_CLEAR, NULL, 0);
+        return;
+    }
+
+    keyboard_key_clear_internal();
 }
 
 /*-----------------------------------------------------------------------*/
@@ -541,7 +627,7 @@ static void keyboard_parse_set_pos_row(signed long sym, int row, int col,
 {
     int i;
 
-    for (i = 0; keyconvmap[i].sym; i++) {
+    for (i = 0; i < keyc_num; i++) {
         if (sym == keyconvmap[i].sym && !(keyconvmap[i].shift & ALLOW_OTHER)) {
             keyconvmap[i].row = row;
             keyconvmap[i].column = col;
