@@ -66,12 +66,14 @@ struct snapshot_s;
 extern void keyboard_init(void);
 extern void keyboard_shutdown(void);
 extern void keyboard_set_keyarr(int row, int col, int value);
-extern void keyboard_set_keyarr_and_latch(int row, int col, int value);
 extern void keyboard_clear_keymatrix(void);
 extern void keyboard_event_playback(CLOCK offset, void *data);
 extern void keyboard_restore_event_playback(CLOCK offset, void *data);
 extern int keyboard_snapshot_write_module(struct snapshot_s *s);
 extern int keyboard_snapshot_read_module(struct snapshot_s *s);
+extern void keyboard_event_delayed_playback(void *data);
+extern void keyboard_register_delay(unsigned int delay);
+extern void keyboard_register_clear(void);
 
 extern int keyboard_set_keymap_index(void *v, void *param);
 extern int keyboard_set_keymap_file(void *v, void *param);
