@@ -53,6 +53,7 @@
 #include "maincpu.h"
 #include "mem.h"
 #include "monitor.h"
+#include "network.h"
 #include "printer.h"
 #include "resources.h"
 #include "romset.h"
@@ -116,9 +117,12 @@ void machine_trigger_reset(const unsigned int mode)
     if (event_playback_active())
         return;
 
-    event_record(EVENT_RESETCPU, (void *)&mode, sizeof(mode));
-
-    machine_trigger_reset_internal(mode);
+    if (network_connected()) {
+        network_event_record(EVENT_RESETCPU, (void *)&mode, sizeof(mode));
+    } else {
+        event_record(EVENT_RESETCPU, (void *)&mode, sizeof(mode));
+        machine_trigger_reset_internal(mode);
+    }
 }
 
 void machine_reset_event_playback(CLOCK offset, void *data)
@@ -231,6 +235,8 @@ void machine_shutdown(void)
 
     event_shutdown();
 
+    network_shutdown();
+
     fsdevice_resources_shutdown();
     disk_image_resources_shutdown();
     machine_resources_shutdown();
