@@ -33,7 +33,9 @@
 #include "mouse.h"
 #include "mousedrv.h"
 #include "resources.h"
-
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 
 int _mouse_enabled = 0;
 
@@ -75,15 +77,27 @@ int mouse_resources_init(void)
     return mousedrv_resources_init();
 }
 
+#ifdef HAS_TRANSLATION
+static const cmdline_option_t cmdline_options[] = {
+    { "-mouse", SET_RESOURCE, 1, NULL, NULL,
+      "Mouse", NULL, 0, IDCLS_ENABLE_1351_MOUSE },
+    { "+mouse", SET_RESOURCE, 0, NULL, NULL,
+      "Mouse", NULL, 0, IDCLS_DISABLE_1351_MOUSE },
+    { "-mouseport", SET_RESOURCE, 1, NULL, NULL,
+      "Mouseport", NULL, IDCLS_P_VALUE, IDCLS_SELECT_MOUSE_JOY_PORT },
+    { NULL }
+};
+#else
 static const cmdline_option_t cmdline_options[] = {
     { "-mouse", SET_RESOURCE, 1, NULL, NULL,
       "Mouse", NULL, NULL, N_("Enable emulation of the 1351 proportional mouse") },
     { "+mouse", SET_RESOURCE, 0, NULL, NULL,
       "Mouse", NULL, NULL, N_("Disable emulation of the 1351 proportional mouse") },
     { "-mouseport", SET_RESOURCE, 1, NULL, NULL,
-      "Mouseport", NULL, "<value>", "Select the joystick port the mouse is attached to" },
+      "Mouseport", NULL, N_("<value>"), N_("Select the joystick port the mouse is attached to") },
     { NULL }
 };
+#endif
 
 int mouse_cmdline_options_init(void)
 {
