@@ -239,9 +239,16 @@ static void pet_monitor_init(void)
 {
     unsigned int dnr;
     monitor_cpu_type_t asm6502;
-    monitor_cpu_type_t *asmarray[2] = { &asm6502, NULL };
     monitor_interface_t *drive_interface_init[DRIVE_NUM];
 
+#ifdef MINIXVMD
+    monitor_cpu_type_t *asmarray[2];
+    asmarray[0]=&asm6502;
+    asmarray[1]=NULL;
+#else
+    monitor_cpu_type_t *asmarray[2] = { &asm6502, NULL };
+#endif
+
     asm6502_init(&asm6502);
 
     for (dnr = 0; dnr < DRIVE_NUM; dnr++)
@@ -394,9 +401,13 @@ static void machine_vsync_hook(void)
 }
 
 /* Dummy - no restore key.  */
-int machine_set_restore_key(int v)
+void machine_set_restore_key(int v)
 {
-    return 0;   /* key not used -> lookup in keymap */
+}
+
+int machine_has_restore_key(void)
+{
+    return 0;
 }
 
 /* ------------------------------------------------------------------------- */
