@@ -43,6 +43,9 @@
 #include "petpia.h"
 #include "piacore.h"
 #include "resources.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 
 
@@ -104,13 +107,23 @@ int pia1_init_resources(void)
 }
 
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-diagpin", SET_RESOURCE, 0, NULL, NULL, "DiagPin", (resource_value_t)1,
-      NULL, "Enable userport diagnostic pin" },
+      0, IDCLS_ENABLE_USERPORT_DIAG_PIN },
     { "+diagpin", SET_RESOURCE, 0, NULL, NULL, "DiagPin", (resource_value_t)1,
-      NULL, "Disable userport diagnostic pin" },
+      0, IDCLS_DISABLE_USERPORT_DIAG_PIN },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-diagpin", SET_RESOURCE, 0, NULL, NULL, "DiagPin", (resource_value_t)1,
+      NULL, N_("Enable userport diagnostic pin") },
+    { "+diagpin", SET_RESOURCE, 0, NULL, NULL, "DiagPin", (resource_value_t)1,
+      NULL, N_("Disable userport diagnostic pin") },
+    { NULL }
+};
+#endif
 
 int pia1_init_cmdline_options(void)
 {
