@@ -46,6 +46,17 @@
  * Support for Final Cartridge III extensions to c64 2.0 basic
  *   Matti 'ccr' Hmlinen <ccr@tnsp.org>
  *
+ * Support for Ultrabasic-64 extensions to c64 2.0 basic and
+ * support for graphics-basic extensions to c64 2.0 basic and
+ * support for WS (WohnzimmerSoft) basic extensions to c64 2.0 basic and
+ * support for Mighty basic extensions to vic20 2.0 basic and
+ * support for Pegasus basic 4.0 extensions to c64 2.0 basic and
+ * support for X-basic extensions to c64 2.0 basic and
+ * support for Drago basic 2.2 extensions to c64 2.0 basic and
+ * support for REU-basic extensions to c64 2.0 basic and
+ * support for Basic Lightning extensions to c64 2.0 basic by
+ *   Marco van den Heuvel <blackystardust68@yahoo.com>
+ *
  */
 
 #include "vice.h"
@@ -59,11 +70,12 @@
 
 #include "archdep.h"
 #include "charset.h"            /* ctrl1, ctrl2, cbmkeys */
+#include "cmdline.h"
 #include "lib.h"
 #include "types.h"
 
 
-#define PETCATVERSION   2.03
+#define PETCATVERSION   2.11
 #define PETCATLEVEL     1
 
 #define B_1              1
@@ -81,7 +93,15 @@
 #define B_7             11
 #define B_10            12
 #define B_FC3           13
-
+#define B_ULTRA         14
+#define B_GRAPH         15
+#define B_WS            16
+#define B_MIGHTY        17
+#define B_PEG           18
+#define B_X             19
+#define B_DRAGO         20
+#define B_REU           21
+#define B_BASL          22
 
 /* Limits */
 
@@ -102,6 +122,16 @@
 #define NUM_V7FE        39
 #define NUM_V10FE       62
 
+#define NUM_ULTRCC      51      /* Ultrabasic-64 */
+#define NUM_GRAPHCC     51      /* graphics basic (c64) */
+#define NUM_WSCC        51      /* WS basic (c64) */
+#define NUM_MIGHTYCC    51      /* Mighty basic (vic20) */
+#define NUM_PEGCC       33      /* Pegasus basic 4.0 (c64) */
+#define NUM_XCC         33      /* Xbasic (c64) */
+#define NUM_DRAGOCC     13      /* Drago basic 2.2 (c64) */
+#define NUM_REUCC       14      /* REU-basic (c64) */
+#define NUM_BASLCC      51      /* Basic Lightning (c64) */
+
 
 #define MAX_COMM        0xCB    /* common for all versions */
 #define MAX_SECC        0xDD    /* VIC-20 extension */
@@ -114,6 +144,16 @@
 
 #define MAX_FC3CC       0xE8    /* Final Cartridge III */
 
+#define MAX_ULTRCC      0xFE    /* Ultrabasic-64 */
+#define MAX_GRAPHCC     0xFE    /* graphics basic (c64) */
+#define MAX_WSCC        0xFE    /* WS basic (c64) */
+#define MAX_MIGHTYCC    0xFE    /* Mighty basic (vic20) */
+#define MAX_PEGCC       0xEC    /* Pegasus basic 4.0 (c64) */
+#define MAX_XCC         0xEC    /* Xbasic (c64) */
+#define MAX_DRAGOCC     0xD8    /* Drago basic 2.2 (c64) */
+#define MAX_REUCC       0xDA    /* REU-basic (c64) */
+#define MAX_BASLCC      0xFE    /* Basic Lightning (c64) */
+
 #define MAX_KWCE        0x0A
 #define MAX_V7FE        0x26
 #define MAX_V10FE       0x3D
@@ -159,7 +199,7 @@ static const char *cbmkeys[] = {
     "CBM-U", "CBM-O", "SHIFT-@", "CBM-F", "CBM-C", "CBM-X", "CBM-V", "CBM-B"
 };
 
-#define NUM_VERSIONS  13
+#define NUM_VERSIONS  22
 
 const char *VersNames[] = {
     "Basic 1.0",
@@ -177,6 +217,15 @@ const char *VersNames[] = {
     "Basic 7.0",
     "Basic 10.0",
     "Basic 2.0 with Final Cartridge III",
+    "Basic 2.0 with Ultrabasic-64",
+    "Basic 2.0 with graphics basic",
+    "Basic 2.0 with WS basic",
+    "Basic 2.0 with Mighty basic",
+    "Basic 2.0 with Pegasus basic 4.0",
+    "Basic 2.0 with Xbasic",
+    "Basic 2.0 with Drago basic 2.2",
+    "Basic 2.0 with REU-basic",
+    "Basic 2.0 with Basic Lightning",
     ""
 };
 
@@ -279,6 +328,21 @@ const char *turtlekwcc[] = {
 };
 
 
+/* Mighty basic Keywords */
+
+const char *mightykwcc[] = {
+    "delete",  "old",     "renumber",  "help",   "header", "move",
+    "trace",   "kill",    "dump",      "dsave",  "dload",  "dverify",
+    "dresave", "scratch", "directory", "key",    "send",   "pop",
+    "off",     "bsave",   "bload",     "find",   "auto",   "pprint",
+    "accept",  "reset",   "else",      "color",  "take",   "pause",
+    "base",    "copychr", "char",      "beep",   "cls",    "fill",
+    "merge",   "sound",   "give",      "plist",  "put",    "volume",
+    "rtime",   "msb",     "lsb",       "vector", "joy",    "dec",
+    "hex$",    "grab",    "ds$"
+};
+
+
 /*
  * Third party products for C=64
  */
@@ -306,6 +370,99 @@ const char *atbasickwcc[] = {
 };
 
 
+/* Ultrabasic-64 Keywords (Tokens CC - FE) -- Marco van den Heuvel */
+
+const char *ultrabasic64kwcc[] = {
+    "dot",    "draw",  "box",    "tic",    "copy", "sprite", "off",   "mode",
+    "norm",   "graph", "dump",   "gread",  "char", "place",  "multi", "hires",
+    "hex",    "bit",   "colors", "pixel",  "fill", "circle", "block", "sdata",
+    "vol",    "gen",   "scoll",  "bcoll",  "joy",  "paddle", "pen",   "sound",
+    "tune",   "tdata", "set",    "turnto", "turn", "tup",    "tdown", "tcolor",
+    "turtle", "move",  "bye",    "rotate", "tpos", "ctr",    "sctr",  "[",
+    "]",      "hard",  "exit"
+};
+
+
+/* Graphics basic (c64) Keywords (Tokens CC - FE) -- Marco van den Heuvel */
+
+const char *graphicsbasickwcc[] = {
+    "background", "border",    "dir",       "disk",    "fill",   "key",
+    "circle",     "procedure", "dot",       "find",    "change", "ren",
+    "else",       "copy",      "scroll",    "roll",    "box",    "scale",
+    "do",         "line",      "sprite",    "color",   "hires",  "clear",
+    "text",       "window",    "off",       "at",      "shape",  "xysize",
+    "speed",      "from",      "setorigin", "animate", "multi",  "eze",
+    "move",       "under",     "edit",      "reset",   "xpos",   "gprint",
+    "voice",      "adsr",      "wave",      "ne",      "volume", "play",
+    "ypos",       "sound",     "joy"
+};
+
+
+/* WS (WohnzimmerSoft) basic (c64) Keywords (Tokens CC - FE) -- Marco van den
+                                                                Heuvel */
+
+const char *wsbasickwcc[] = {
+    "copy",   "old",    "port",  "doke",  "vpoke",  "fill",   "error",
+    "send",   "call",   "bit",   "dir",   "bload",  "bsave",  "find",
+    "speed",  "pitch",  "say",   "fast",  "slow",   "talk",   "shutup",
+    "stash",  "fetch",  "swap",  "off",   "screen", "device", "object",
+    "vstash", "vfetch", "quiet", "color", "cls",    "curpos", "monitor",
+    "subend", "do",     "loop",  "exit",  "deek",   "rsc",    "rsm",
+    "dec",    "hex$",   "hi",    "lo",    "ds$",    "line",   "vpeek",
+    "row",    "joy"
+};
+
+
+/* Pegasus basic 4.0 (c64) Keywords (Tokens CC - EC) -- Marco van den Heuvel */
+ 
+const char *pegbasickwcc[] = {
+    "off",      "asc(",     "sin(",      "cos(",  "tan(",     "atn(",
+    "deg(",     "rad(",     "frac(",     "mod(",  "round(",   "dec(",
+    "bin(",     "deek(",    "instr(",    "joy(",  "pot(",     "screen(",
+    "test(",    "using",    "ds$",       "hex$(", "bin$(",    "space$(",
+    "ucase$(",  "string$(", "input$(",   "time$", "spritex(", "spritey(",
+    "turtlex(", "turtley(", "turtleang"
+};
+
+
+/* Xbasic (c64) Keywords (Tokens CC - EC) -- Marco van den Heuvel */
+
+const char *xbasickwcc[] = {
+    "sprat",  "brdr",    "screen",  "quit",  "sprmult",  "move",
+    "sprite", "asprite", "dsprite", "sid",   "envelope", "gate",
+    "frq",    "wave",    "vol",     "fcut",  "fmode",    "filter",
+    "frsn",   "cset",    "multi",   "extnd", "locate",   "center",
+    "hires",  "line",    "hprnt",   "plot",  "text",     "clear",
+    "colr",   "stick",   "btn"
+};
+
+/* Drago basic 2.2 (c64) Keywords (Tokens CC - D8) -- Marco van den Heuvel */
+
+const char *dragobasickwcc[] = {
+    "punkt", "linia",   "rysuj",  "param", "kuntur", "anim", "kolor",
+    "puwid", "ryselip", "koguma", "fiut",  "figura", "figuma"
+};
+
+/* REU-basic (c64) Keywords (Tokens CC - DA) -- Marco van den Heuvel */
+
+const char *reubasickwcc[] = {
+    "push", "pull", "flip", "rec",  "stash", "fetch", "swap", "reu",
+    "size", "dir",  "@",    "kill", "rom",   "ram",   "move"
+};
+
+/* Basic Lightning (c64) Keywords (Tokens CC - FE) -- Marco van den Heuvel */
+
+const char *baslkwcc[] = {
+    "else",  "hex$",  "deek",     "true",    "import",  "cfn",   "size",
+    "false", "ver$",  "lpx",      "lpy",     "common%", "crow",  "ccol",
+    "atr",   "inc",   "num",      "row2",    "col2",    "spn2",  "hgt",
+    "wid",   "row",   "col",      "spn",     "task",    "halt",  "repeat",
+    "until", "while", "wend",     "cif",     "celse",   "cend",  "label",
+    "doke",  "exit",  "allocate", "disable", "pull",    "dload", "dsave",
+    "var",   "local", "procend",  "proc",    "casend",  "of",    "case",
+    "rpt",   "setatr"
+};
+
 /* Simon's Basic Keywords */
 
 const char *simonskw[] = {
@@ -376,6 +533,12 @@ static unsigned char sstrcmp(unsigned char *line, const char **wordlist,
 static FILE *source, *dest;
 static int kwlen;
 
+/* dummy function */
+int cmdline_register_options(const cmdline_option_t *c)
+{
+  return 0;
+}
+
 int main(int argc, char **argv)
 {
     char *progname, *outfilename = NULL;
@@ -453,7 +616,7 @@ int main(int argc, char **argv)
 
         } else if (!strcmp(argv[0], "-help") ||
                  !strncmp(argv[0], "-v", 2)) {  /* version ID */
-            fprintf(stderr,
+            fprintf(stdout,
                     "\n\t%s V%4.2f PL %d -- Basic list/crunch utility.\n\tPart of "PACKAGE" "VERSION"\n",
                     progname, (float)PETCATVERSION, PETCATLEVEL );
 
@@ -473,12 +636,12 @@ int main(int argc, char **argv)
             continue;
         }
 
-        fprintf(stderr,
+        fprintf(stdout,
                 "\nUsage: %7s  [-c | -nc]  [-h | -nh]  [-text | -<version> | -w<version>]"
                 "\n\t\t[-skip <bytes>] [-l <hex>]  [--] [file list]\n\t\t[-k[<version>]]\n",
                 progname);
 
-        fprintf(stderr, "\n"
+        fprintf(stdout, "\n"
             "   -help\tOutput this help screen here\n"
             "   -v\t\tSame as above\n"
             "   -c\t\tcontrols (interpret also control codes) <default if textmode>\n"
@@ -497,21 +660,30 @@ int main(int argc, char **argv)
             "   -f\t\tForce overwritten the output file\n"
             "   \t\tThe default depends on the BASIC version.\n");
 
-        fprintf(stderr, "\n\tVersions:\n"
+        fprintf(stdout, "\n\tVersions:\n"
                 "\t1\tPET Basic V1.0\n"
                 "\t2\tBasic v2.0\n"
                 "\tsuper\tBasic v2.0 with Super Expander (VIC)\n"
                 "\tturtle\tBasic v2.0 with Turtle Basic by Craig Bruce (VIC)\n"
+                "\tmighty\tBasic v2.0 with Mighty Basic by Craig Bruce (VIC)\n"
                 "\ta\tBasic v2.0 with AtBasic (C64)\n"
                 "\tsimon\tBasic v2.0 with Simon's Basic extension (C64)\n"
                 "\tspeech\tBasic v2.0 with Speech Basic v2.7 (C64)\n"
                 "\tF\tBasic v2.0 with Final Cartridge III (C64)\n"
+                "\tultra\tBasic v2.0 with Ultrabasic-64 (C64)\n"
+                "\tgraph\tBasic v2.0 with Graphics basic (C64)\n"
+                "\tWSB\tBasic v2.0 with WS basic (C64)\n"
+                "\tPegasus\tBasic v2.0 with Pegasus basic 4.0 (C64)\n"
+                "\tXbasic\tBasic v2.0 with Xbasic (C64)\n"
+                "\tDrago\tBasic v2.0 with Drago basic 2.2 (C64)\n"
+                "\tREU\tBasic v2.0 with REU-basic (C64)\n"
+                "\tLightning\tBasic v2.0 with Basic Lightning (C64)\n"
                 "\t4 -w4e\tPET Basic v4.0 program (PET/C64)\n"
                 "\t3\tBasic v3.5 program (C16)\n"
                 "\t7\tBasic v7.0 program (C128)\n"
                 "\t10\tBasic v10.0 program (C64DX)\n\n");
 
-        fprintf(stderr, "\tUsage examples:\n"
+        fprintf(stdout, "\tUsage examples:\n"
             "\tpetcat -w2 -o outputfile.txt -- inputfile.prg\n"
             "\t\tConvert inputfile.prg to a text file in outputfile.txt,\n"
             "\t\tusing BASIC V2 only\n"
@@ -553,6 +725,7 @@ int main(int argc, char **argv)
 
     if (!load_addr) {
         switch (version) {
+          case B_PEG:
           case B_SUPER:
             load_addr = 0x0401;
             break;
@@ -568,6 +741,16 @@ int main(int argc, char **argv)
           case B_10:
             load_addr = 0x2001;
             break;
+          case B_ULTRA:
+            load_addr = 0x2c01;
+            break;
+          case B_GRAPH:
+            load_addr = 0x1001;
+            break;
+          case B_MIGHTY:
+            load_addr = 0x3201;
+            break;
+
           default:
             load_addr = 0x0801;
         }
@@ -763,6 +946,42 @@ static int parse_version(char *str)
       	version = B_FC3;
       	break;
 
+      case 'U':
+        version = B_ULTRA;
+        break;
+
+      case 'G':
+        version = B_GRAPH;
+        break;
+
+      case 'W':
+        version = B_WS;
+        break;
+
+      case 'M':
+        version = B_MIGHTY;
+        break;
+
+      case 'P':
+        version = B_PEG;
+        break;
+
+      case 'X':
+        version = B_X;
+        break;
+
+      case 'D':
+        version = B_DRAGO;
+        break;
+
+      case 'R':
+        version = B_REU;
+        break;
+
+      case 'L':
+        version = B_BASL;
+        break;
+
       default:
         fprintf (stderr, "\nUnimplemented version '%s'\n", str);
         version = -1;
@@ -822,6 +1041,11 @@ static void list_keywords(int version)
             printf("%s\t", turtlekwcc[n] /*, n + 0xcc*/);
         break;
 
+      case B_MIGHTY:
+        for (n = 0; n < NUM_MIGHTYCC; n++)
+            printf("%s\t", mightykwcc[n] /*, n + 0xcc*/);
+        break;
+
         case B_4:
         case B_4E:
         for (n = 0; n < ((version == B_4) ? NUM_V4CC : NUM_4ECC); n++)
@@ -843,11 +1067,50 @@ static void list_keywords(int version)
             printf("%s\t", atbasickwcc[n] /*, n + 0xcc*/);
         break;
         
+      case B_ULTRA:
+        for (n = 0; n < NUM_ULTRCC; n++)
+            printf("%s\t", ultrabasic64kwcc[n] /*, n + 0xcc*/);
+        break;
+
+      case B_GRAPH:
+        for (n = 0; n < NUM_GRAPHCC; n++)
+            printf("%s\t", graphicsbasickwcc[n] /*, n + 0xcc*/);
+        break;
+
+      case B_WS:
+        for (n = 0; n < NUM_WSCC; n++)
+            printf("%s\t", wsbasickwcc[n] /*, n + 0xcc*/);
+        break;
+
+      case B_PEG:
+        for (n = 0; n < NUM_PEGCC; n++)
+            printf("%s\t", pegbasickwcc[n] /*, n + 0xcc*/);
+        break;
+
+      case B_X:
+        for (n = 0; n < NUM_XCC; n++)
+            printf("%s\t", xbasickwcc[n] /*, n + 0xcc*/);
+        break;
+
+      case B_DRAGO:
+        for (n = 0; n < NUM_DRAGOCC; n++)
+            printf("%s\t", dragobasickwcc[n] /*, n + 0xcc*/);
+        break;
+
+      case B_REU:
+        for (n = 0; n < NUM_REUCC; n++)
+            printf("%s\t", reubasickwcc[n] /*, n + 0xcc*/);
+
       case B_FC3:
         for (n = 0; n < NUM_FC3CC; n++)
             printf("%s\t", fc3kw[n] /*, n + 0xcc*/);
       break;
       
+      case B_BASL:
+        for (n = 0; n < NUM_BASLCC; n++)
+            printf("%s\t", baslkwcc[n] /*, n + 0xcc*/);
+      break;
+
     }  /* switch */
 
     printf("\n\n");
@@ -969,7 +1232,7 @@ static int p_expand(int version, int addr, int ctrls)
 
         /* prevent list protection from terminating listing */
 
-        while (((int)c = getc(source)) != EOF && !c);
+        while ((c = getc(source)) != EOF && !c);
 
         if (c == 0x12 && !line[2] && !line[3]) {  /* 00 00 12 22 */
             directory++;
@@ -1030,6 +1293,11 @@ static int p_expand(int version, int addr, int ctrls)
                         fprintf(dest, "%s", turtlekwcc[c - 0xcc]);
                     break;
 
+                  case B_MIGHTY:        /* VIC Mightyb basic */
+                    if (c >= 0xcc && c <= MAX_MIGHTYCC)
+                        fprintf(dest, "%s", mightykwcc[c - 0xcc]);
+                    break;
+
                   case B_SPEECH:        /* C64 Speech basic */
                     if (c >= 0xcc && c <= MAX_SPECC)
                         fprintf(dest, "%s", speechkwcc[c - 0xcc]);
@@ -1040,11 +1308,51 @@ static int p_expand(int version, int addr, int ctrls)
                         fprintf(dest, "%s", atbasickwcc[c - 0xcc]);
                     break;
 
-                  case B_FC3:		/* C64 FC3 */
+                  case B_FC3:           /* C64 FC3 */
                     if (c >= 0xcc && c <= MAX_FC3CC)
                         fprintf(dest, "%s", fc3kw[c - 0xcc]);
                     break;
 
+                  case B_ULTRA:         /* C64 Ultrabasic-64 */
+                    if (c >= 0xcc && c <= MAX_ULTRCC)
+                        fprintf(dest, "%s", ultrabasic64kwcc[c - 0xcc]);
+                    break;
+
+                  case B_GRAPH:
+                    if (c >= 0xcc && c <= MAX_GRAPHCC)
+                        fprintf(dest, "%s", graphicsbasickwcc[c - 0xcc]);
+                    break;
+
+                  case B_WS:
+                    if (c >= 0xcc && c <= MAX_WSCC)
+                        fprintf(dest, "%s", wsbasickwcc[c - 0xcc]);
+                    break;
+
+                  case B_PEG:
+                    if (c >= 0xcc && c <= MAX_PEGCC)
+                        fprintf(dest, "%s", pegbasickwcc[c - 0xcc]);
+                    break;
+
+                  case B_X:
+                    if (c >= 0xcc && c <= MAX_XCC)
+                        fprintf(dest, "%s", xbasickwcc[c - 0xcc]);
+                    break;
+
+                  case B_DRAGO:
+                    if (c >= 0xcc && c <= MAX_DRAGOCC)
+                        fprintf(dest, "%s", dragobasickwcc[c - 0xcc]);
+                    break;
+
+                  case B_REU:
+                    if (c >= 0xcc && c <= MAX_REUCC)
+                        fprintf(dest, "%s", reubasickwcc[c - 0xcc]);
+                    break;
+
+                  case B_BASL:
+                    if (c >= 0xcc && c <= MAX_BASLCC)
+                        fprintf(dest, "%s", baslkwcc[c - 0xcc]);
+                    break;
+
                   case B_4:             /* PET V4.0 */
                   case B_4E:            /* V4.0 extension */
                     if (c >= 0xcc && c <= MAX_4ECC)
@@ -1064,7 +1372,7 @@ static int p_expand(int version, int addr, int ctrls)
 
             _p_toascii((int)c, ctrls);  /* convert character */
 
-        } while (((int)c = getc(source)) != EOF && c);
+        } while ((c = getc(source)) != EOF && c);
         fprintf(dest, "\n");
 
     }      /* line */
@@ -1236,6 +1544,14 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
                     }
                     break;
 
+                  case B_MIGHTY:
+                    if ((c = sstrcmp(p2, mightykwcc, 0, NUM_MIGHTYCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
                   case B_4:
                   case B_4E:
                     if ((c = sstrcmp(p2, petkwcc, 0,
@@ -1278,6 +1594,71 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
                         p2 += kwlen;
                         match++;
                     }
+                    break;
+
+                  case B_ULTRA:
+                    if ((c = sstrcmp(p2 , ultrabasic64kwcc, 0, NUM_ULTRCC)) != KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
+                  case B_GRAPH:
+                    if ((c = sstrcmp(p2 , graphicsbasickwcc, 0, NUM_GRAPHCC)) != KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
+                  case B_WS:
+                    if ((c = sstrcmp(p2 , wsbasickwcc, 0, NUM_WSCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
+                  case B_PEG:
+                    if ((c = sstrcmp(p2 , pegbasickwcc, 0, NUM_PEGCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
+                  case B_X:
+                    if ((c = sstrcmp(p2 , xbasickwcc, 0, NUM_XCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
+                  case B_DRAGO:
+                    if ((c = sstrcmp(p2 , dragobasickwcc, 0, NUM_DRAGOCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
+                  case B_REU:
+                    if ((c = sstrcmp(p2 , reubasickwcc, 0, NUM_REUCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
+
+                  case B_BASL:
+                    if ((c = sstrcmp(p2 , baslkwcc, 0, NUM_BASLCC)) !=KW_NONE) {
+                        *p1++ = c + 0xcc;
+                        p2 += kwlen;
+                        match++;
+                    }
+                    break;
 
                 }  /* switch */
             } /* !quote */
