@@ -44,6 +44,9 @@
 #include "resources.h"
 #include "rs232drv.h"
 #include "rsuser.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 
 
@@ -91,7 +94,7 @@ static void calculate_baudrate(void)
 {
     if (rsuser_enabled) {
         char_clk_ticks = (int)(10.0 * cycles_per_sec
-                         / ((double)rsuser_enabled));
+                         / ((double)rsuser_baudrate));
     } else {
         char_clk_ticks = RSUSER_TICKS;
     }
@@ -162,19 +165,35 @@ int rsuser_resources_init(void)
     return resources_register(resources);
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-rsuser", SET_RESOURCE, 0, NULL, NULL, "RsUserEnable", (void *)1,
-      NULL, "Enable RS232 userport emulation" },
+      0, IDCLS_ENABLE_RS232_USERPORT },
     { "+rsuser", SET_RESOURCE, 0, NULL, NULL, "RsUserEnable", (void *)0,
-      NULL, "Disable RS232 userport emulation" },
+      0, IDCLS_DISABLE_RS232_USERPORT },
     { "-rsuserbaud", SET_RESOURCE, 1, NULL, NULL, "RsUserBaud",
-      (resource_value_t)300, "<baud>",
-      "Set the baud rate of the RS232 userport emulation." },
+      (resource_value_t)300, IDCLS_P_BAUD,
+      IDCLS_SET_BAUD_RS232_USERPORT },
     { "-rsuserdev", SET_RESOURCE, 1, NULL, NULL, "RsUserDev",
       (resource_value_t)0,
-      "<0-3>", "Specify VICE RS232 device for userport" },
+      IDCLS_P_0_3, IDCLS_SPECIFY_RS232_DEVICE_USERPORT },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-rsuser", SET_RESOURCE, 0, NULL, NULL, "RsUserEnable", (void *)1,
+      NULL, N_("Enable RS232 userport emulation") },
+    { "+rsuser", SET_RESOURCE, 0, NULL, NULL, "RsUserEnable", (void *)0,
+      NULL, N_("Disable RS232 userport emulation") },
+    { "-rsuserbaud", SET_RESOURCE, 1, NULL, NULL, "RsUserBaud",
+      (resource_value_t)300, N_("<baud>"),
+      N_("Set the baud rate of the RS232 userport emulation.") },
+    { "-rsuserdev", SET_RESOURCE, 1, NULL, NULL, "RsUserDev",
+      (resource_value_t)0,
+      "<0-3>", N_("Specify VICE RS232 device for userport") },
+    { NULL }
+};
+#endif
 
 int rsuser_cmdline_options_init(void)
 {
@@ -333,7 +352,7 @@ void rsuser_set_tx_bit(int b)
               clk, clk_start_tx, b);
 #endif
 
-    if (fd == -1 || rsuser_enabled > 2400) {
+    if (fd == -1 || rsuser_baudrate > 2400) {
         clk_start_tx = 0;
         return;
     }
@@ -376,7 +395,7 @@ BYTE rsuser_get_rx_bit(void)
 
 BYTE rsuser_read_ctrl(void)
 {
-    return rsuser_get_rx_bit() | CTS_IN | (rsuser_enabled > 2400 ? 0 : DCD_IN);
+    return rsuser_get_rx_bit() | CTS_IN | (rsuser_baudrate > 2400 ? 0 : DCD_IN);
 }
 
 void rsuser_tx_byte(BYTE b)
