@@ -45,6 +45,9 @@
 #include "maincpu.h"
 #include "resources.h"
 #include "sound.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "types.h"
 #include "ui.h"
 #include "util.h"
@@ -212,27 +215,51 @@ void sound_resources_shutdown(void)
 
 /* ------------------------------------------------------------------------- */
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-sound", SET_RESOURCE, 0, NULL, NULL, "Sound", (resource_value_t)1,
-      NULL, "Enable sound playback" },
+      0, IDCLS_ENABLE_SOUND_PLAYBACK },
     { "+sound", SET_RESOURCE, 0, NULL, NULL, "Sound", (resource_value_t)0,
-      NULL, "Disable sound playback" },
+      0, IDCLS_DISABLE_SOUND_PLAYBACK },
     { "-soundrate", SET_RESOURCE, 1, NULL, NULL, "SoundSampleRate", NULL,
-      "<value>", "Set sound sample rate to <value> Hz" },
+      IDCLS_P_VALUE, IDCLS_SET_SAMPLE_RATE_VALUE_HZ },
     { "-soundbufsize", SET_RESOURCE, 1, NULL, NULL, "SoundBufferSize", NULL,
-      "<value>", "Set sound buffer size to <value> msec" },
+      IDCLS_P_VALUE, IDCLS_SET_SOUND_BUFFER_SIZE_MSEC },
     { "-sounddev", SET_RESOURCE, 1, NULL, NULL, "SoundDeviceName", NULL,
-      "<name>", "Specify sound driver" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_SOUND_DRIVER },
     { "-soundarg", SET_RESOURCE, 1, NULL, NULL, "SoundDeviceArg", NULL,
-      "<args>", "Specify initialization parameters for sound driver" },
+      IDCLS_P_ARGS, IDCLS_SPECIFY_SOUND_DRIVER_PARAM },
     { "-soundrecdev", SET_RESOURCE, 1, NULL, NULL, "SoundRecordDeviceName",
-      NULL, "<name>", "Specify recording sound driver" },
+      NULL, IDCLS_P_NAME, IDCLS_SPECIFY_RECORDING_SOUND_DRIVER },
     { "-soundrecarg", SET_RESOURCE, 1, NULL, NULL, "SoundRecordDeviceArg", NULL,
-      "<args>", "Specify initialization parameters for recording sound driver" },
+      IDCLS_P_ARGS, IDCLS_SPECIFY_REC_SOUND_DRIVER_PARAM },
     { "-soundsync", SET_RESOURCE, 1, NULL, NULL, "SoundSpeedAdjustment", NULL,
-      "<sync>", "Set sound speed adjustment (0: flexible, 1: adjusting, 2: exact)" },
+      IDCLS_P_SYNC, IDCLS_SET_SOUND_SPEED_ADJUST },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-sound", SET_RESOURCE, 0, NULL, NULL, "Sound", (resource_value_t)1,
+      NULL, N_("Enable sound playback") },
+    { "+sound", SET_RESOURCE, 0, NULL, NULL, "Sound", (resource_value_t)0,
+      NULL, N_("Disable sound playback") },
+    { "-soundrate", SET_RESOURCE, 1, NULL, NULL, "SoundSampleRate", NULL,
+      N_("<value>"), N_("Set sound sample rate to <value> Hz") },
+    { "-soundbufsize", SET_RESOURCE, 1, NULL, NULL, "SoundBufferSize", NULL,
+      N_("<value>"), N_("Set sound buffer size to <value> msec") },
+    { "-sounddev", SET_RESOURCE, 1, NULL, NULL, "SoundDeviceName", NULL,
+      N_("<name>"), N_("Specify sound driver") },
+    { "-soundarg", SET_RESOURCE, 1, NULL, NULL, "SoundDeviceArg", NULL,
+      N_("<args>"), N_("Specify initialization parameters for sound driver") },
+    { "-soundrecdev", SET_RESOURCE, 1, NULL, NULL, "SoundRecordDeviceName",
+      NULL, N_("<name>"), N_("Specify recording sound driver") },
+    { "-soundrecarg", SET_RESOURCE, 1, NULL, NULL, "SoundRecordDeviceArg", NULL,
+      N_("<args>"), N_("Specify initialization parameters for recording sound driver") },
+    { "-soundsync", SET_RESOURCE, 1, NULL, NULL, "SoundSpeedAdjustment", NULL,
+      N_("<sync>"), N_("Set sound speed adjustment (0: flexible, 1: adjusting, 2: exact)") },
+    { NULL }
+};
+#endif
 
 int sound_cmdline_options_init(void)
 {
@@ -320,12 +347,25 @@ static snddata_t snddata;
 /* device registration code */
 static sound_device_t *sound_devices[32];
 
+static char *devlist;
+
 int sound_register_device(sound_device_t *pdevice)
 {
+    const int max = sizeof(sound_devices) / sizeof(sound_devices[0]);
     int i;
+    char *tmplist;
+
+    for (i = 0; sound_devices[i] && i < max; i++);
+
+    if (i < max) {
+        sound_devices[i] = pdevice;
+        tmplist = lib_msprintf("%s %s", devlist, pdevice->name);
+        lib_free(devlist);
+        devlist = tmplist;
+    } else {
+        log_error(sound_log, "available sound devices exceed VICEs storage");
+    }
 
-    for (i = 0; sound_devices[i]; i++);
-    sound_devices[i] = pdevice;
     return 0;
 }
 
@@ -409,7 +449,11 @@ static void fill_buffer(int size, int rise)
     lib_free(p);
 
     if (i)
+#ifdef HAS_TRANSLATION
+        sound_error(translate_text(IDGS_WRITE_TO_SOUND_DEVICE_FAILED));
+#else
         sound_error(_("write to sound device failed."));
+#endif
 }
 
 
@@ -420,7 +464,11 @@ static int sid_open(void)
 
     for (c = 0; c < snddata.channels; c++) {
         if (!(snddata.psid[c] = sound_machine_open(c))) {
+#ifdef HAS_TRANSLATION
+            return sound_error(translate_text(IDGS_CANNOT_OPEN_SID_ENGINE));
+#else
             return sound_error(_("Cannot open SID engine"));
+#endif
         }
     }
 
@@ -455,7 +503,11 @@ static int sid_init(void)
 
     for (c = 0; c < snddata.channels; c++) {
         if (!sound_machine_init(snddata.psid[c], speed, cycles_per_sec)) {
+#ifdef HAS_TRANSLATION
+            return sound_error(translate_text(IDGS_CANNOT_INIT_SID_ENGINE));
+#else
             return sound_error(_("Cannot initialize SID engine"));
+#endif
         }
     }
 
@@ -557,8 +609,13 @@ int sound_open(void)
             int channels_cap = snddata.channels;
             if (pdev->init(playparam, &speed, &fragsize, &fragnr, &channels_cap)) {
                 char *err;
+#ifdef HAS_TRANSLATION
+                err = lib_msprintf(translate_text(IDGS_INIT_FAILED_FOR_DEVICE_S),
+                                   pdev->name);
+#else
                 err = lib_msprintf(_("initialization failed for device `%s'."),
                                    pdev->name);
+#endif
                 sound_error(err);
                 lib_free(err);
                 return 1;
@@ -611,8 +668,13 @@ int sound_open(void)
             }
         }
     } else {
+#ifdef HAS_TRANSLATION
+        char *err = lib_msprintf(translate_text(IDGS_DEVICE_S_NOT_FOUND_SUPPORT),
+                                 playname);
+#else
         char *err = lib_msprintf(_("device '%s' not found or not supported."),
                                  playname);
+#endif
         sound_error(err);
         lib_free(err);
         return 1;
@@ -628,24 +690,41 @@ int sound_open(void)
     }
 
     if (recname && rdev == NULL)
+#ifdef HAS_TRANSLATION
+        ui_error(translate_text(IDGS_RECORD_DEVICE_S_NOT_EXIST), recname);
+#else
         ui_error(_("Recording device %s doesn't exist!"), recname);
+#endif
 
     if (rdev) {
         if (rdev == pdev) {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_RECORD_DIFFERENT_PLAYBACK));
+#else
             ui_error(_("Recording device must be different from playback device"));
+#endif
             resources_set_value("SoundRecordDeviceName", "");
             return 0;
         }
 
         if (rdev->bufferspace != NULL) {
+#ifdef HAS_TRANSLATION
+            ui_error(translate_text(IDGS_WARNING_RECORDING_REALTIME));
+#else
             ui_error(_("Warning! Recording device %s seems to be a realtime device!"));
+#endif
         }
 
         if (rdev->init) {
             int channels_cap = snddata.channels;
             if (rdev->init(recparam, &speed, &fragsize, &fragnr, &channels_cap)) {
+#ifdef HAS_TRANSLATION
+                ui_error(translate_text(IDGS_INIT_FAILED_FOR_DEVICE_S),
+                                   rdev->name);
+#else
                 ui_error(_("Initialization failed for device `%s'."),
                                    rdev->name);
+#endif
                 resources_set_value("SoundRecordDeviceName", "");
                 return 0;
             }
@@ -655,7 +734,11 @@ int sound_open(void)
                 || snddata.fragnr != fragnr
                 || snddata.channels != channels_cap)
             {
+#ifdef HAS_TRANSLATION
+                ui_error(translate_text(IDGS_RECORD_NOT_SUPPORT_SOUND_PAR));
+#else
                 ui_error(_("The recording device doesn't support current sound parameters"));
+#endif
                 rdev->close();
                 resources_set_value("SoundRecordDeviceName", "");
             } else {
@@ -732,7 +815,11 @@ static int sound_run_sound(void)
                                                  snddata.channels,
                                                  &delta_t);
             if (delta_t) {
+#ifdef HAS_TRANSLATION
+                return sound_error(translate_text(IDGS_SOUND_BUFFER_OVERFLOW_CYCLE));
+#else
                 return sound_error(_("Sound buffer overflow (cycle based)"));
+#endif
             }
         }
     } else {
@@ -742,7 +829,11 @@ static int sound_run_sound(void)
         if (!nr)
             return 0;
         if (snddata.bufptr + nr > BUFSIZE) {
+#ifdef HAS_TRANSLATION
+            return sound_error(translate_text(IDGS_SOUND_BUFFER_OVERFLOW));
+#else
             return sound_error(_("Sound buffer overflow."));
+#endif
         }
         for (c = 0; c < snddata.channels; c++) {
             sound_machine_calculate_samples(snddata.psid[c],
@@ -864,7 +955,11 @@ double sound_flush(int relative_speed)
         i = snddata.playdev->flush(state);
         lib_free(state);
         if (i) {
+#ifdef HAS_TRANSLATION
+            sound_error(translate_text(IDGS_CANNOT_FLUSH));
+#else
             sound_error(_("cannot flush."));
+#endif
             return 0;
         }
     }
@@ -909,7 +1004,11 @@ double sound_flush(int relative_speed)
             log_warning(sound_log, "fragment problems %d %d",
                  space, snddata.bufsize);
 
+#ifdef HAS_TRANSLATE
+            sound_error(translate_text(IDGS_FRAGMENT_PROBLEMS));
+#else
             sound_error(_("fragment problems."));
+#endif
             return 0;
         }
         used = snddata.bufsize - space;
@@ -974,7 +1073,11 @@ double sound_flush(int relative_speed)
             if (suspend_time > 0)
                 suspendsound("running too slow");
             else {
+#ifdef HAS_TRANSLATION
+                sound_error(translate_text(IDGS_RUNNING_TOO_SLOW));
+#else
                 sound_error(_("running too slow."));
+#endif
             }
             return 0;
         }
@@ -986,13 +1089,21 @@ double sound_flush(int relative_speed)
 
     /* Flush buffer, all channels are already mixed into it. */
     if (snddata.playdev->write(snddata.buffer, nr * snddata.channels)) {
+#ifdef HAS_TRANSLATION
+        sound_error(translate_text(IDGS_WRITE_TO_SOUND_DEVICE_FAILED));
+#else
         sound_error(_("write to sounddevice failed."));
+#endif
         return 0;
     }
 
     if (snddata.recdev) {
         if (snddata.recdev->write(snddata.buffer, nr * snddata.channels)) {
+#ifdef HAS_TRANSLATION
+            sound_error(translate_text(IDGS_WRITE_TO_SOUND_DEVICE_FAILED));
+#else
             sound_error(_("write to sounddevice failed."));
+#endif
             return 0;
         }
     }
@@ -1107,19 +1218,34 @@ void sound_init(unsigned int clock_rate, unsigned int ticks_per_frame)
     clk_guard_add_callback(maincpu_clk_guard, prevent_clk_overflow_callback,
                            NULL);
 
+    devlist = lib_stralloc("");
+
 #if defined(USE_ARTS)
     sound_init_arts_device();
 #endif
+#if defined(HAVE_ALSA_ASOUNDLIB_H)
+    sound_init_alsa_device();
+#endif
+#ifdef USE_COREAUDIO
+    sound_init_coreaudio_device();
+#endif
 #if defined(HAVE_LINUX_SOUNDCARD_H) || defined(HAVE_MACHINE_SOUNDCARD_H) || defined(HAVE_SYS_SOUNDCARD_H)
+
+/* don't use uss for FreeBSD or BSDI */
+
+#if !defined(__FreeBSD__) && !defined(__bsdi__)
     sound_init_uss_device();
 #endif
+#endif
 #if defined(HAVE_ESD_H) && defined(HAVE_LIBESD)
     sound_init_esd_device();
 #endif
 #if defined(HAVE_DMEDIA_AUDIO_H)
     sound_init_sgi_device();
 #endif
-#if defined(HAVE_SYS_AUDIOIO_H)
+
+/* Don't use the NetBSD/SUN sound driver for OpenBSD */
+#if defined(HAVE_SYS_AUDIOIO_H) && !defined(__OpenBSD__)
     sound_init_sun_device();
 #endif
 #if defined(HAVE_SYS_AUDIO_H)
@@ -1176,6 +1302,10 @@ void sound_init(unsigned int clock_rate, unsigned int ticks_per_frame)
 #if 0
     sound_init_test_device();   /* XXX: missing */
 #endif
+
+    log_message(sound_log, "Available sound devices:%s", devlist);
+
+    lib_free(devlist);
 }
 
 long sound_sample_position(void)
@@ -1216,7 +1346,11 @@ void sound_store(WORD addr, BYTE val, int chipno)
     snddata.wclk = maincpu_clk;
 
     if (i)
+#ifdef HAS_TRANSLATION
+        sound_error(translate_text(IDGS_STORE_SOUNDDEVICE_FAILED));
+#else
         sound_error(_("store to sounddevice failed."));
+#endif
 }
 
 
