@@ -27,6 +27,9 @@
  *
  */
 
+/* Don't use this sound driver for OpenBSD */
+#if !defined(__OpenBSD__)
+
 #include "vice.h"
 
 #include <stdio.h>
@@ -46,7 +49,7 @@
 
 #include <sys/audioio.h>
 
-#if defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__NetBSD__)
 #include <sys/ioctl.h>       /* For ioctl and _IOWR */
 #include <string.h>          /* For memset */
 #endif
@@ -58,8 +61,11 @@ static int sun_bufferspace(void);
 
 static int sun_fd = -1;
 static int sun_8bit = 0;
+static int sun_channels = 1;
 static int sun_bufsize = 0;
+#if !defined(__NETBSD__)
 static int sun_written = 0;
+#endif
 
 static int toulaw8(SWORD data)
 {
@@ -101,8 +107,10 @@ static int sun_init(const char *param, int *speed,
     int	st;
     struct audio_info info;
 
+#if !defined(__NETBSD__)
     /* No stereo capability. */
     *channels = 1;
+#endif
 
     if (!param) {
         if (getenv("AUDIODEV"))
@@ -115,7 +123,7 @@ static int sun_init(const char *param, int *speed,
 	return 1;
     AUDIO_INITINFO(&info);
     info.play.sample_rate = *speed;
-    info.play.channels = 1;
+    info.play.channels = *channels;
     info.play.precision = 16;
     info.play.encoding = AUDIO_ENCODING_LINEAR;
     st = ioctl(sun_fd, AUDIO_SETINFO, &info);
@@ -130,10 +138,14 @@ static int sun_init(const char *param, int *speed,
 	    goto fail;
 	sun_8bit = 1;
 	*speed = 8000;
+        *channels = 1;
 	log_message(LOG_DEFAULT, "Playing 8 bit ulaw at 8000Hz");
     }
     sun_bufsize = (*fragsize)*(*fragnr);
+#if !defined(__NETBSD__)
     sun_written = 0;
+#endif
+    sun_channels = *channels;
     return 0;
 fail:
     close(sun_fd);
@@ -152,14 +164,16 @@ static int sun_write(SWORD *pbuf, size_t nr)
 	total = nr;
     }
     else
-	total = nr*sizeof(SWORD);
+	total = nr*sizeof(SWORD)*sun_channels;
     for (i = 0; i < total; i += now)
     {
 	now = write(sun_fd, (char *)pbuf + i, total - i);
 	if (now <= 0)
 	    return 1;
     }
+#if !defined(__NETBSD__)
     sun_written += nr;
+#endif
 
     while (sun_bufferspace() < 0)
 	usleep(5000);
@@ -169,18 +183,19 @@ static int sun_write(SWORD *pbuf, size_t nr)
 
 static int sun_bufferspace(void)
 {
-    int			st;
+    int	st, size;
     struct audio_info	info;
     /* ioctl(fd, AUDIO_GET_STATUS, &info) yields number of played samples
        in info.play.samples. */
     st = ioctl(sun_fd, AUDIO_GETINFO, &info);
     if (st < 0)
 	return -1;
-#if defined(__NetBSD__) || defined(__OpenBSD__)
-    if (!sun_8bit)
-	return sun_bufsize - (sun_written - info.play.samples / sizeof(SWORD));
-#endif
+#if defined(__NetBSD__)
+    size = (sun_8bit ? 1 : 2) * sun_channels;
+    return sun_bufsize - info.play.seek  / size;
+#else
     return sun_bufsize - (sun_written - info.play.samples);
+#endif
 }
 
 static void sun_close(void)
@@ -189,13 +204,16 @@ static void sun_close(void)
     sun_fd = -1;
     sun_8bit = 0;
     sun_bufsize = 0;
+#if !defined(__NETBSD__)
     sun_written = 0;
+#endif
+    sun_channels = 1;
 }
 
 
 static sound_device_t sun_device =
 {
-#if defined(__NetBSD__) || defined(__OpenBSD__)
+#if defined(__NetBSD__)
     "netbsd",
 #else
     "sun",
@@ -215,3 +233,5 @@ int sound_init_sun_device(void)
 {
     return sound_register_device(&sun_device);
 }
+
+#endif
