@@ -38,6 +38,9 @@
 #include "log.h"
 #include "resources.h"
 #include "sysfile.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "util.h"
 
 
@@ -112,12 +115,19 @@ static const resource_t resources[] = {
 
 /* Command-line options.  */
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] = {
     { "-directory", SET_RESOURCE, 1, NULL, NULL, "Directory", NULL,
-      "<path>", "Define search path to locate system files" },
+      IDCLS_P_PATH, IDCLS_DEFINE_SYSTEM_FILES_PATH },
     { NULL },
 };
-
+#else
+static const cmdline_option_t cmdline_options[] = {
+    { "-directory", SET_RESOURCE, 1, NULL, NULL, "Directory", NULL,
+      N_("<path>"), N_("Define search path to locate system files") },
+    { NULL },
+};
+#endif
 
 /* ------------------------------------------------------------------------- */
 
