@@ -221,17 +221,20 @@ int tap_create(const char *name)
 
 static int tap_find_pilot(tap_t *tap, int type);
 
-inline static int tap_get_pulse(tap_t *tap)
+inline static int tap_get_pulse(tap_t *tap, int *pos_advance)
 {
     BYTE data;
     DWORD pulse_length = 0;
     size_t res;
 
+    *pos_advance = 0;
     res = fread(&data, 1, 1, tap->fd);
 
     if (res == 0)
         return -1;
 
+    *pos_advance += res;
+
     if (data == 0) {
         if (tap->version == 0) {
             pulse_length = 256;
@@ -240,6 +243,7 @@ inline static int tap_get_pulse(tap_t *tap)
             res = fread(size, 3, 1, tap->fd);
             if (res == 0)
                 return -1;
+            *pos_advance += res;
             pulse_length = ((size[2] << 16) | (size[1] << 8) | size[0]) >> 3;
         }
     } else {
@@ -254,11 +258,13 @@ inline static int tap_get_pulse(tap_t *tap)
 
         if (res == 0)
             return -1;
+        *pos_advance += res;
         if (data == 0) {
             BYTE size[3];
             res = fread(size, 3, 1, tap->fd);
             if (res == 0)
                 return -1;
+            *pos_advance += res;
             pulse_length2 = ((size[2] << 16) | (size[1] << 8) | size[0]) >> 3;
         } else {
             pulse_length2 = data;
@@ -286,10 +292,11 @@ inline static int tap_get_pulse(tap_t *tap)
 inline static int tap_cbm_read_bit(tap_t *tap)
 {
   int pulse1, pulse2;
+  int pos_advance;
 
-  pulse1 = tap_get_pulse(tap);
+  pulse1 = tap_get_pulse(tap, &pos_advance);
   if (pulse1 < 0) return -1;
-  pulse2 = tap_get_pulse(tap);
+  pulse2 = tap_get_pulse(tap, &pos_advance);
   if (pulse2 < 0) return -1;
   
   /* when reading a bit, treat L as M */
@@ -306,17 +313,18 @@ static int tap_cbm_read_byte(tap_t *tap)
 {
     int i, data, parity;
     BYTE read;
+    int pos_advance;
 
     /* wait for L pulse (start-of-byte) */
     do
       {
-        data = tap_get_pulse(tap);
+        data = tap_get_pulse(tap, &pos_advance);
         if (data < 0) return -1;
       }
     while( !TAP_PULSE_LONG(data) );
 
     /* expect either M (L-M: start-of-byte) or S (L-S: end-of-data-block) */
-    data = tap_get_pulse(tap);
+    data = tap_get_pulse(tap, &pos_advance);
     if (data < 0)
       return -1; /* end of tape */
     else if( TAP_PULSE_SHORT(data) )
@@ -352,19 +360,24 @@ static int tap_cbm_skip_pilot(tap_t *tap)
   int data, errors;
   long fpos, counter;
   long fpos2;
+  long current_filepos;
+  int pos_advance;
   
   errors  = 0;
   counter = 0;
+  current_filepos = ftell(tap->fd);
   while(1)
     {
       /*  Save file position */
-      fpos = ftell(tap->fd);
-      data = tap_get_pulse(tap);
-      fpos2 = ftell(tap->fd);
+      fpos = current_filepos;
+      data = tap_get_pulse(tap, &pos_advance);
+      current_filepos += pos_advance;
+      fpos2 = current_filepos;
       if( TAP_PULSE_LONG(data) )
         {
           /* found an L pulse, try to read a byte */
           fseek(tap->fd, fpos, SEEK_SET);
+          current_filepos = fpos;
           data = tap_cbm_read_byte(tap);
           if( data==-1 ) 
             {
@@ -378,12 +391,14 @@ static int tap_cbm_skip_pilot(tap_t *tap)
 
               /* Start over after the L pulse */
               fseek(tap->fd, fpos2, SEEK_SET);
+              current_filepos = fpos2;
               counter = 0;
             }
           else
             {
               /* success.  Go back to start of byte and return */
               fseek(tap->fd, fpos, SEEK_SET);
+              current_filepos = fpos;
               return 0;
             }
         }
@@ -405,7 +420,7 @@ void tap_cbm_print_error(int ret)
     case  0: log_debug("OK\n"); break;
     case -1: log_debug("ERROR (tape end)\n"); break;
     case -2: log_debug("ERROR (sync read)\n"); break;
-    case -3: log_debug("ERROR (short block)\n"); break;
+/*    case -3: log_debug("ERROR (short block)\n"); break; */
     case -4: log_debug("ERROR (long block)\n"); break;
     case -5: log_debug("ERROR (too many single errors)\n"); break;
     case -6: log_debug("ERROR (double read error)\n"); break;
@@ -415,7 +430,7 @@ void tap_cbm_print_error(int ret)
 }
 #endif
 
-static int tap_cbm_read_block_once(tap_t *tap, int *pass, BYTE *buffer, int size, int *error_buf, int *error_count)
+static int tap_cbm_read_block_once(tap_t *tap, int *pass, BYTE *buffer, int *size, int *error_buf, int *error_count)
 {
   int count, data, ecount, found_pass;
 
@@ -423,7 +438,7 @@ static int tap_cbm_read_block_once(tap_t *tap, int *pass, BYTE *buffer, int size
       0 : ok
      -1 : tape end reached
      -2 : error reading sync 
-     -3 : short block
+     (-3 : short block) short blocks are okay, size will be adapted (iAN CooG, AndrerasM)
      -4 : long block
      -5 : too many single errors
      -6 : unrecoverable read error */
@@ -495,21 +510,19 @@ static int tap_cbm_read_block_once(tap_t *tap, int *pass, BYTE *buffer, int size
       else if( data==-3 )
         {
           /* found L-S sequence (end-of-block) */
-          if( count<size )
-            return -3; /* error: small block */
-          else
-            return 0;
+          *size = count; /* set size */
+          return 0;
         }
       else
         {
           /* byte ok */
-          if( count<size ) 
+          if( count < *size ) 
             {
 #if TAP_DEBUG > 1
               log_debug(" %02x", (BYTE) data);
 #endif
               buffer[count++] = (BYTE) data;
-              if ((tap->system == 2) && (count == size)) {
+              if ((tap->system == 2) && (count == *size)) {
                   /*  On the C16 a block is finished with 1 Medium pulse
                       followed by 450 Small pulse
                       Return here, because the byte read expects a Long pulse
@@ -540,7 +553,7 @@ static int tap_cbm_read_block(tap_t *tap, BYTE *buffer, int size)
     {
       /* try to read data.  If tap_cbm_read_block_once() finds a sync countdown 
          it will reset 'pass' to the value indicated by the countdown. */
-      ret = tap_cbm_read_block_once(tap, &pass, buffer, size, error_buf, &error_count);
+      ret = tap_cbm_read_block_once(tap, &pass, buffer, &size, error_buf, &error_count);
 
 #if TAP_DEBUG>0 
       log_debug(" PASS%i:%i/%i ", pass, ret, error_count);
@@ -598,10 +611,10 @@ static int tap_cbm_read_block(tap_t *tap, BYTE *buffer, int size)
 static int tap_cbm_read_header(tap_t *tap)
 {
   int ret;
-  BYTE buffer[193];
+  BYTE buffer[255];
 
   /* read header data */
-  ret = tap_cbm_read_block(tap, buffer, 193);
+  ret = tap_cbm_read_block(tap, buffer, 255);
   if( ret<0 ) return ret;
 
   /* first byte of header must represent a valid file type (1, 3 or 4) */
@@ -763,6 +776,7 @@ static int tap_tt_read_byte(tap_t *tap)
 {
   int pulse, i;
   BYTE read;
+  int pos_advance;
 
   read = 0;
 
@@ -770,7 +784,7 @@ static int tap_tt_read_byte(tap_t *tap)
      short pulse=0,  long pulse=1.  MSB comes first */
   for(i=0; i<8; i++)
     {
-      pulse = tap_get_pulse(tap);
+      pulse = tap_get_pulse(tap, &pos_advance);
       if( pulse<0 ) return -1;
 
       read <<= 1;
@@ -1192,8 +1206,9 @@ static int tap_find_header(tap_t *tap)
           res = tap_cbm_read_header(tap);
           if( res<0 ) 
             {
+              int pos_advance;
               fseek(tap->fd, fpos, SEEK_SET);
-              while( TAP_PULSE_SHORT(tap_get_pulse(tap)) );
+              while( TAP_PULSE_SHORT(tap_get_pulse(tap, &pos_advance)) );
             }
         }
       else if( type==PILOT_TYPE_TT )
