@@ -56,6 +56,7 @@
 #define DRIVE_RAMSIZE           0x400
 
 #define DIR_MAXBUF  (40 * 256)
+#define BAM_MAXSIZE (5 * 256)
 
 /* Serial Error Codes. */
 #define SERIAL_OK               0
@@ -77,6 +78,34 @@ typedef struct bufferinfo_s {
     unsigned int sector;   /*   (for write files only) */
     unsigned int length;   /* Directory-read length */
     unsigned int record;   /* Current record */
+
+    /* REL file information stored in buffers since we can have more than
+        one open */
+    BYTE *side_sector;
+    /* location of the side sectors */
+    BYTE *side_sector_track;
+    BYTE *side_sector_sector;
+
+    BYTE *super_side_sector;
+    /* location of the super side sector */
+    BYTE super_side_sector_track;
+    BYTE super_side_sector_sector;
+
+    BYTE *buffer_next;          /* next buffer for rel file */
+    unsigned int track_next;    /* track for the next sector */
+    unsigned int sector_next;   /* sector for the next sector */
+
+    unsigned int record_max;  /* Max rel file record, inclusive */
+    unsigned int record_next; /* Buffer pointer to beginning of next record */
+    BYTE needsupdate;         /* true if the current sector needs to be
+                                  written (from REL write) */
+    BYTE super_side_sector_needsupdate; /* similar to above */
+    BYTE *side_sector_needsupdate;
+
+    BYTE dir_track;           /* track, sector and slot of REL file */
+    BYTE dir_sector;          /*  directory entry */
+    BYTE dir_slot;
+
 } bufferinfo_t;
 
 struct disk_image_s;
@@ -98,16 +127,15 @@ typedef struct vdrive_s {
     unsigned int Dir_Sector;
     unsigned int num_tracks;
 
-    /* FIXME: bam sizeof define */
-    BYTE bam[5 * 256]; /* The 1581 uses 3 secs as BAM - but the 8250 uses 5.  */
+    BYTE bam[BAM_MAXSIZE];
     bufferinfo_t buffers[16];
 
     /* File information */
     BYTE Dir_buffer[256];  /* Current directory sector.  */
     unsigned int SlotNumber;
 
-    const char *find_name; /* Current search pattern.  */
     int find_length;       /* -1 allowed.  */
+    BYTE find_nslot[16];
     unsigned int find_type;
 
     unsigned int Curr_track;
@@ -120,7 +148,8 @@ typedef struct vdrive_s {
     BYTE mem_buf[256];
     unsigned int mem_length;
 
-    BYTE *side_sector;
+    /* removed side sector data and placed it in buffer structure */
+    /* BYTE *side_sector; */
 
     BYTE ram[0x800];
 } vdrive_t;
