@@ -28,10 +28,12 @@
  *
  */
 
-#ifndef _VIC_II_COLOR_H
-#define _VIC_II_COLOR_H
+#ifndef _VIC_COLOR_H
+#define _VIC_COLOR_H
 
-extern int vic_update_palette(void);
+struct video_canvas_s;
+
+extern int vic_color_update_palette(struct video_canvas_s *canvas);
 
 #endif
 
