@@ -276,9 +276,16 @@ static void vic20_monitor_init(void)
 {
     unsigned int dnr;
     monitor_cpu_type_t asm6502;
-    monitor_cpu_type_t *asmarray[2] = { &asm6502, NULL };
     monitor_interface_t *drive_interface_init[DRIVE_NUM];
 
+#ifdef MINIXVMD
+    monitor_cpu_type_t *asmarray[2];
+    asmarray[0]=&asm6502;
+    asmarray[1]=NULL;
+#else
+    monitor_cpu_type_t *asmarray[2] = { &asm6502, NULL };
+#endif
+
     asm6502_init(&asm6502);
 
     for (dnr = 0; dnr < DRIVE_NUM; dnr++)
@@ -446,13 +453,16 @@ static void machine_vsync_hook(void)
     drivecpu_prevent_clk_overflow_all(sub);
 }
 
-int machine_set_restore_key(int v)
+void machine_set_restore_key(int v)
 {
     viacore_signal(machine_context.via2,
                    VIA_SIG_CA1, v ? VIA_SIG_FALL : VIA_SIG_RISE);
-    return 1;
 }
 
+int machine_has_restore_key(void)
+{
+    return 1;
+}
 /* ------------------------------------------------------------------------- */
 
 long machine_get_cycles_per_second(void)
