@@ -49,6 +49,9 @@
 #include "log.h"
 #include "mem.h"
 #include "resources.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "util.h"
 #include "vic20mem.h"
 #include "zfile.h"
@@ -191,20 +194,37 @@ static int attach_cart2(const char *param, void *extra_param)
     return cartridge_attach_image(CARTRIDGE_VIC20_16KB_2000, param);
 }
 
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
     { "-cart2", CALL_FUNCTION, 1, attach_cart2, NULL, NULL, NULL,
-      "<name>", "Specify 4/8/16K extension ROM name at $2000" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_EXT_ROM_2000_NAME },
     { "-cart4", CALL_FUNCTION, 1, attach_cart4, NULL, NULL, NULL,
-      "<name>", "Specify 4/8/16K extension ROM name at $4000" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_EXT_ROM_4000_NAME },
     { "-cart6", CALL_FUNCTION, 1, attach_cart6, NULL, NULL, NULL,
-      "<name>", "Specify 4/8/16K extension ROM name at $6000" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_EXT_ROM_6000_NAME },
     { "-cartA", CALL_FUNCTION, 1, attach_cartA, NULL, NULL, NULL,
-      "<name>", "Specify 4/8K extension ROM name at $A000" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_EXT_ROM_A000_NAME },
     { "-cartB", CALL_FUNCTION, 1, attach_cartB, NULL, NULL, NULL,
-      "<name>", "Specify 4K extension ROM name at $B000" },
+      IDCLS_P_NAME, IDCLS_SPECIFY_EXT_ROM_B000_NAME },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] =
+{
+    { "-cart2", CALL_FUNCTION, 1, attach_cart2, NULL, NULL, NULL,
+      N_("<name>"), N_("Specify 4/8/16K extension ROM name at $2000") },
+    { "-cart4", CALL_FUNCTION, 1, attach_cart4, NULL, NULL, NULL,
+      N_("<name>"), N_("Specify 4/8/16K extension ROM name at $4000") },
+    { "-cart6", CALL_FUNCTION, 1, attach_cart6, NULL, NULL, NULL,
+      N_("<name>"), N_("Specify 4/8/16K extension ROM name at $6000") },
+    { "-cartA", CALL_FUNCTION, 1, attach_cartA, NULL, NULL, NULL,
+      N_("<name>"), N_("Specify 4/8K extension ROM name at $A000") },
+    { "-cartB", CALL_FUNCTION, 1, attach_cartB, NULL, NULL, NULL,
+      N_("<name>"), N_("Specify 4K extension ROM name at $B000") },
+    { NULL }
+};
+#endif
 
 int cartridge_cmdline_options_init(void)
 {
