@@ -31,35 +31,65 @@
 
 #include "cmdline.h"
 #include "raster-cmdline-options.h"
+#ifdef HAS_TRANSLATION
+#include "translate.h"
+#endif
 #include "vicii-cmdline-options.h"
 #include "viciitypes.h"
 
 
 /* VIC-II command-line options.  */
+#ifdef HAS_TRANSLATION
 static const cmdline_option_t cmdline_options[] =
 {
     { "-VICIIchecksb", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSbColl",
-      (void *)1, NULL, "Enable sprite-background collision registers" },
+      (void *)1, 0, IDCLS_ENABLE_SPRITE_BACKGROUND },
     { "+VICIIchecksb", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSbColl",
-      (void *)0, NULL, "Disable sprite-background collision registers" },
+      (void *)0, 0, IDCLS_DISABLE_SPRITE_BACKGROUND },
     { "-VICIIcheckss", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSsColl",
-      (void *)1, NULL, "Enable sprite-sprite collision registers" },
+      (void *)1, 0, IDCLS_ENABLE_SPRITE_SPRITE },
     { "+VICIIcheckss", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSsColl",
-      (void *)0, NULL, "Disable sprite-sprite collision registers" },
+      (void *)0, 0, IDCLS_DISABLE_SPRITE_SPRITE },
     { "-newluminance", SET_RESOURCE, 0, NULL, NULL, "VICIINewLuminances",
-      (void *)1, NULL, "Use new luminances" },
+      (void *)1, 0, IDCLS_USE_NEW_LUMINANCES },
     { "+newluminance", SET_RESOURCE, 0, NULL, NULL, "VICIINewLuminances",
-      (void *)0, NULL, "Use old luminances" },
+      (void *)0, 0, IDCLS_USE_OLD_LUMINANCES },
     { "-saturation", SET_RESOURCE, 1, NULL, NULL, "ColorSaturation", NULL,
-      "<0-2000>", "Set saturation of internal calculated palette [1000]" },
+      IDCLS_P_0_2000, IDCLS_SET_SATURATION },
     { "-contrast", SET_RESOURCE, 1, NULL, NULL, "ColorContrast", NULL,
-      "<0-2000>", "Set contrast of internal calculated palette [1100]" },
+      IDCLS_P_0_2000, IDCLS_SET_CONTRAST },
     { "-brightness", SET_RESOURCE, 1, NULL, NULL, "ColorBrightness", NULL,
-      "<0-2000>", "Set brightness of internal calculated palette [1100]" },
+      IDCLS_P_0_2000, IDCLS_SET_BRIGHTNESS },
     { "-gamma", SET_RESOURCE, 1, NULL, NULL, "ColorGamma", NULL,
-      "<0-2000>", "Set gamma of internal calculated palette [900]" },
+      IDCLS_P_0_2000, IDCLS_SET_GAMMA },
     { NULL }
 };
+#else
+static const cmdline_option_t cmdline_options[] =
+{
+    { "-VICIIchecksb", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSbColl",
+      (void *)1, NULL, N_("Enable sprite-background collision registers") },
+    { "+VICIIchecksb", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSbColl",
+      (void *)0, NULL, N_("Disable sprite-background collision registers") },
+    { "-VICIIcheckss", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSsColl",
+      (void *)1, NULL, N_("Enable sprite-sprite collision registers") },
+    { "+VICIIcheckss", SET_RESOURCE, 0, NULL, NULL, "VICIICheckSsColl",
+      (void *)0, NULL, N_("Disable sprite-sprite collision registers") },
+    { "-newluminance", SET_RESOURCE, 0, NULL, NULL, "VICIINewLuminances",
+      (void *)1, NULL, N_("Use new luminances") },
+    { "+newluminance", SET_RESOURCE, 0, NULL, NULL, "VICIINewLuminances",
+      (void *)0, NULL, N_("Use old luminances") },
+    { "-saturation", SET_RESOURCE, 1, NULL, NULL, "ColorSaturation", NULL,
+      "<0-2000>", N_("Set saturation of internal calculated palette [1000]") },
+    { "-contrast", SET_RESOURCE, 1, NULL, NULL, "ColorContrast", NULL,
+      "<0-2000>", N_("Set contrast of internal calculated palette [1100]") },
+    { "-brightness", SET_RESOURCE, 1, NULL, NULL, "ColorBrightness", NULL,
+      "<0-2000>", N_("Set brightness of internal calculated palette [1100]") },
+    { "-gamma", SET_RESOURCE, 1, NULL, NULL, "ColorGamma", NULL,
+      "<0-2000>", N_("Set gamma of internal calculated palette [900]") },
+    { NULL }
+};
+#endif
 
 int vicii_cmdline_options_init(void)
 {
