@@ -3,6 +3,7 @@
  *
  * Written by
  *  Ettore Perazzoli <ettore@comm2000.it>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -24,19 +25,17 @@
  *
  */
 
-#ifndef _VIC_II_MEM_H
-#define _VIC_II_MEM_H
+#ifndef _VICII_MEM_H
+#define _VICII_MEM_H
 
 #include "types.h"
 
-extern void REGPARM2 vic_store(ADDRESS addr, BYTE value);
-extern BYTE REGPARM1 vic_read(ADDRESS addr);
-extern BYTE REGPARM1 vic_peek(ADDRESS addr);
-extern BYTE REGPARM1 colorram_read(ADDRESS addr);
-extern void REGPARM2 colorram_store(ADDRESS addr, BYTE value);
-extern void REGPARM2 vicii_mem_vbank_store(ADDRESS addr, BYTE value);
-extern void REGPARM2 vicii_mem_vbank_39xx_store(ADDRESS addr, BYTE value);
-extern void REGPARM2 vicii_mem_vbank_3fxx_store(ADDRESS addr, BYTE value);
+extern void REGPARM2 vicii_store(WORD addr, BYTE value);
+extern BYTE REGPARM1 vicii_read(WORD addr);
+extern BYTE REGPARM1 vicii_peek(WORD addr);
+extern void REGPARM2 vicii_mem_vbank_store(WORD addr, BYTE value);
+extern void REGPARM2 vicii_mem_vbank_39xx_store(WORD addr, BYTE value);
+extern void REGPARM2 vicii_mem_vbank_3fxx_store(WORD addr, BYTE value);
 
 #endif
 
