@@ -28,7 +28,6 @@
 #define _VIDEO_H
 
 #include "types.h"
-#include "viewport.h"
 
 
 /* These constants are used to configure the video output.  */
@@ -98,6 +97,7 @@ struct video_chip_cap_s {
     unsigned int dsize_limit_width;
     unsigned int dsize_limit_height;
     unsigned int dscan_allowed;
+    unsigned int hwscale_allowed;
     unsigned int scale2x_allowed;
     unsigned int internal_palette_allowed;
     unsigned int palemulation_allowed;
@@ -114,6 +114,7 @@ struct video_render_config_s {
     int doublesizex;               /* Doublesizex enabled?  */
     int doublesizey;               /* Doublesizey enabled?  */
     int doublescan;                /* Doublescan enabled?  */
+    int hwscale;                   /* Hardware scaling enabled? */
     int scale2x;                   /* Scale2x enabled?  */
     DWORD physical_colors[256];
     unsigned int external_palette; /* Use an external palette?  */
@@ -168,7 +169,7 @@ extern void video_viewport_get(struct video_canvas_s *canvas,
 extern void video_viewport_resize(struct video_canvas_s *canvas);
 extern void video_viewport_title_set(struct video_canvas_s *canvas,
                                      const char *title);
-extern void video_viewport_title_free(viewport_t *viewport);
+extern void video_viewport_title_free(struct viewport_s *viewport);
 
 typedef struct video_draw_buffer_callback_s {
     int (*draw_buffer_alloc)(struct video_canvas_s *canvas, BYTE **draw_buffer,
