@@ -35,12 +35,13 @@
 #include "video-color.h"
 #include "video.h"
 #include "videoarch.h"
+#include "viewport.h"
 #include "util.h"
 
 
 video_resources_t video_resources =
 {
-    1000, 1100, 1100, 880, 500,
+    1000, 1100, 1100, 880, 0,
     0, 0, 0
 };
 
@@ -62,6 +63,7 @@ struct video_resource_chip_s {
     video_chip_cap_t *video_chip_cap;
     int double_scan_enabled;
     int double_size_enabled;
+    int hwscale_enabled;
     int scale2x_enabled;
     int fullscreen_enabled;
     char *fullscreen_device;
@@ -87,6 +89,7 @@ static int set_double_size_enabled(resource_value_t v, void *param)
     video_chip_cap_t *video_chip_cap;
     cap_render_t *cap_render;
     video_canvas_t *canvas;
+    int old_doublesizex, old_doublesizey;
 
     video_resource_chip = (video_resource_chip_t *)param;
     video_chip_cap = video_resource_chip->video_chip_cap;
@@ -99,18 +102,23 @@ static int set_double_size_enabled(resource_value_t v, void *param)
 
     canvas->videoconfig->rendermode = cap_render->rmode;
 
+    old_doublesizex = canvas->videoconfig->doublesizex;
+    old_doublesizey = canvas->videoconfig->doublesizey;
+
     if (cap_render->sizex > 1
         && (video_chip_cap->dsize_limit_width == 0
-        || canvas->draw_buffer->canvas_width
-        <= video_chip_cap->dsize_limit_width))
+        || (canvas->draw_buffer->canvas_width > 0
+        && canvas->draw_buffer->canvas_width
+        <= video_chip_cap->dsize_limit_width)))
         canvas->videoconfig->doublesizex = 1;
     else
         canvas->videoconfig->doublesizex = 0;
 
     if (cap_render->sizey > 1
         && (video_chip_cap->dsize_limit_height == 0
-        || canvas->draw_buffer->canvas_height
-        <= video_chip_cap->dsize_limit_height))
+        || (canvas->draw_buffer->canvas_height > 0
+        && canvas->draw_buffer->canvas_height
+        <= video_chip_cap->dsize_limit_height)))
         canvas->videoconfig->doublesizey = 1;
     else
         canvas->videoconfig->doublesizey = 0;
@@ -125,7 +133,9 @@ static int set_double_size_enabled(resource_value_t v, void *param)
             canvas->videoconfig->rendermode = VIDEO_RENDER_RGB_1X1;
     }
 
-    if (video_resource_chip->double_size_enabled != (int)v
+    if ((video_resource_chip->double_size_enabled != (int)v
+        || old_doublesizex != canvas->videoconfig->doublesizex
+        || old_doublesizey != canvas->videoconfig->doublesizey)
         && canvas->initialized
         && canvas->viewport->update_canvas > 0) {
         video_viewport_resize(canvas);
@@ -175,6 +185,36 @@ static resource_t resources_chip_scan[] =
     { NULL }
 };
 
+static int set_hwscale_enabled(resource_value_t v, void *param)
+{
+    video_resource_chip_t *video_resource_chip;
+    video_canvas_t *canvas;
+
+    video_resource_chip = (video_resource_chip_t *)param;
+    canvas = *(video_resource_chip->canvas);
+
+    video_resource_chip->hwscale_enabled = (int)v;
+    canvas->videoconfig->hwscale = (int)v;
+
+    if (canvas->initialized) {
+        video_viewport_resize(canvas);
+        video_color_update_palette(canvas);
+    }
+
+    video_resources_update_ui(video_resource_chip);
+
+    return 0;
+}
+
+static const char *vname_chip_hwscale[] = { "HwScale", NULL };
+
+static resource_t resources_chip_hwscale[] =
+{
+    { NULL, RES_INTEGER, (resource_value_t)0, NULL,
+      set_hwscale_enabled, NULL },
+    { NULL }
+};
+
 static int set_scale2x_enabled(resource_value_t v, void *param)
 {
     video_resource_chip_t *video_resource_chip;
@@ -395,6 +435,18 @@ int video_resources_chip_init(const char *chipname,
         lib_free((char *)(resources_chip_scan[0].name));
     }
 
+    if (video_chip_cap->hwscale_allowed != 0) {
+        resources_chip_hwscale[0].name
+            = util_concat(chipname, vname_chip_hwscale[0], NULL);
+        resources_chip_hwscale[0].value_ptr
+            = (resource_value_t *)&(resource_chip->hwscale_enabled);
+        resources_chip_hwscale[0].param = (void *)resource_chip;
+        if (resources_register(resources_chip_hwscale) < 0)
+            return -1;
+
+        lib_free((char *)(resources_chip_hwscale[0].name));
+    }
+
     if (video_chip_cap->scale2x_allowed != 0) {
         resources_chip_scale2x[0].name
             = util_concat(chipname, vname_chip_scale2x[0], NULL);
